{%- if "AEPg" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Configuration Issues,Configuration State,Exception Tag,Flood On Encapsulation,Forward Control,Has Multicast Source,Is Attribute Based EPG,Is Shared Service Multicast Site EPG,Match T,PC Enforcement Preference,PC Tag,PC Tag Allocation Source,Preference Gr Member,Priority,Scope,Shutdown,Trigger State,TX Id,Modified Timestamp
{%-     for epg in data_to_template['imdata'] %}
{{ epg.fvAEPg.attributes.name }},{{ epg.fvAEPg.attributes.nameAlias }},{{ epg.fvAEPg.attributes.descr | replace(","," ") }},{{ epg.fvAEPg.attributes.status }},{{ epg.fvAEPg.attributes.dn }},{{ epg.fvAEPg.attributes.uid }},{{ epg.fvAEPg.attributes.annotation }},{{ epg.fvAEPg.attributes.childAction }},{{ epg.fvAEPg.attributes.extMngdBy }},{{ epg.fvAEPg.attributes.lcOwn }},{{ epg.fvAEPg.attributes.monPolDn }},{{ epg.fvAEPg.attributes.userdom }},{{ epg.fvAEPg.attributes.configIssues }},{{ epg.fvAEPg.attributes.configSt }},{{ epg.fvAEPg.attributes.exceptionTag }},{{ epg.fvAEPg.attributes.floodOnEncap }},{{ epg.fvAEPg.attributes.fwdCtrl }},{{ epg.fvAEPg.attributes.hasMcastSource }},{{ epg.fvAEPg.attributes.isAttrBasedEPg }},{{ epg.fvAEPg.attributes.isSharedSrvMsiteEPg }},{{ epg.fvAEPg.attributes.matchT }},{{ epg.fvAEPg.attributes.pcEnfPref }},{{ epg.fvAEPg.attributes.pcTag }},{{ epg.fvAEPg.attributes.pcTagAllocSrc }},{{ epg.fvAEPg.attributes.prefGrMemb }},{{ epg.fvAEPg.attributes.prio }},{{ epg.fvAEPg.attributes.scope }},{{ epg.fvAEPg.attributes.shutdown }},{{ epg.fvAEPg.attributes.triggerSt }},{{ epg.fvAEPg.attributes.txId }},{{ epg.fvAEPg.attributes.modTs }}
{%-     endfor %}
{%- elif "fvBD" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Configuration Issues,Optimize Wan Bandwidth,ARP Flood,Broadcast P,Endpoint Clear,Endpoint Move Detect Mode,Host Based Routing,Intersite BUM Traffic Allow,Intersite L2 Stretch,IP Learning,IPv6 Multicast Allow,Limit IP Learn To Subnets,Link Local Address,MAC,Multicast Allow,MTU,Multicase Destination Packet Action,Owner Key,Owner Tag,PC Tag,Scope,Segment,Type,Unicast Route,Unknown MAC Unicast Action,Unknown Multicast Action,IPv6 Unknown Multicast Action,Virtual MAC,Modified Timestamp
{%-     for bd in data_to_template['imdata'] %}
{{ bd.fvBD.attributes.name }},{{ bd.fvBD.attributes.nameAlias }},{{ bd.fvBD.attributes.descr | replace(","," ") }},{{ bd.fvBD.attributes.status }},{{ bd.fvBD.attributes.dn }},{{ bd.fvBD.attributes.uid }},{{ bd.fvBD.attributes.annotation }},{{ bd.fvBD.attributes.childAction }},{{ bd.fvBD.attributes.extMngdBy }},{{ bd.fvBD.attributes.lcOwn }},{{ bd.fvBD.attributes.monPolDn }},{{ bd.fvBD.attributes.userdom }},{{ bd.fvBD.attributes.configIssues }},{{ bd.fvBD.attributes.OptimizeWanBandwidth }},{{ bd.fvBD.attributes.arpFlood }},{{ bd.fvBD.attributes.bcastP }},{{ bd.fvBD.attributes.epClear }},{{ bd.fvBD.attributes.epMoveDetectMode }},{{ bd.fvBD.attributes.hostBasedRouting }},{{ bd.fvBD.attributes.intersiteBumTrafficAllow }},{{ bd.fvBD.attributes.intersiteL2Stretch }},{{ bd.fvBD.attributes.ipLearning }},{{ bd.fvBD.attributes.ipv6McastAllow }},{{ bd.fvBD.attributes.limitIpLearnToSubnets }},{{ bd.fvBD.attributes.llAddr }},{{ bd.fvBD.attributes.mac }},{{ bd.fvBD.attributes.mcastAllow }},{{ bd.fvBD.attributes.mtu }},{{ bd.fvBD.attributes.multiDstPktAct }},{{ bd.fvBD.attributes.ownerKey }},{{ bd.fvBD.attributes.ownerTag }},{{ bd.fvBD.attributes.pcTag }},{{ bd.fvBD.attributes.scope }},{{ bd.fvBD.attributes.seg }},{{ bd.fvBD.attributes.type }},{{ bd.fvBD.attributes.unicastRoute }},{{ bd.fvBD.attributes.unkMacUcastAct }},{{ bd.fvBD.attributes.unkMcastAct }},{{ bd.fvBD.attributes.v6unkMcastAct }},{{ bd.fvBD.attributes.vmac }},{{ bd.fvBD.attributes.modTs }}
{%-     endfor %}
{%- elif "fvCtx" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Bridge Domain Enforced Enable,IP Data Plane Learning,Known Multicast Action,Owner Key,Owner Tag,PC Enforce Directory,PC Enforce Directory Updated,PC Enforce Preference,PC Tag,Scope,Seg,VRF ID,VRF Index,Modified Timestamp
{%-     for context in data_to_template['imdata'] %}
{{ context.fvCtx.attributes.name }},{{ context.fvCtx.attributes.nameAlias }},{{ context.fvCtx.attributes.descr | replace(","," ") }},{{ context.fvCtx.attributes.status }},{{ context.fvCtx.attributes.dn }},{{ context.fvCtx.attributes.uid }},{{ context.fvCtx.attributes.annotation }},{{ context.fvCtx.attributes.childAction }},{{ context.fvCtx.attributes.extMngdBy }},{{ context.fvCtx.attributes.lcOwn }},{{ context.fvCtx.attributes.monPolDn }},{{ context.fvCtx.attributes.userdom }},{{ context.fvCtx.attributes.bdEnforcedEnable }},{{ context.fvCtx.attributes.ipDataPlaneLearning }},{{ context.fvCtx.attributes.knwMcastAct }},{{ context.fvCtx.attributes.ownerKey }},{{ context.fvCtx.attributes.ownerTag }},{{ context.fvCtx.attributes.pcEnfDir }},{{ context.fvCtx.attributes.pcEnfDirUpdated }},{{ context.fvCtx.attributes.pcEnfPref }},{{ context.fvCtx.attributes.pcTag }},{{ context.fvCtx.attributes.scope }},{{ context.fvCtx.attributes.seg }},{{ context.fvCtx.attributes.vrfId }},{{ context.fvCtx.attributes.vrfIndex }},{{ context.fvCtx.attributes.modTs }}
{%-     endfor %}
{%- elif "Ap" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Owner Key,Owner Tag,Priority,Modified Timestamp
{%-     for application_profile in data_to_template['imdata'] %}
{{ application_profile.fvAp.attributes.name }},{{ application_profile.fvAp.attributes.nameAlias }},{{ application_profile.fvAp.attributes.descr | replace(","," ") }},{{ application_profile.fvAp.attributes.status }},{{ application_profile.fvAp.attributes.dn }},{{ application_profile.fvAp.attributes.uid }},{{ application_profile.fvAp.attributes.annotation }},{{ application_profile.fvAp.attributes.childAction }},{{ application_profile.fvAp.attributes.extMngdBy }},{{ application_profile.fvAp.attributes.lcOwn }},{{ application_profile.fvAp.attributes.monPolDn }},{{ application_profile.fvAp.attributes.userdom }},{{ application_profile.fvAp.attributes.ownerKey }},{{ application_profile.fvAp.attributes.ownerTag }},{{ application_profile.fvAp.attributes.prio }},{{ application_profile.fvAp.attributes.modTs }}
{%-     endfor %}
{%- elif "l3extOut" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Owner Key,Owner Tag,Priority,Enforce Route Control,Target DSCP,Modified Timestamp
{%-     for l3out in data_to_template['imdata'] %}
{{ l3out.l3extOut.attributes.name }},{{ l3out.l3extOut.attributes.nameAlias }},{{ l3out.l3extOut.attributes.descr | replace(","," ") }},{{ l3out.l3extOut.attributes.status }},{{ l3out.l3extOut.attributes.dn }},{{ l3out.l3extOut.attributes.uid }},{{ l3out.l3extOut.attributes.annotation }},{{ l3out.l3extOut.attributes.childAction }},{{ l3out.l3extOut.attributes.extMngdBy }},{{ l3out.l3extOut.attributes.lcOwn }},{{ l3out.l3extOut.attributes.monPolDn }},{{ l3out.l3extOut.attributes.userdom }},{{ l3out.l3extOut.attributes.ownerKey }},{{ l3out.l3extOut.attributes.ownerTag }},{{ l3out.l3extOut.attributes.prio }},{{ l3out.l3extOut.attributes.enforceRtctrl }},{{ l3out.l3extOut.attributes.targetDscp }},{{ l3out.l3extOut.attributes.modTs }}
{%-     endfor %}
{%- elif "l2extOut" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,LC Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Target DSCP,UID,User Domain
{%-     for l2out in data_to_template['imdata'] %}
{{ l2out.l2extOut.attributes.name }},{{ l2out.l2extOut.attributes.nameAlias }},{{ l2out.l2extOut.attributes.annotation }},{{ l2out.l2extOut.attributes.childAction }},{{ l2out.l2extOut.attributes.descr | replace(","," ") }},{{ l2out.l2extOut.attributes.dn }},{{ l2out.l2extOut.attributes.extMngdBy }},{{ l2out.l2extOut.attributes.lcOwn }},{{ l2out.l2extOut.attributes.modTs }},{{ l2out.l2extOut.attributes.monPolDn }},{{ l2out.l2extOut.attributes.ownerKey }},{{ l2out.l2extOut.attributes.ownerTag }},{{ l2out.l2extOut.attributes.status }},{{ l2out.l2extOut.attributes.targetDscp }},{{ l2out.l2extOut.attributes.uid }},{{ l2out.l2extOut.attributes.userdom }}
{%-     endfor %}
{%- elif "fvSubnet" in api %}Name,Alias,Annotation,Child Action,Config Issues,Control,Debug Message,Description,DN,Externally Managed By,IP,IP Data Plane Learning,LC Owner,Monitoring Policy DN,Preferred,Scope,Status,UID,User Domain,Virtual,Last Modified
{%-     for subnet in data_to_template['imdata'] %}
{{ subnet.fvSubnet.attributes.name }},{{ subnet.fvSubnet.attributes.nameAlias }},{{ subnet.fvSubnet.attributes.annotation }},{{ subnet.fvSubnet.attributes.childAction }},{{ subnet.fvSubnet.attributes.configIssues }},{{ subnet.fvSubnet.attributes.ctrl }},{{ subnet.fvSubnet.attributes.debugMessage }},{{ subnet.fvSubnet.attributes.descr | replace(","," ") }},{{ subnet.fvSubnet.attributes.dn }},{{ subnet.fvSubnet.attributes.extMngdBy }},{{ subnet.fvSubnet.attributes.ip }},{{ subnet.fvSubnet.attributes.ipDPLearning }},{{ subnet.fvSubnet.attributes.lcOwn }},{{ subnet.fvSubnet.attributes.monPolDn }},{{ subnet.fvSubnet.attributes.preferred }},{{ subnet.fvSubnet.attributes.scope | replace(","," ")}},{{ subnet.fvSubnet.attributes.status }},{{ subnet.fvSubnet.attributes.uid }},{{ subnet.fvSubnet.attributes.userdom }},{{ subnet.fvSubnet.attributes.virtual }},{{ subnet.fvSubnet.attributes.modTs }}
{%-     endfor %}
{%- elif "fvCEp" in api %}Name,Name Alias,MAC,Annotation,Base EPG DN,Bridge Domain DN,Child Action,Container Name,DN,Encapsulation,ESG Use gDN,Externally Managed By,Full Fabric Path DN,POD,Path,Parent Interface,Interface Number,ID,ID Endpoint DN,LCC,LC Owner,Multicast Address,Last Modified,Monitor Policy DN,Status,UID,User Domain,UUID,VMM Source,VRF DN
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.fvCEp.attributes.name }},{{ endpoint.fvCEp.attributes.nameAlias }},{{ endpoint.fvCEp.attributes.mac }},{{ endpoint.fvCEp.attributes.annotation }},{{ endpoint.fvCEp.attributes.baseEpgDn }},{{ endpoint.fvCEp.attributes.bdDn }},{{ endpoint.fvCEp.attributes.childAction }},{{ endpoint.fvCEp.attributes.contName }},{{ endpoint.fvCEp.attributes.dn }},{{ endpoint.fvCEp.attributes.encap }},{{ endpoint.fvCEp.attributes.esgUsegDn }},{{ endpoint.fvCEp.attributes.extMngdBy }},{{ endpoint.fvCEp.attributes.fabricPathDn }},{%- if endpoint.fvCEp.attributes.fabricPathDn %}{{ endpoint.fvCEp.attributes.fabricPathDn | replace("topology/","") | replace("/",",") | replace("pathep-[","") | replace("]","")}}{%- if "eth" not in endpoint.fvCEp.attributes.fabricPathDn %},N/A{%- endif %}{%- else %}N/A,N/A,N/A,N/A{%- endif %},{{ endpoint.fvCEp.attributes.id }},{{ endpoint.fvCEp.attributes.idepdn }},{{ endpoint.fvCEp.attributes.lcC | replace(","," ") }},{{ endpoint.fvCEp.attributes.lcOwn }},{{ endpoint.fvCEp.attributes.mcastAddr }},{{ endpoint.fvCEp.attributes.modTs }},{{ endpoint.fvCEp.attributes.monPolDn }},{{ endpoint.fvCEp.attributes.status }},{{ endpoint.fvCEp.attributes.uid }},{{ endpoint.fvCEp.attributes.userdom }},{{ endpoint.fvCEp.attributes.uuid }},{{ endpoint.fvCEp.attributes.vmmSrc }},{{ endpoint.fvCEp.attributes.vrfDn }}
{%-     endfor %}
{%- elif "fabricNode" in api %}Name,Name Alias,AD St,Address,Annotation,APIC Type,Child Action,Delayed Heartbeat,DN,Externally Managed By,Fabric State,ID,Last State Modified,Local Owner,Last Modified,Model,Monitoring Policy DN,Node Type,Role,Serial,Status,UID,User Domain,Vendor,Version
{%-     for node in data_to_template['imdata'] %}
{{ node.fabricNode.attributes.name }},{{ node.fabricNode.attributes.nameAlias }},{{ node.fabricNode.attributes.adSt }},{{ node.fabricNode.attributes.address }},{{ node.fabricNode.attributes.annotation }},{{ node.fabricNode.attributes.apicType }},{{ node.fabricNode.attributes.childAction }},{{ node.fabricNode.attributes.delayedHeartbeat }},{{ node.fabricNode.attributes.dn }},{{ node.fabricNode.attributes.extMngdBy }},{{ node.fabricNode.attributes.fabricSt }},{{ node.fabricNode.attributes.id }},{{ node.fabricNode.attributes.lastStateModTs }},{{ node.fabricNode.attributes.lcOwn }},{{ node.fabricNode.attributes.modTs }},{{ node.fabricNode.attributes.model }},{{ node.fabricNode.attributes.monPolDn }},{{ node.fabricNode.attributes.nodeType }},{{ node.fabricNode.attributes.role }},{{ node.fabricNode.attributes.serial }},{{ node.fabricNode.attributes.status }},{{ node.fabricNode.attributes.uid }},{{ node.fabricNode.attributes.userdom }},{{ node.fabricNode.attributes.vendor | replace(","," ")}},{{ node.fabricNode.attributes.version }}
{%-     endfor %}
{%- elif "l1PhysIf" in api %}Admin State,Auto Negotiate,Breakout Map,Bandwidth,Child Action,Delay,Description,DFE Delay MS,DN,POD,Node,Dot1q EtherType,Eth PM Cfg Failed Bmp,Eth PM Cfg Failed Timestamp,Eth PM Cfg State,FCOT Channel Number,FEC Mode,ID,Inherited Bandwidth,Is Reflective Relay Config Supported,Layer,Local Owner,Link Debounce,Link Flap Error Max,Link Flap Error Seconds,Link Log,MDIX,Medium,Last Modified,Mode,Monitoring Policy DN,MTU,Name,Path S Description,Port Physical Media Type,Port T,Priority Flow Control,Reflective Relay Enable,Router MAC,SNMP Trap State,Span Mode,Speed,Status,Switching State,Trunk Log,Usage
{%-     for outer_list in data_to_template %}
{%-         for interface in outer_list %}
{{ interface.l1PhysIf.attributes.adminSt }},{{ interface.l1PhysIf.attributes.autoNeg }},{{ interface.l1PhysIf.attributes.brkoutMap }},{{ interface.l1PhysIf.attributes.bw }},{{ interface.l1PhysIf.attributes.childAction }},{{ interface.l1PhysIf.attributes.delay }},{{ interface.l1PhysIf.attributes.descr | replace(","," ") }},{{ interface.l1PhysIf.attributes.dfeDelayMs }},{{ interface.l1PhysIf.attributes.dn }},{{ interface.l1PhysIf.attributes.dn | replace("topology/","") | replace("/sys/phys-[","") | replace (interface.l1PhysIf.attributes.id,"") | replace("/",",") | replace("]","")}},{{ interface.l1PhysIf.attributes.dot1qEtherType }},{{ interface.l1PhysIf.attributes.ethpmCfgFailedBmp }},{{ interface.l1PhysIf.attributes.ethpmCfgFailedTs }},{{ interface.l1PhysIf.attributes.ethpmCfgState }},{{ interface.l1PhysIf.attributes.fcotChannelNumber }},{{ interface.l1PhysIf.attributes.fecMode }},{{ interface.l1PhysIf.attributes.id }},{{ interface.l1PhysIf.attributes.inhBw }},{{ interface.l1PhysIf.attributes.isReflectiveRelayCfgSupported }},{{ interface.l1PhysIf.attributes.layer }},{{ interface.l1PhysIf.attributes.lcOwn }},{{ interface.l1PhysIf.attributes.linkDebounce }},{{ interface.l1PhysIf.attributes.linkFlapErrorMax }},{{ interface.l1PhysIf.attributes.linkFlapErrorSeconds }},{{ interface.l1PhysIf.attributes.linkLog }},{{ interface.l1PhysIf.attributes.mdix }},{{ interface.l1PhysIf.attributes.medium }},{{ interface.l1PhysIf.attributes.modTs }},{{ interface.l1PhysIf.attributes.mode }},{{ interface.l1PhysIf.attributes.monPolDn }},{{ interface.l1PhysIf.attributes.mtu }},{{ interface.l1PhysIf.attributes.name }},{{ interface.l1PhysIf.attributes.pathSDescr }},{{ interface.l1PhysIf.attributes.portPhyMediaType }},{{ interface.l1PhysIf.attributes.portT }},{{ interface.l1PhysIf.attributes.prioFlowCtrl }},{{ interface.l1PhysIf.attributes.reflectiveRelayEn }},{{ interface.l1PhysIf.attributes.routerMac }},{{ interface.l1PhysIf.attributes.snmpTrapSt }},{{ interface.l1PhysIf.attributes.spanMode }},{{ interface.l1PhysIf.attributes.speed }},{{ interface.l1PhysIf.attributes.status }},{{ interface.l1PhysIf.attributes.switchingSt }},{{ interface.l1PhysIf.attributes.trunkLog }},{{ interface.l1PhysIf.attributes.usage | replace(","," ") }}
{%-         endfor %}
{%-     endfor %}
{%- elif "infraAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraAccPortP.attributes.name }},{{ profile.infraAccPortP.attributes.nameAlias }},{{ profile.infraAccPortP.attributes.annotation }},{{ profile.infraAccPortP.attributes.childAction }},{{ profile.infraAccPortP.attributes.descr | replace(","," ") }},{{ profile.infraAccPortP.attributes.dn }},{{ profile.infraAccPortP.attributes.extMngdBy }},{{ profile.infraAccPortP.attributes.lcOwn }},{{ profile.infraAccPortP.attributes.modTs }},{{ profile.infraAccPortP.attributes.monPolDn }},{{ profile.infraAccPortP.attributes.ownerKey }},{{ profile.infraAccPortP.attributes.ownerTag }},{{ profile.infraAccPortP.attributes.status }},{{ profile.infraAccPortP.attributes.uid }},{{ profile.infraAccPortP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraSpAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraSpAccPortP.attributes.name }},{{ profile.infraSpAccPortP.attributes.nameAlias }},{{ profile.infraSpAccPortP.attributes.annotation }},{{ profile.infraSpAccPortP.attributes.childAction }},{{ profile.infraSpAccPortP.attributes.descr | replace(","," ") }},{{ profile.infraSpAccPortP.attributes.dn }},{{ profile.infraSpAccPortP.attributes.extMngdBy }},{{ profile.infraSpAccPortP.attributes.lcOwn }},{{ profile.infraSpAccPortP.attributes.modTs }},{{ profile.infraSpAccPortP.attributes.monPolDn }},{{ profile.infraSpAccPortP.attributes.ownerKey }},{{ profile.infraSpAccPortP.attributes.ownerTag }},{{ profile.infraSpAccPortP.attributes.status }},{{ profile.infraSpAccPortP.attributes.uid }},{{ profile.infraSpAccPortP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraNodeP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraNodeP.attributes.name }},{{ profile.infraNodeP.attributes.nameAlias }},{{ profile.infraNodeP.attributes.annotation }},{{ profile.infraNodeP.attributes.childAction }},{{ profile.infraNodeP.attributes.descr | replace(","," ") }},{{ profile.infraNodeP.attributes.dn }},{{ profile.infraNodeP.attributes.extMngdBy }},{{ profile.infraNodeP.attributes.lcOwn }},{{ profile.infraNodeP.attributes.modTs }},{{ profile.infraNodeP.attributes.monPolDn }},{{ profile.infraNodeP.attributes.ownerKey }},{{ profile.infraNodeP.attributes.ownerTag }},{{ profile.infraNodeP.attributes.status }},{{ profile.infraNodeP.attributes.uid }},{{ profile.infraNodeP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraSpineP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraSpineP.attributes.name }},{{ profile.infraSpineP.attributes.nameAlias }},{{ profile.infraSpineP.attributes.annotation }},{{ profile.infraSpineP.attributes.childAction }},{{ profile.infraSpineP.attributes.descr | replace(","," ") }},{{ profile.infraSpineP.attributes.dn }},{{ profile.infraSpineP.attributes.extMngdBy }},{{ profile.infraSpineP.attributes.lcOwn }},{{ profile.infraSpineP.attributes.modTs }},{{ profile.infraSpineP.attributes.monPolDn }},{{ profile.infraSpineP.attributes.ownerKey }},{{ profile.infraSpineP.attributes.ownerTag }},{{ profile.infraSpineP.attributes.status }},{{ profile.infraSpineP.attributes.uid }},{{ profile.infraSpineP.attributes.userdom }}
{%-     endfor %}
{%- elif "fvnsVlanInstP" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for pool in data_to_template['imdata'] %}
{{ pool.fvnsVlanInstP.attributes.name }},{{ pool.fvnsVlanInstP.attributes.nameAlias }},{{ pool.fvnsVlanInstP.attributes.allocMode }},{{ pool.fvnsVlanInstP.attributes.annotation }},{{ pool.fvnsVlanInstP.attributes.childAction }},{{ pool.fvnsVlanInstP.attributes.configIssues }},{{ pool.fvnsVlanInstP.attributes.descr | replace(","," ") }},{{ pool.fvnsVlanInstP.attributes.dn }},{{ pool.fvnsVlanInstP.attributes.extMngdBy }},{{ pool.fvnsVlanInstP.attributes.lcOwn }},{{ pool.fvnsVlanInstP.attributes.modTs }},{{ pool.fvnsVlanInstP.attributes.monPolDn }},{{ pool.fvnsVlanInstP.attributes.ownerKey }},{{ pool.fvnsVlanInstP.attributes.ownerTag }},{{ pool.fvnsVlanInstP.attributes.status }},{{ pool.fvnsVlanInstP.attributes.uid }},{{ pool.fvnsVlanInstP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraAttEntityP" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraAttEntityP.attributes.name }},{{ profile.infraAttEntityP.attributes.nameAlias }},{{ profile.infraAttEntityP.attributes.allocMode }},{{ profile.infraAttEntityP.attributes.annotation }},{{ profile.infraAttEntityP.attributes.childAction }},{{ profile.infraAttEntityP.attributes.configIssues }},{{ profile.infraAttEntityP.attributes.descr | replace(","," ") }},{{ profile.infraAttEntityP.attributes.dn }},{{ profile.infraAttEntityP.attributes.extMngdBy }},{{ profile.infraAttEntityP.attributes.lcOwn }},{{ profile.infraAttEntityP.attributes.modTs }},{{ profile.infraAttEntityP.attributes.monPolDn }},{{ profile.infraAttEntityP.attributes.ownerKey }},{{ profile.infraAttEntityP.attributes.ownerTag }},{{ profile.infraAttEntityP.attributes.status }},{{ profile.infraAttEntityP.attributes.uid }},{{ profile.infraAttEntityP.attributes.userdom }}
{%-     endfor %}
{%- elif "vzBrCP" in api %}Name,Name Alias,Access Privilege,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Intent,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Priority,Re Evaluate All,Scope,Status,Target DSCP,UID,User Domain
{%-     for contract in data_to_template['imdata'] %}
{{ contract.vzBrCP.attributes.name }},{{ contract.vzBrCP.attributes.nameAlias }},{{ contract.vzBrCP.attributes.accessPrivilege }},{{ contract.vzBrCP.attributes.annotation }},{{ contract.vzBrCP.attributes.childAction }},{{ contract.vzBrCP.attributes.configIssues }},{{ contract.vzBrCP.attributes.descr | replace(","," ") }},{{ contract.vzBrCP.attributes.dn }},{{ contract.vzBrCP.attributes.extMngdBy }},{{ contract.vzBrCP.attributes.intent }},{{ contract.vzBrCP.attributes.lcOwn }},{{ contract.vzBrCP.attributes.modTs }},{{ contract.vzBrCP.attributes.monPolDn }},{{ contract.vzBrCP.attributes.ownerKey }},{{ contract.vzBrCP.attributes.ownerTag }},{{ contract.vzBrCP.attributes.prio }},{{ contract.vzBrCP.attributes.reevaluateAll }},{{ contract.vzBrCP.attributes.scope }},{{ contract.vzBrCP.attributes.status }},{{ contract.vzBrCP.attributes.targetDscp }},{{ contract.vzBrCP.attributes.uid }},{{ contract.vzBrCP.attributes.userdom }}
{%-     endfor %}
{%- elif "vzEntry" in api %}Name,Name Alias,Access Privilege,Annotation,Apply To Fragments,ARP Opc,Child Action,Destination From Port,Destination To Port,Description,DN,EtherType,Externally Managed By,ICMPv4 T,ICMPv6 T,Local Owner,Match DSCP,Last Modified,Monitoring Policy DN,Protocol,Source From Port,Source To Port,Stateful,Status,TCP Rules,UID,User Domain
{%-     for entry in data_to_template['imdata'] %}
{{ entry.vzEntry.attributes.name }},{{ entry.vzEntry.attributes.nameAlias }},{{ entry.vzEntry.attributes.accessPrivilege }},{{ entry.vzEntry.attributes.annotation }},{{ entry.vzEntry.attributes.applyToFrag }},{{ entry.vzEntry.attributes.arpOpc }},{{ entry.vzEntry.attributes.childAction }},{{ entry.vzEntry.attributes.dFromPort }},{{ entry.vzEntry.attributes.dToPort }},{{ entry.vzEntry.attributes.descr | replace(","," ") }},{{ entry.vzEntry.attributes.dn }},{{ entry.vzEntry.attributes.etherT }},{{ entry.vzEntry.attributes.extMngdBy }},{{ entry.vzEntry.attributes.icmpv4T }},{{ entry.vzEntry.attributes.icmpv6T }},{{ entry.vzEntry.attributes.lcOwn }},{{ entry.vzEntry.attributes.matchDscp }},{{ entry.vzEntry.attributes.modTs }},{{ entry.vzEntry.attributes.monPolDn }},{{ entry.vzEntry.attributes.prot }},{{ entry.vzEntry.attributes.sFromPort }},{{ entry.vzEntry.attributes.sToPort }},{{ entry.vzEntry.attributes.stateful }},{{ entry.vzEntry.attributes.status }},{{ entry.vzEntry.attributes.tcpRules }},{{ entry.vzEntry.attributes.uid }},{{ entry.vzEntry.attributes.userdom }}
{%-     endfor %}
{%- elif "physDomP" in api %}Name,Name Alias,Annotation,Child Action,Configuration Issues,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for domain in data_to_template['imdata'] %}
{{ domain.physDomP.attributes.name }},{{ domain.physDomP.attributes.nameAlias }},{{ domain.physDomP.attributes.annotation }},{{ domain.physDomP.attributes.childAction }},{{ domain.physDomP.attributes.configIssues }},{{ domain.physDomP.attributes.dn }},{{ domain.physDomP.attributes.extMngdBy }},{{ domain.physDomP.attributes.lcOwn }},{{ domain.physDomP.attributes.modTs }},{{ domain.physDomP.attributes.monPolDn }},{{ domain.physDomP.attributes.ownerKey }},{{ domain.physDomP.attributes.ownerTag }},{{ domain.physDomP.attributes.status }},{{ domain.physDomP.attributes.uid }},{{ domain.physDomP.attributes.userdom }}
{%-     endfor %}
{%- elif "l3extDomP" in api %}Name,Name Alias,Annotation,Child Action,Configuration Issues,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for domain in data_to_template['imdata'] %}
{{ domain.l3extDomP.attributes.name }},{{ domain.l3extDomP.attributes.nameAlias }},{{ domain.l3extDomP.attributes.annotation }},{{ domain.l3extDomP.attributes.childAction }},{{ domain.l3extDomP.attributes.configIssues }},{{ domain.l3extDomP.attributes.dn }},{{ domain.l3extDomP.attributes.extMngdBy }},{{ domain.l3extDomP.attributes.lcOwn }},{{ domain.l3extDomP.attributes.modTs }},{{ domain.l3extDomP.attributes.monPolDn }},{{ domain.l3extDomP.attributes.ownerKey }},{{ domain.l3extDomP.attributes.ownerTag }},{{ domain.l3extDomP.attributes.status }},{{ domain.l3extDomP.attributes.uid }},{{ domain.l3extDomP.attributes.userdom }}
{%-     endfor %}
{%- elif "qosClass" in api %}Name,Name Alias,Admin,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,MTU,Owner Key,Owner Tag,Priority,Status,UID,User Domain
{%-     for class in data_to_template['imdata'] %}
{{ class.qosClass.attributes.name }},{{ class.qosClass.attributes.nameAlias }},{{ class.qosClass.attributes.admin }},{{ class.qosClass.attributes.annotation }},{{ class.qosClass.attributes.childAction }},{{ class.qosClass.attributes.descr | replace(","," ") }},{{ class.qosClass.attributes.dn }},{{ class.qosClass.attributes.extMngdBy }},{{ class.qosClass.attributes.lcOwn }},{{ class.qosClass.attributes.modTs }},{{ class.qosClass.attributes.mtu }},{{ class.qosClass.attributes.ownerKey }},{{ class.qosClass.attributes.ownerTag }},{{ class.qosClass.attributes.prio }},{{ class.qosClass.attributes.status }},{{ class.qosClass.attributes.uid }},{{ class.qosClass.attributes.userdom }}
{%-     endfor %}
{%- elif "faultSummary" in api %}Cause,Child Action,Code,Count,Description,DN,Domain,Non Acknowledged,Non Delegated,Non Delegated And Non Acknowledged,Rule,Severity,Status,Subject,Type
{%-     for fault in data_to_template['imdata'] %}
{{ fault.faultSummary.attributes.cause }},{{ fault.faultSummary.attributes.childAction }},{{ fault.faultSummary.attributes.code }},{{ fault.faultSummary.attributes.count }},{{ fault.faultSummary.attributes.descr | replace(","," ") | replace(","," ")}},{{ fault.faultSummary.attributes.dn }},{{ fault.faultSummary.attributes.domain }},{{ fault.faultSummary.attributes.nonAcked }},{{ fault.faultSummary.attributes.nonDelegated }},{{ fault.faultSummary.attributes.nonDelegatedAndNonAcked }},{{ fault.faultSummary.attributes.rule }},{{ fault.faultSummary.attributes.severity }},{{ fault.faultSummary.attributes.status }},{{ fault.faultSummary.attributes.subject }},{{ fault.faultSummary.attributes.type }}
{%-     endfor %}
{%- elif "aaaModLR" in api %}ID,Affected,Cause,Change Set,Child Action,Client Tag,Code,Created,Description,DN,IND,Last Modified,Session ID,Severity,Status,Trigger,TX ID,User
{%-     for log in data_to_template['imdata'] %}
{{ log.aaaModLR.attributes.id }},{{ log.aaaModLR.attributes.affected }},{{ log.aaaModLR.attributes.cause }},{{ log.aaaModLR.attributes.changeSet | replace(","," ")}},{{ log.aaaModLR.attributes.childAction }},{{ log.aaaModLR.attributes.clientTag }},{{ log.aaaModLR.attributes.code }},{{ log.aaaModLR.attributes.created }},{{ log.aaaModLR.attributes.descr | replace(","," ") }},{{ log.aaaModLR.attributes.dn }},{{ log.aaaModLR.attributes.ind }},{{ log.aaaModLR.attributes.modTs }},{{ log.aaaModLR.attributes.sessionId }},{{ log.aaaModLR.attributes.severity }},{{ log.aaaModLR.attributes.status }},{{ log.aaaModLR.attributes.trig }},{{ log.aaaModLR.attributes.txId }},{{ log.aaaModLR.attributes.user }}
{%-     endfor %}
{%- elif "fvIp" in api %}IP Address,Annotation,Base EPG DN,Bridge Domain DN,Child Action,Created,Debug MAC Message,ESG Use gDN,Externally Managed By,Fabric Path DN,Flags,Local Owner,Last Modified,Monitoring Policy DN,DN,Status,UID,User Domain,VRF DN
{%-     for ip in data_to_template['imdata'] %}
{{ ip.fvIp.attributes.addr }},{{ ip.fvIp.attributes.annotation }},{{ ip.fvIp.attributes.baseEpgDn }},{{ ip.fvIp.attributes.bdDn }},{{ ip.fvIp.attributes.childAction }},{{ ip.fvIp.attributes.createTs }},{{ ip.fvIp.attributes.debugMACMessage }},{{ ip.fvIp.attributes.esgUsegDn }},{{ ip.fvIp.attributes.extMngdBy }},{{ ip.fvIp.attributes.fabricPathDn }},{{ ip.fvIp.attributes.flags | replace(","," ")}},{{ ip.fvIp.attributes.lcOwn }},{{ ip.fvIp.attributes.modTs }},{{ ip.fvIp.attributes.monPolDn }},{{ ip.fvIp.attributes.dn }},{{ ip.fvIp.attributes.status }},{{ ip.fvIp.attributes.uid }},{{ ip.fvIp.attributes.userdom }},{{ ip.fvIp.attributes.vrfDn }}
{%-     endfor %}
{%- elif "eventRecord" in api %}ID,Affected,Cause,Change Set,Child Action,Code,Created,Description,DN,IND,Last Modified,Severity,Status,Trigger,TX ID,User
{%-     for event in data_to_template['imdata'] %}
{{ event.eventRecord.attributes.id }},{{ event.eventRecord.attributes.affected }},{{ event.eventRecord.attributes.cause }},{{ event.eventRecord.attributes.changeSet | replace(','," ") }},{{ event.eventRecord.attributes.childAction }},{{ event.eventRecord.attributes.code }},{{ event.eventRecord.attributes.created }},{{ event.eventRecord.attributes.descr | replace(","," ")}},{{ event.eventRecord.attributes.dn }},{{ event.eventRecord.attributes.ind }},{{ event.eventRecord.attributes.modTs }},{{ event.eventRecord.attributes.severity }},{{ event.eventRecord.attributes.status }},{{ event.eventRecord.attributes.trig | replace(","," ")}},{{ event.eventRecord.attributes.txId }},{{ event.eventRecord.attributes.user }}
{%-     endfor %}
{%- elif "licenseEntitlement" in api %}Name,Auth Status,Child Action,Count,Description,DN,Local Owner,Last Modified,Status,Tag,Version
{%-     for license in data_to_template['imdata'] %}
{{ license.licenseEntitlement.attributes.name }},{{ license.licenseEntitlement.attributes.authStatus }},{{ license.licenseEntitlement.attributes.childAction }},{{ license.licenseEntitlement.attributes.count }},{{ license.licenseEntitlement.attributes.descr | replace(","," ")}},{{ license.licenseEntitlement.attributes.dn }},{{ license.licenseEntitlement.attributes.lcOwn }},{{ license.licenseEntitlement.attributes.modTs }},{{ license.licenseEntitlement.attributes.status }},{{ license.licenseEntitlement.attributes.tag | replace(","," ")}},{{ license.licenseEntitlement.attributes.version }}
{%-     endfor %}
{%- elif "bgpRRNodePEp" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,ID,Local Owner,Last Modified,Monitoring Policy DN,POD ID,Status,UID,User Domain
{%-     for rr in data_to_template['imdata'] %}
{{ rr.bgpRRNodePEp.attributes.name }},{{ rr.bgpRRNodePEp.attributes.nameAlias }},{{ rr.bgpRRNodePEp.attributes.annotation }},{{ rr.bgpRRNodePEp.attributes.childAction }},{{ rr.bgpRRNodePEp.attributes.descr | replace(","," ")}},{{ rr.bgpRRNodePEp.attributes.dn }},{{ rr.bgpRRNodePEp.attributes.extMngdBy }},{{ rr.bgpRRNodePEp.attributes.id }},{{ rr.bgpRRNodePEp.attributes.lcOwn }},{{ rr.bgpRRNodePEp.attributes.modTs }},{{ rr.bgpRRNodePEp.attributes.monPolDn }},{{ rr.bgpRRNodePEp.attributes.podId }},{{ rr.bgpRRNodePEp.attributes.status }},{{ rr.bgpRRNodePEp.attributes.uid }},{{ rr.bgpRRNodePEp.attributes.userdom }}
{%-     endfor %}
{%- elif "infraPortS" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Type,UID,User Domain
{%-     for policy in data_to_template['imdata'] %}
{%-         if "infraSHPortS" in policy %}
{{ policy.infraSHPortS.attributes.name }},{{ policy.infraSHPortS.attributes.nameAlias }},{{ policy.infraSHPortS.attributes.annotation }},{{ policy.infraSHPortS.attributes.childAction }},{{ policy.infraSHPortS.attributes.descr | replace(","," ")}},{{ policy.infraSHPortS.attributes.dn }},{{ policy.infraSHPortS.attributes.extMngdBy }},{{ policy.infraSHPortS.attributes.lcOwn }},{{ policy.infraSHPortS.attributes.modTs }},{{ policy.infraSHPortS.attributes.monPolDn }},{{ policy.infraSHPortS.attributes.ownerKey }},{{ policy.infraSHPortS.attributes.ownerTag }},{{ policy.infraSHPortS.attributes.status }},{{ policy.infraSHPortS.attributes.type }},{{ policy.infraSHPortS.attributes.uid }}
{%-         else %}
{{ policy.infraHPortS.attributes.name }},{{ policy.infraHPortS.attributes.nameAlias }},{{ policy.infraHPortS.attributes.annotation }},{{ policy.infraHPortS.attributes.childAction }},{{ policy.infraHPortS.attributes.descr | replace(","," ")}},{{ policy.infraHPortS.attributes.dn }},{{ policy.infraHPortS.attributes.extMngdBy }},{{ policy.infraHPortS.attributes.lcOwn }},{{ policy.infraHPortS.attributes.modTs }},{{ policy.infraHPortS.attributes.monPolDn }},{{ policy.infraHPortS.attributes.ownerKey }},{{ policy.infraHPortS.attributes.ownerTag }},{{ policy.infraHPortS.attributes.status }},{{ policy.infraHPortS.attributes.type }},{{ policy.infraHPortS.attributes.uid }},{{ policy.infraHPortS.attributes.userdom }}, N/A
{%-         endif %}
{%-     endfor %}
{%- elif "infraProfile" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Type,UID,User Domain
{%-     for policy in data_to_template['imdata'] %}
{%-         if policy.infraAccPortP %}
{{ policy.infraAccPortP.attributes.name }},{{ policy.infraAccPortP.attributes.nameAlias }},{{ policy.infraAccPortP.attributes.annotation }},{{ policy.infraAccPortP.attributes.childAction }},{{ policy.infraAccPortP.attributes.descr | replace(","," ")}},{{ policy.infraAccPortP.attributes.dn }},{{ policy.infraAccPortP.attributes.extMngdBy }},{{ policy.infraAccPortP.attributes.lcOwn }},{{ policy.infraAccPortP.attributes.modTs }},{{ policy.infraAccPortP.attributes.monPolDn }},{{ policy.infraAccPortP.attributes.ownerKey }},{{ policy.infraAccPortP.attributes.ownerTag }},{{ policy.infraAccPortP.attributes.status }},{{ policy.infraAccPortP.attributes.type }},{{ policy.infraAccPortP.attributes.uid }},{{ policy.infraAccPortP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraAttEntityP %}
{{ policy.infraAttEntityP.attributes.name }},{{ policy.infraAttEntityP.attributes.nameAlias }},{{ policy.infraAttEntityP.attributes.annotation }},{{ policy.infraAttEntityP.attributes.childAction }},{{ policy.infraAttEntityP.attributes.descr | replace(","," ")}},{{ policy.infraAttEntityP.attributes.dn }},{{ policy.infraAttEntityP.attributes.extMngdBy }},{{ policy.infraAttEntityP.attributes.lcOwn }},{{ policy.infraAttEntityP.attributes.modTs }},{{ policy.infraAttEntityP.attributes.monPolDn }},{{ policy.infraAttEntityP.attributes.ownerKey }},{{ policy.infraAttEntityP.attributes.ownerTag }},{{ policy.infraAttEntityP.attributes.status }},{{ policy.infraAttEntityP.attributes.type }},{{ policy.infraAttEntityP.attributes.uid }},{{ policy.infraAttEntityP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraFexP %}
{{ policy.infraFexP.attributes.name }},{{ policy.infraFexP.attributes.nameAlias }},{{ policy.infraFexP.attributes.annotation }},{{ policy.infraFexP.attributes.childAction }},{{ policy.infraFexP.attributes.descr | replace(","," ")}},{{ policy.infraFexP.attributes.dn }},{{ policy.infraFexP.attributes.extMngdBy }},{{ policy.infraFexP.attributes.lcOwn }},{{ policy.infraFexP.attributes.modTs }},{{ policy.infraFexP.attributes.monPolDn }},{{ policy.infraFexP.attributes.ownerKey }},{{ policy.infraFexP.attributes.ownerTag }},{{ policy.infraFexP.attributes.status }},{{ policy.infraFexP.attributes.type }},{{ policy.infraFexP.attributes.uid }},{{ policy.infraFexP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraFuncP %}
{{ policy.infraFuncP.attributes.name }},{{ policy.infraFuncP.attributes.nameAlias }},{{ policy.infraFuncP.attributes.annotation }},{{ policy.infraFuncP.attributes.childAction }},{{ policy.infraFuncP.attributes.descr | replace(","," ")}},{{ policy.infraFuncP.attributes.dn }},{{ policy.infraFuncP.attributes.extMngdBy }},{{ policy.infraFuncP.attributes.lcOwn }},{{ policy.infraFuncP.attributes.modTs }},{{ policy.infraFuncP.attributes.monPolDn }},{{ policy.infraFuncP.attributes.ownerKey }},{{ policy.infraFuncP.attributes.ownerTag }},{{ policy.infraFuncP.attributes.status }},{{ policy.infraFuncP.attributes.type }},{{ policy.infraFuncP.attributes.uid }},{{ policy.infraFuncP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraNodeP %}
{{ policy.infraNodeP.attributes.name }},{{ policy.infraNodeP.attributes.nameAlias }},{{ policy.infraNodeP.attributes.annotation }},{{ policy.infraNodeP.attributes.childAction }},{{ policy.infraNodeP.attributes.descr | replace(","," ")}},{{ policy.infraNodeP.attributes.dn }},{{ policy.infraNodeP.attributes.extMngdBy }},{{ policy.infraNodeP.attributes.lcOwn }},{{ policy.infraNodeP.attributes.modTs }},{{ policy.infraNodeP.attributes.monPolDn }},{{ policy.infraNodeP.attributes.ownerKey }},{{ policy.infraNodeP.attributes.ownerTag }},{{ policy.infraNodeP.attributes.status }},{{ policy.infraNodeP.attributes.type }},{{ policy.infraNodeP.attributes.uid }},{{ policy.infraNodeP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraPodP %}
{{ policy.infraPodP.attributes.name }},{{ policy.infraPodP.attributes.nameAlias }},{{ policy.infraPodP.attributes.annotation }},{{ policy.infraPodP.attributes.childAction }},{{ policy.infraPodP.attributes.descr | replace(","," ")}},{{ policy.infraPodP.attributes.dn }},{{ policy.infraPodP.attributes.extMngdBy }},{{ policy.infraPodP.attributes.lcOwn }},{{ policy.infraPodP.attributes.modTs }},{{ policy.infraPodP.attributes.monPolDn }},{{ policy.infraPodP.attributes.ownerKey }},{{ policy.infraPodP.attributes.ownerTag }},{{ policy.infraPodP.attributes.status }},{{ policy.infraPodP.attributes.type }},{{ policy.infraPodP.attributes.uid }},{{ policy.infraPodP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraSpAccPortP %}
{{ policy.infraSpAccPortP.attributes.name }},{{ policy.infraSpAccPortP.attributes.nameAlias }},{{ policy.infraSpAccPortP.attributes.annotation }},{{ policy.infraSpAccPortP.attributes.childAction }},{{ policy.infraSpAccPortP.attributes.descr | replace(","," ")}},{{ policy.infraSpAccPortP.attributes.dn }},{{ policy.infraSpAccPortP.attributes.extMngdBy }},{{ policy.infraSpAccPortP.attributes.lcOwn }},{{ policy.infraSpAccPortP.attributes.modTs }},{{ policy.infraSpAccPortP.attributes.monPolDn }},{{ policy.infraSpAccPortP.attributes.ownerKey }},{{ policy.infraSpAccPortP.attributes.ownerTag }},{{ policy.infraSpAccPortP.attributes.status }},{{ policy.infraSpAccPortP.attributes.type }},{{ policy.infraSpAccPortP.attributes.uid }},{{ policy.infraSpAccPortP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraSpineP %}
{{ policy.infraSpineP.attributes.name }},{{ policy.infraSpineP.attributes.nameAlias }},{{ policy.infraSpineP.attributes.annotation }},{{ policy.infraSpineP.attributes.childAction }},{{ policy.infraSpineP.attributes.descr | replace(","," ")}},{{ policy.infraSpineP.attributes.dn }},{{ policy.infraSpineP.attributes.extMngdBy }},{{ policy.infraSpineP.attributes.lcOwn }},{{ policy.infraSpineP.attributes.modTs }},{{ policy.infraSpineP.attributes.monPolDn }},{{ policy.infraSpineP.attributes.ownerKey }},{{ policy.infraSpineP.attributes.ownerTag }},{{ policy.infraSpineP.attributes.status }},{{ policy.infraSpineP.attributes.type }},{{ policy.infraSpineP.attributes.uid }},{{ policy.infraSpineP.attributes.userdom }}
{%-         endif %}
{%-     endfor %}
{%- elif "fabricPod" in api %}ID,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Pod Type,Status
{%-     for pod in data_to_template['imdata'] %}
{{ pod.fabricPod.attributes.id }},{{ pod.fabricPod.attributes.childAction }},{{ pod.fabricPod.attributes.dn }},{{ pod.fabricPod.attributes.lcOwn }},{{ pod.fabricPod.attributes.modTs }},{{ pod.fabricPod.attributes.monPolDn }},{{ pod.fabricPod.attributes.podType }},{{ pod.fabricPod.attributes.status }}
{%-     endfor %}
{%- elif "fabricPath" in api %}
{%-     if "Ep" in api %}
{%-         if "Cont" in api %}Node ID,DN,Child Action,Local Owner,Last Modified,Monitoring Policy DN,Status
{%-             for container in data_to_template['imdata'] %}
{{ container.fabricPathEpCont.attributes.nodeId }},{{ container.fabricPathEpCont.attributes.dn }},{{ container.fabricPathEpCont.attributes.childAction }},{{ container.fabricPathEpCont.attributes.lcOwn }},{{ container.fabricPathEpCont.attributes.modTs }},{{ container.fabricPathEpCont.attributes.monPolDn }},{{ container.fabricPathEpCont.attributes.status }}
{%-             endfor %}
{%-         else %}Name,Child Action,Description,DN,Lag Type,Local Owner,Last Modified,Monitoring Policy DN,Path Type,Status
{%-             for endpoint in data_to_template['imdata'] %}
{{ endpoint.fabricPathEp.attributes.name }},{{ endpoint.fabricPathEp.attributes.childAction }},{{ endpoint.fabricPathEp.attributes.descr }},{{ endpoint.fabricPathEp.attributes.dn }},{{ endpoint.fabricPathEp.attributes.lagT }},{{ endpoint.fabricPathEp.attributes.lcOwn }},{{ endpoint.fabricPathEp.attributes.modTs }},{{ endpoint.fabricPathEp.attributes.monPolDn }},{{ endpoint.fabricPathEp.attributes.pathT }},{{ endpoint.fabricPathEp.attributes.status }}
{%-             endfor %}
{%-         endif %}
{%-     else %}Node 1,Node 2,Child Action,DN,Local Owner,Last Updated,Monitoring Policy DN,Status
{%-         for path in data_to_template['imdata'] %}
{{ path.fabricPath.attributes.n1 }},{{ path.fabricPath.attributes.n2 }},{{ path.fabricPath.attributes.childAction }},{{ path.fabricPath.attributes.dn }},{{ path.fabricPath.attributes.lcOwn }},{{ path.fabricPath.attributes.modTs }},{{ path.fabricPath.attributes.monPolDn }},{{ path.fabricPath.attributes.status }}
{%-         endfor %}
{%-     endif %}
{%- elif "rtctrlSubjP" in api %}Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Name,Name Alias,Status,UID,User Domain
{%-     for outer_list in data_to_template %}
{%-         for prefix_list in outer_list %}
{{ prefix_list.rtctrlSubjP.attributes.annotation }},{{ prefix_list.rtctrlSubjP.attributes.childAction }},{{ prefix_list.rtctrlSubjP.attributes.description }},{{ prefix_list.rtctrlSubjP.attributes.dn }},{{ prefix_list.rtctrlSubjP.attributes.extMngdBy }},{{ prefix_list.rtctrlSubjP.attributes.lcOwn }},{{ prefix_list.rtctrlSubjP.attributes.modTs }},{{ prefix_list.rtctrlSubjP.attributes.name }},{{ prefix_list.rtctrlSubjP.attributes.nameAlias }},{{ prefix_list.rtctrlSubjP.attributes.status }},{{ prefix_list.rtctrlSubjP.attributes.uid }},{{ prefix_list.rtctrlSubjP.attributes.userdom }}
{%-         endfor %}
{%-     endfor %}
{%- elif "rtctrlMatchRtDest" in api %}Aggregate,Annotation,Child Action,Description,DN,Externally Managed By,fromPfxLen,IP,Local Owner,Last Modified,Name,Name Alias,Status,toPfxLen,Type,UID,User Domain
{%-     for outer_list in data_to_template %}
{%-         for prefix_list_detailed in outer_list %}
{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.aggregate }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.annotation }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.childAction }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.descr }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.dn }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.extMngdBy }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.fromPfxLen }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.ip }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.lcOwn }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.modTs }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.name }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.nameAlias }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.status }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.toPfxLen }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.type }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.uid }},{{ prefix_list_detailed.rtctrlMatchRtDest.attributes.userdom }}
{%-         endfor %}
{%-     endfor %}
{%- elif "Tenant" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,Owner Key,Owner Tag,User Domain,Modified Timestamp
{%-     for tenant in data_to_template['imdata'] %}
{{ tenant.fvTenant.attributes.name }},{{ tenant.fvTenant.attributes.nameAlias }},{{ tenant.fvTenant.attributes.descr | replace(","," ") }},{{ tenant.fvTenant.attributes.status }},{{ tenant.fvTenant.attributes.dn }},{{ tenant.fvTenant.attributes.uid }},{{ tenant.fvTenant.attributes.annotation }},{{ tenant.fvTenant.attributes.childAction }},{{ tenant.fvTenant.attributes.extMngdBy }},{{ tenant.fvTenant.attributes.lcOwn }},{{ tenant.fvTenant.attributes.monPolDn }},{{ tenant.fvTenant.attributes.ownerKey }},{{ tenant.fvTenant.attributes.ownerTag }},{{ tenant.fvTenant.attributes.userdom }},{{ tenant.fvTenant.attributes.modTs }}
{%-     endfor %}
{%- elif "aaaUser" in api %}Name,Name Alias,Account Status,Annotation,Cert Attribute,Child Action,Clear Password History,Description,DN,Email,Expiration,Expires,Externally Managed By,First Name,Last Name,Local Owner,Last Modified,Monitoring Policy DN,OTP Enable,OTP Enforced,OTP Key,Owner Key,Owner Tag,Phone,Password Life Time,Password Update Required,RBAC String,Restricted RBAC User,Status,UID,UNIX User ID,User Domain
{%-     for user in data_to_template['imdata'] %}
{{ user.aaaUser.attributes.name }},{{ user.aaaUser.attributes.nameAlias }},{{ user.aaaUser.attributes.accountStatus }},{{ user.aaaUser.attributes.annotation }},{{ user.aaaUser.attributes.certAttribute }},{{ user.aaaUser.attributes.childAction }},{{ user.aaaUser.attributes.clearPwdHistory }},{{ user.aaaUser.attributes.descr }},{{ user.aaaUser.attributes.dn }},{{ user.aaaUser.attributes.email }},{{ user.aaaUser.attributes.expiration }},{{ user.aaaUser.attributes.expires }},{{ user.aaaUser.attributes.extMngdBy }},{{ user.aaaUser.attributes.firstName }},{{ user.aaaUser.attributes.lastName }},{{ user.aaaUser.attributes.lcOwn }},{{ user.aaaUser.attributes.modTs }},{{ user.aaaUser.attributes.monPolDn }},{{ user.aaaUser.attributes.otpenable }},{{ user.aaaUser.attributes.otpenf }},{{ user.aaaUser.attributes.otpkey }},{{ user.aaaUser.attributes.ownerKey }},{{ user.aaaUser.attributes.ownerTag }},{{ user.aaaUser.attributes.phone }},{{ user.aaaUser.attributes.pwdLifeTime }},{{ user.aaaUser.attributes.pwdUpdateRequired }},{{ user.aaaUser.attributes.rbacString }},{{ user.aaaUser.attributes.restrictedRbacUser }},{{ user.aaaUser.attributes.status }},{{ user.aaaUser.attributes.uid }},{{ user.aaaUser.attributes.unixUserId }},{{ user.aaaUser.attributes.userdom }}
{%-     endfor %}
{%- elif "aaaDomain" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Owner Key,Owner Tag,Restricted RBAC Domain,Status,UID,User Domain
{%-     for domain in data_to_template['imdata'] %}
{{ domain.aaaDomain.attributes.name }},{{ domain.aaaDomain.attributes.nameAlias }},{{ domain.aaaDomain.attributes.annotation }},{{ domain.aaaDomain.attributes.childAction }},{{ domain.aaaDomain.attributes.descr }},{{ domain.aaaDomain.attributes.dn }},{{ domain.aaaDomain.attributes.extMngdBy }},{{ domain.aaaDomain.attributes.lcOwn }},{{ domain.aaaDomain.attributes.modTs }},{{ domain.aaaDomain.attributes.ownerKey }},{{ domain.aaaDomain.attributes.ownerTag }},{{ domain.aaaDomain.attributes.restrictedRbacDomain }},{{ domain.aaaDomain.attributes.status }},{{ domain.aaaDomain.attributes.uid }},{{ domain.aaaDomain.attributes.userdom }}
{%-     endfor %}
{%- elif "vzSubj" in api %}Name,Name Alias,Access Privilege,Annotation,Child Action,Configuration Issues,Consumer Match T,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Priority,Provider Match T,Reverse Filter Ports,Status,Target DSCP,UID,User Domain
{%-     for subject in data_to_template['imdata'] %}
{{ subject.vzSubj.attributes.name }},{{ subject.vzSubj.attributes.nameAlias }},{{ subject.vzSubj.attributes.accessPrivilege }},{{ subject.vzSubj.attributes.annotation }},{{ subject.vzSubj.attributes.childAction }},{{ subject.vzSubj.attributes.configIssues }},{{ subject.vzSubj.attributes.consMatchT }},{{ subject.vzSubj.attributes.descr }},{{ subject.vzSubj.attributes.dn }},{{ subject.vzSubj.attributes.extMngdBy }},{{ subject.vzSubj.attributes.lcOwn }},{{ subject.vzSubj.attributes.modTs }},{{ subject.vzSubj.attributes.monPolDn }},{{ subject.vzSubj.attributes.prio }},{{ subject.vzSubj.attributes.provMatchT }},{{ subject.vzSubj.attributes.revFltPorts }},{{ subject.vzSubj.attributes.status }},{{ subject.vzSubj.attributes.targetDscp }},{{ subject.vzSubj.attributes.uid }},{{ subject.vzSubj.attributes.userdom }}
{%-     endfor %}
{%- elif "topology/health" in api %}Change,Current,Child Action,DN,Local Owner,Maximum Severity,Last Modified,Previous,Status,TW Score,Updated
{%-     for score in data_to_template['imdata'] %}
{{ score.fabricHealthTotal.attributes.chng }},{{ score.fabricHealthTotal.attributes.cur }},{{ score.fabricHealthTotal.attributes.childAction }},{{ score.fabricHealthTotal.attributes.dn }},{{ score.fabricHealthTotal.attributes.lcOwn }},{{ score.fabricHealthTotal.attributes.maxSev }},{{ score.fabricHealthTotal.attributes.modTs }},{{ score.fabricHealthTotal.attributes.prev }},{{ score.fabricHealthTotal.attributes.status }},{{ score.fabricHealthTotal.attributes.twScore }},{{ score.fabricHealthTotal.attributes.updTs }}
{%-     endfor %}
{%- elif "pkiFabricNodeSSLCertificate" in api %}Name,Name Alias,Authority Key Identifier,Child Action,Data,Description,DN,Expired Certificate,Invalid Issuer,Invalid Signing CA For Certificate,Invalid Subject Format,Issuer,Key Size,Local Owner,Message,Last Modified,Monitoring Policy DN,Node ID,Node Type,Owner Key,Owner Tag,Public Key Algorithm,Serial Number,Signature Algorithm,Status,Subject,Subject Key Identifier,Valid Certificate,Validity Not After,Validity Not Before,Version
{%-     for cert in data_to_template['imdata'] %}
{{ cert.pkiFabricNodeSSLCertificate.attributes.name }},{{ cert.pkiFabricNodeSSLCertificate.attributes.nameAlias }},{{ cert.pkiFabricNodeSSLCertificate.attributes.authorityKeyIdentifier }},{{ cert.pkiFabricNodeSSLCertificate.attributes.childAction }},{{ cert.pkiFabricNodeSSLCertificate.attributes.data | replace("\n"," ") }},{{ cert.pkiFabricNodeSSLCertificate.attributes.descr }},{{ cert.pkiFabricNodeSSLCertificate.attributes.dn }},{{ cert.pkiFabricNodeSSLCertificate.attributes.expiredCertificate }},{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidIssuer }},{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSigningCAForCertificate }},{{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSubjectFormat }},{{ cert.pkiFabricNodeSSLCertificate.attributes.issuer }},{{ cert.pkiFabricNodeSSLCertificate.attributes.keySize }},{{ cert.pkiFabricNodeSSLCertificate.attributes.lcOwn }},{{ cert.pkiFabricNodeSSLCertificate.attributes.message }},{{ cert.pkiFabricNodeSSLCertificate.attributes.modTs }},{{ cert.pkiFabricNodeSSLCertificate.attributes.monPolDn }},{{ cert.pkiFabricNodeSSLCertificate.attributes.nodeId }},{{ cert.pkiFabricNodeSSLCertificate.attributes.nodeType }},{{ cert.pkiFabricNodeSSLCertificate.attributes.ownerKey }},{{ cert.pkiFabricNodeSSLCertificate.attributes.ownerTag }},{{ cert.pkiFabricNodeSSLCertificate.attributes.publicKeyAlgorithm }},{{ cert.pkiFabricNodeSSLCertificate.attributes.serialNumber }},{{ cert.pkiFabricNodeSSLCertificate.attributes.signatureAlgorithm }},{{ cert.pkiFabricNodeSSLCertificate.attributes.status }},{{ cert.pkiFabricNodeSSLCertificate.attributes.subject | replace(","," ")}},{{ cert.pkiFabricNodeSSLCertificate.attributes.subjectKeyIdentifier }},{{ cert.pkiFabricNodeSSLCertificate.attributes.validCertificate }},{{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotAfter }},{{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotBefore }},{{ cert.pkiFabricNodeSSLCertificate.attributes.version }}
{%-     endfor %}
{%- elif "tn-" and "health" in api %}DN,Change,Current,Previous,TW Score,Child Action,Max Severity,Last Modified,Status,Last Updated
{%-     for outer_list in data_to_template %}
{%-         for tenant in outer_list %}
{{ tenant.healthInst.attributes.dn }},{{ tenant.healthInst.attributes.chng }},{{ tenant.healthInst.attributes.cur }},{{ tenant.healthInst.attributes.prev }},{{ tenant.healthInst.attributes.twScore }},{{ tenant.healthInst.attributes.childAction }},{{ tenant.healthInst.attributes.maxSev }},{{ tenant.healthInst.attributes.modTs }},{{ tenant.healthInst.attributes.status }},{{ tenant.healthInst.attributes.updTs }}
{%-         endfor %}
{%-     endfor %}
{%- elif "firmwareCtrlrRunning" in api %}DN,Child Action,Description,Internal Label,Local Owner,Last Modified,Mode,Status,TPM In Use,Timestamp,Type,Version
{%-     for member in data_to_template['imdata'] %}
{{ member.firmwareCtrlrRunning.attributes.dn }},{{ member.firmwareCtrlrRunning.attributes.childAction }},{{ member.firmwareCtrlrRunning.attributes.descr }},{{ member.firmwareCtrlrRunning.attributes.internalLabel }},{{ member.firmwareCtrlrRunning.attributes.lcOwn }},{{ member.firmwareCtrlrRunning.attributes.modTs }},{{ member.firmwareCtrlrRunning.attributes.mode }},{{ member.firmwareCtrlrRunning.attributes.status }},{{ member.firmwareCtrlrRunning.attributes.tpmInUse }},{{ member.firmwareCtrlrRunning.attributes.ts }},{{ member.firmwareCtrlrRunning.attributes.type }},{{ member.firmwareCtrlrRunning.attributes.version }}
{%-     endfor %}
{%- elif "topSystem" in api %}
{%-     if "?" not in api %}Name,Address,Bootstrap State,Child Action,Cluster Time Diff,Configuration Issues,Control Plane MTU,Current Time,DN,Enforce Subnet Check,ETEP Address,Fabric Domain,Fabric ID,Fabric MAC,ID,Inband Mgmt Address,Inband Mgmt Address6,Inband Mgmt Address6 Mask,Inband Mgmt Address Mask,Inband Mgmt Gateway,Inband Mgmt Gateway6,Last Reboot Time,Last Reset Reason,LC Own,Modified Timestamp,Mode,Monitoring Policy DN,Name Alias,Node Type,Out of Band Mgmt Address,Out of Band Mgmt Address6,Out of Band Mgmt Address6 Mask,Out of Band Mgmt Address Mask,Out of Band Mgmt Gateway,Out of Band Mgmt Gateway6,Pod ID,Remote Network ID,Remote Node,RL Oper Pod ID,RL Routable Mode,RL Direct Mode,Role,Serial Number,Server Type,Site ID,State,Status,System Uptime,TEP Pool,Unicast XR EP Learn Disable,Version,Virtual Mode
{%-         for topSystem in data_to_template['imdata'] %}
{{ topSystem.topSystem.attributes.name }},{{ topSystem.topSystem.attributes.address }},{{ topSystem.topSystem.attributes.bootstrapState }},{{ topSystem.topSystem.attributes.childAction }},{{ topSystem.topSystem.attributes.clusterTimeDiff }},{{ topSystem.topSystem.attributes.configIssues }},{{ topSystem.topSystem.attributes.controlPlaneMTU }},{{ topSystem.topSystem.attributes.currentTime }},{{ topSystem.topSystem.attributes.dn }},{{ topSystem.topSystem.attributes.enforceSubnetCheck }},{{ topSystem.topSystem.attributes.etepAddr }},{{ topSystem.topSystem.attributes.fabricDomain }},{{ topSystem.topSystem.attributes.fabricId }},{{ topSystem.topSystem.attributes.fabricMAC }},{{ topSystem.topSystem.attributes.id }},{{ topSystem.topSystem.attributes.inbMgmtAddr }},{{ topSystem.topSystem.attributes.inbMgmtAddr }},{{ topSystem.topSystem.attributes.inbMgmtAddr6Mask }},{{ topSystem.topSystem.attributes.inbMgmtAddrMask }},{{ topSystem.topSystem.attributes.inbMgmtGateway }},{{ topSystem.topSystem.attributes.inbMgmtGateway6 }},{{ topSystem.topSystem.attributes.lastRebootTime }},{{ topSystem.topSystem.attributes.lastResetReason }},{{ topSystem.topSystem.attributes.lcOwn }},{{ topSystem.topSystem.attributes.modTs }},{{ topSystem.topSystem.attributes.mode }},{{ topSystem.topSystem.attributes.monPolDn }},{{ topSystem.topSystem.attributes.nameAlias }},{{ topSystem.topSystem.attributes.nodeType }},{{ topSystem.topSystem.attributes.oobMgmtAddr }},{{ topSystem.topSystem.attributes.oobMgmtAddr6 }},{{ topSystem.topSystem.attributes.oobMgmtAddr6Mask }},{{ topSystem.topSystem.attributes.oobMgmtAddrMask }},{{ topSystem.topSystem.attributes.oobMgmtGateway }},{{ topSystem.topSystem.attributes.oobMgmtGateway6 }},{{ topSystem.topSystem.attributes.podId }},{{ topSystem.topSystem.attributes.remoteNetworkId }},{{ topSystem.topSystem.attributes.remoteNode }},{{ topSystem.topSystem.attributes.rlOperPodId }},{{ topSystem.topSystem.attributes.rlRoutableMode }},{{ topSystem.topSystem.attributes.rldirectMode }},{{ topSystem.topSystem.attributes.role }},{{ topSystem.topSystem.attributes.serial }},{{ topSystem.topSystem.attributes.serverType }},{{ topSystem.topSystem.attributes.siteId }},{{ topSystem.topSystem.attributes.state }},{{ topSystem.topSystem.attributes.status }},{{ topSystem.topSystem.attributes.systemUpTime }},{{ topSystem.topSystem.attributes.tepPool }},{{ topSystem.topSystem.attributes.unicastXrEpLearnDisable }},{{ topSystem.topSystem.attributes.version }},{{ topSystem.topSystem.attributes.virtualMode }}
{%-         endfor %}
{%-     endif %}
{%- elif "infraWiNode" in api %}Node Name,Name,Name Alias,IP Address,Admin State,Annotation,APIC Mode,Chassis,Child Action,Control Sbst State,DN,Externally Managed By,Failover Status,Health,ID,Local Owner,Member Serial Number,Last Modified,Monitoring Policy DN,Mutn Timestamp,Operational State,Pod ID,Routable IP Address,Status,Target Member Serial Number,UID,User Domain
{%-     for node in data_to_template['imdata'] %}
{{ node.infraWiNode.attributes.nodeName }},{{ node.infraWiNode.attributes.name }},{{ node.infraWiNode.attributes.nameAlias }},{{ node.infraWiNode.attributes.addr }},{{ node.infraWiNode.attributes.adminSt }},{{ node.infraWiNode.attributes.annotation }},{{ node.infraWiNode.attributes.apicMode }},{{ node.infraWiNode.attributes.chassis }},{{ node.infraWiNode.attributes.childAction }},{{ node.infraWiNode.attributes.cntrlSbstState }},{{ node.infraWiNode.attributes.dn }},{{ node.infraWiNode.attributes.extMngdBy }},{{ node.infraWiNode.attributes.failoverStatus }},{{ node.infraWiNode.attributes.health }},{{ node.infraWiNode.attributes.id }},{{ node.infraWiNode.attributes.lcOwn }},{{ node.infraWiNode.attributes.mbSn }},{{ node.infraWiNode.attributes.modTs }},{{ node.infraWiNode.attributes.monPolDn }},{{ node.infraWiNode.attributes.mutnTs }},{{ node.infraWiNode.attributes.operSt }},{{ node.infraWiNode.attributes.podId }},{{ node.infraWiNode.attributes.routableIpAddr }},{{ node.infraWiNode.attributes.status }},{{ node.infraWiNode.attributes.targetMbSn }},{{ node.infraWiNode.attributes.uid }},{{ node.infraWiNode.attributes.userdom }}
{%-     endfor %}
{%- elif "vnsMDev" in api %}Vendor,Annotation,Audit On Busy,Child Action,DN,Externally Managed By,Function Mask,Local Owner,Managed,Last Modified,Model,Monitoring Policy DN,Status,UID,User Domain,Version
{%-     for package in data_to_template['imdata'] %}
{{ package.vnsMDev.attributes.vendor }},{{ package.vnsMDev.attributes.annotation }},{{ package.vnsMDev.attributes.auditOnBusy }},{{ package.vnsMDev.attributes.childAction }},{{ package.vnsMDev.attributes.dn }},{{ package.vnsMDev.attributes.extMngdBy }},{{ package.vnsMDev.attributes.funcMask | replace(","," ") }},{{ package.vnsMDev.attributes.lcOwn }},{{ package.vnsMDev.attributes.managed }},{{ package.vnsMDev.attributes.modTs }},{{ package.vnsMDev.attributes.model }},{{ package.vnsMDev.attributes.monPolDn }},{{ package.vnsMDev.attributes.status }},{{ package.vnsMDev.attributes.uid }},{{ package.vnsMDev.attributes.userdom }},{{ package.vnsMDev.attributes.version }}
{%-     endfor %}
{%- elif "cnwAggrIf" in api %}Name,Admin State,Auto Negotiate,Bandwidth,Child Action,Delay,Description,DN,Dot1q Ether Type,FCOT Channel Number,ID,Inherited Bandwidth,Is Reflective Relay Config Supported,Layer,Local Owner,Link Debounce,Link Log,MDIX,Medium,Last Modified,Mode,Monitoring Policy DN,MTU,Oper State,Path S Description,Port T,Priority Flow Control,Reflective Relay Enable,Router MAC,SNMP Trap State,Span Mode,Speed,Status,Switching State,Trunk Log,Usage
{%-     for interface in data_to_template['imdata'] %}
{{ interface.cnwAggrIf.attributes.name }},{{ interface.cnwAggrIf.attributes.adminSt }},{{ interface.cnwAggrIf.attributes.autoNeg }},{{ interface.cnwAggrIf.attributes.bw }},{{ interface.cnwAggrIf.attributes.childAction }},{{ interface.cnwAggrIf.attributes.delay }},{{ interface.cnwAggrIf.attributes.descr }},{{ interface.cnwAggrIf.attributes.dn }},{{ interface.cnwAggrIf.attributes.dot1qEtherType }},{{ interface.cnwAggrIf.attributes.fcotChannelNumber }},{{ interface.cnwAggrIf.attributes.id }},{{ interface.cnwAggrIf.attributes.inhBw }},{{ interface.cnwAggrIf.attributes.isReflectiveRelayCfgSupported }},{{ interface.cnwAggrIf.attributes.layer }},{{ interface.cnwAggrIf.attributes.lcOwn }},{{ interface.cnwAggrIf.attributes.linkDebounce }},{{ interface.cnwAggrIf.attributes.linkLog }},{{ interface.cnwAggrIf.attributes.mdix }},{{ interface.cnwAggrIf.attributes.medium }},{{ interface.cnwAggrIf.attributes.modTs }},{{ interface.cnwAggrIf.attributes.mode }},{{ interface.cnwAggrIf.attributes.monPolDn }},{{ interface.cnwAggrIf.attributes.mtu }},{{ interface.cnwAggrIf.attributes.operSt }},{{ interface.cnwAggrIf.attributes.pathSDescr }},{{ interface.cnwAggrIf.attributes.portT }},{{ interface.cnwAggrIf.attributes.prioFlowCtrl }},{{ interface.cnwAggrIf.attributes.reflectiveRelayEn }},{{ interface.cnwAggrIf.attributes.routerMac }},{{ interface.cnwAggrIf.attributes.snmpTrapSt }},{{ interface.cnwAggrIf.attributes.spanMode }},{{ interface.cnwAggrIf.attributes.speed }},{{ interface.cnwAggrIf.attributes.status }},{{ interface.cnwAggrIf.attributes.switchingSt }},{{ interface.cnwAggrIf.attributes.trunkLog }},{{ interface.cnwAggrIf.attributes.usage }}
{%-     endfor %}
{%- elif "l3Inst" in api %}Name,Admin State,BGP RD,BGP RD Display,Child Action,Created Timestamp,CTX PKey,DN,Domain ID,Encapsulation,GSDB CTX,ID,L3 VM Config Failed Bmp,L3 VM Config Failed Timestamp,L3 VM Config State,Last Changed Timestamp,Local Owner,Last Modified,Monitoring Policy DN,MPLS VPN Label Index,Old Oper State Quality,Oper State Quality,Oper State,Oui,Pending,Port CL Bmp,Resource ID,Scope,Status,v4 Tib ID,v4 Tib Name,v4 Tib Old Oper State Quality,v4 Tib Oper State Quality,v4 Tib Oper State,v4 Tib Pending,v4 Tib Valid,v6 Tib ID,v6 Tib Name,v6 Tib Old Oper State Quality,v6 Tib Oper State Quality,v6 Tib Oper State,v6 Tib Pending,v6 Tib Valid,VPN ID
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l3Inst.attributes.name }},{{ interface.l3Inst.attributes.adminState }},{{ interface.l3Inst.attributes.bgpRd | replace(","," ") }},{{ interface.l3Inst.attributes.bgpRdDisp }},{{ interface.l3Inst.attributes.childAction }},{{ interface.l3Inst.attributes.createTs }},{{ interface.l3Inst.attributes.ctxPKey }},{{ interface.l3Inst.attributes.dn }},{{ interface.l3Inst.attributes.domainId }},{{ interface.l3Inst.attributes.encap }},{{ interface.l3Inst.attributes.gsdbCtx }},{{ interface.l3Inst.attributes.id }},{{ interface.l3Inst.attributes.l3vmCfgFailedBmp }},{{ interface.l3Inst.attributes.l3vmCfgFailedTs }},{{ interface.l3Inst.attributes.l3vmCfgState }},{{ interface.l3Inst.attributes.lastChgdTs }},{{ interface.l3Inst.attributes.lcOwn }},{{ interface.l3Inst.attributes.modTs }},{{ interface.l3Inst.attributes.monPolDn }},{{ interface.l3Inst.attributes.mplsVPNLabelIndex }},{{ interface.l3Inst.attributes.oldOperStQual }},{{ interface.l3Inst.attributes.operStQual }},{{ interface.l3Inst.attributes.operState }},{{ interface.l3Inst.attributes.oui }},{{ interface.l3Inst.attributes.pending }},{{ interface.l3Inst.attributes.prtclBmp }},{{ interface.l3Inst.attributes.resourceId }},{{ interface.l3Inst.attributes.scope }},{{ interface.l3Inst.attributes.status }},{{ interface.l3Inst.attributes.v4TibId }},{{ interface.l3Inst.attributes.v4TibName }},{{ interface.l3Inst.attributes.v4TibOldOperStQual }},{{ interface.l3Inst.attributes.v4TibOperStQual }},{{ interface.l3Inst.attributes.v4TibOperState }},{{ interface.l3Inst.attributes.v4TibPending }},{{ interface.l3Inst.attributes.v4TibValid }},{{ interface.l3Inst.attributes.v6TibId }},{{ interface.l3Inst.attributes.v6TibName }},{{ interface.l3Inst.attributes.v6TibOldOperStQual }},{{ interface.l3Inst.attributes.v6TibOperStQual }},{{ interface.l3Inst.attributes.v6TibOperState }},{{ interface.l3Inst.attributes.v6TibPending }},{{ interface.l3Inst.attributes.v6TibValid }},{{ interface.l3Inst.attributes.vpnId }}
{%-     endfor %}
{%- elif "actrlEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Operational Error,Operational State,Status
{%-     for acl in data_to_template['imdata'] %}
{{ acl.actrlEntity.attributes.name }},{{ acl.actrlEntity.attributes.adminSt }},{{ acl.actrlEntity.attributes.childAction }},{{ acl.actrlEntity.attributes.dn }},{{ acl.actrlEntity.attributes.lcOwn }},{{ acl.actrlEntity.attributes.modTs }},{{ acl.actrlEntity.attributes.monPolDn }},{{ acl.actrlEntity.attributes.operErr }},{{ acl.actrlEntity.attributes.operSt }},{{ acl.actrlEntity.attributes.status }}
{%-     endfor %}
{%- elif "actrlInst" in api %}Name,Acc Control,Admin State,Child Action,Control,DN,Local Owner,Log Clr Interval,Last Modified,Monitoring Policy DN,Oper Error,Status
{%-     for acl in data_to_template['imdata'] %}
{{ acl.actrlInst.attributes.name }},{{ acl.actrlInst.attributes.accCtrl }},{{ acl.actrlInst.attributes.adminSt }},{{ acl.actrlInst.attributes.childAction }},{{ acl.actrlInst.attributes.ctrl }},{{ acl.actrlInst.attributes.dn }},{{ acl.actrlInst.attributes.lcOwn }},{{ acl.actrlInst.attributes.logClrIntvl }},{{ acl.actrlInst.attributes.modTs }},{{ acl.actrlInst.attributes.monPolDn }},{{ acl.actrlInst.attributes.operErr }},{{ acl.actrlInst.attributes.status }}
{%-     endfor %}
{%- elif "actrlRule" in api %}Name,Name Alias,Action,Access Control Config Failed Bmp,Access Control Config Failed Timestamp,Access Control Config State,Child Action,Contract Name,Destination PC Tag,Description,Direction,DN,Filter ID,ID,Intent,Local Owner,Mark DSCP,Last Modified,Monitoring Policy DN,Operational State,Operational State Quality,Priority,QOS Group,Source PC Tag,Scope ID,Status,Type
{%-     for acl in data_to_template['imdata'] %}
{{ acl.actrlRule.attributes.name }},{{ acl.actrlRule.attributes.nameAlias }},{{ acl.actrlRule.attributes.action | replace(","," ") }},{{ acl.actrlRule.attributes.actrlCfgFailedBmp }},{{ acl.actrlRule.attributes.actrlCfgFailedTs }},{{ acl.actrlRule.attributes.actrlCfgState }},{{ acl.actrlRule.attributes.childAction }},{{ acl.actrlRule.attributes.ctrctName }},{{ acl.actrlRule.attributes.dPcTag }},{{ acl.actrlRule.attributes.descr }},{{ acl.actrlRule.attributes.direction }},{{ acl.actrlRule.attributes.dn }},{{ acl.actrlRule.attributes.fltId }},{{ acl.actrlRule.attributes.id }},{{ acl.actrlRule.attributes.intent }},{{ acl.actrlRule.attributes.lcOwn }},{{ acl.actrlRule.attributes.markDscp }},{{ acl.actrlRule.attributes.modTs }},{{ acl.actrlRule.attributes.monPolDn }},{{ acl.actrlRule.attributes.operSt }},{{ acl.actrlRule.attributes.operStQual }},{{ acl.actrlRule.attributes.prio }},{{ acl.actrlRule.attributes.qosGrp }},{{ acl.actrlRule.attributes.sPcTag }},{{ acl.actrlRule.attributes.scopeId }},{{ acl.actrlRule.attributes.status }},{{ acl.actrlRule.attributes.type }}
{%-     endfor %}
{%- elif "actrlScope" in api %}Name,Name Alias,Child Action,Description,DN,ID,Local Owner,Last Modified,Monitoring Policy DN,Security Label,Status
{%-     for acl in data_to_template['imdata'] %}
{{ acl.actrlScope.attributes.name }},{{ acl.actrlScope.attributes.nameAlias }},{{ acl.actrlScope.attributes.childAction }},{{ acl.actrlScope.attributes.descr }},{{ acl.actrlScope.attributes.dn }},{{ acl.actrlScope.attributes.id }},{{ acl.actrlScope.attributes.lcOwn }},{{ acl.actrlScope.attributes.modTs }},{{ acl.actrlScope.attributes.monPolDn }},{{ acl.actrlScope.attributes.secLbl }},{{ acl.actrlScope.attributes.status }}
{%-     endfor %}
{%- elif "cnwPhysIf" in api %}Name,Admin State,Annotation,Auto Negotiate,Bandwidth,Child Action,Delay,Description,Device ID,DN,Dot1q Ether Type,Externally Managed By,FCOT Channel Number,ID,Inherited Bandwidth,Is Reflective Relay Config Supported,Layer,Local Owner,Link Debounce,Link Log,MDIX,Medium,Last Modified,Mode,Monitoring Policy DN,MTU,Oper State,Path S Description,Port T,Priority Flow Control,Reflective Relay Enable,Router MAC,SNMP Trap State,Span Mode,Speed,Status,Switching State,Trunk Log,UID,Usage,User Domain,Vendor ID,Wiring Issues
{%-     for interface in data_to_template['imdata'] %}
{{ interface.cnwPhysIf.attributes.name }},{{ interface.cnwPhysIf.attributes.adminSt }},{{ interface.cnwPhysIf.attributes.annotation }},{{ interface.cnwPhysIf.attributes.autoNeg }},{{ interface.cnwPhysIf.attributes.bw }},{{ interface.cnwPhysIf.attributes.childAction }},{{ interface.cnwPhysIf.attributes.delay }},{{ interface.cnwPhysIf.attributes.descr }},{{ interface.cnwPhysIf.attributes.deviceId }},{{ interface.cnwPhysIf.attributes.dn }},{{ interface.cnwPhysIf.attributes.dot1qEtherType }},{{ interface.cnwPhysIf.attributes.extMngdBy }},{{ interface.cnwPhysIf.attributes.fcotChannelNumber }},{{ interface.cnwPhysIf.attributes.id }},{{ interface.cnwPhysIf.attributes.inhBw }},{{ interface.cnwPhysIf.attributes.isReflectiveRelayCfgSupported }},{{ interface.cnwPhysIf.attributes.layer }},{{ interface.cnwPhysIf.attributes.lcOwn }},{{ interface.cnwPhysIf.attributes.linkDebounce }},{{ interface.cnwPhysIf.attributes.linkLog }},{{ interface.cnwPhysIf.attributes.mdix }},{{ interface.cnwPhysIf.attributes.medium }},{{ interface.cnwPhysIf.attributes.modTs }},{{ interface.cnwPhysIf.attributes.mode }},{{ interface.cnwPhysIf.attributes.monPolDn }},{{ interface.cnwPhysIf.attributes.mtu }},{{ interface.cnwPhysIf.attributes.operSt }},{{ interface.cnwPhysIf.attributes.pathSDescr }},{{ interface.cnwPhysIf.attributes.portT }},{{ interface.cnwPhysIf.attributes.prioFlowCtrl }},{{ interface.cnwPhysIf.attributes.reflectiveRelayEn }},{{ interface.cnwPhysIf.attributes.routerMac }},{{ interface.cnwPhysIf.attributes.snmpTrapSt }},{{ interface.cnwPhysIf.attributes.spanMode }},{{ interface.cnwPhysIf.attributes.speed }},{{ interface.cnwPhysIf.attributes.status }},{{ interface.cnwPhysIf.attributes.switchingSt }},{{ interface.cnwPhysIf.attributes.trunkLog }},{{ interface.cnwPhysIf.attributes.uid }},{{ interface.cnwPhysIf.attributes.usage }},{{ interface.cnwPhysIf.attributes.userdom }},{{ interface.cnwPhysIf.attributes.vendorId }},{{ interface.cnwPhysIf.attributes.wiringIssues }}
{%-     endfor %}
{%- elif "compCtrlr" in api %}Name,Name Alias,Access Mode,API Version,AVE Switching Active,AVE Time Out,Child Action,CIMC Version,Control Knob,Control rP Key,Deploy Issues,Description,DN,Domain Name,DVS Version,Enable AVE,Enable Tag,Enable VM Folder,EP Ret Time,Host Or IP,ID,Inventory Start Timestamp,Inventory Trigger State,Issues,Key,Lag Policy Name,Last Event Collector ID,Last Event ID,Last Event Timestamp,Last Inventory State,Last Inventory Timestamp,Local Owner,Max Worker Q Size,Last Modified,Mode,Model,Monitoring Policy DN,Oper State,Port,Remote Error Message,Remote Oper Issues,Rev,Root Cont Name,Scope,Ser,Set Deploy Issues,Set Remote Oper Issues,Status,Unset Deploy Issues,Unset Remote Oper Issues,User,Vendor,vSphere PHA,vSphere Tag,VXLAN Deploy Preferred
{%-     for controller in data_to_template['imdata'] %}
{{ controller.compCtrlr.attributes.name }},{{ controller.compCtrlr.attributes.nameAlias }},{{ controller.compCtrlr.attributes.accessMode }},{{ controller.compCtrlr.attributes.apiVer }},{{ controller.compCtrlr.attributes.aveSwitchingActive }},{{ controller.compCtrlr.attributes.aveTimeOut }},{{ controller.compCtrlr.attributes.childAction }},{{ controller.compCtrlr.attributes.cimcVersion }},{{ controller.compCtrlr.attributes.ctrlKnob }},{{ controller.compCtrlr.attributes.ctrlrPKey }},{{ controller.compCtrlr.attributes.deployIssues }},{{ controller.compCtrlr.attributes.descr }},{{ controller.compCtrlr.attributes.dn }},{{ controller.compCtrlr.attributes.domName }},{{ controller.compCtrlr.attributes.dvsVersion }},{{ controller.compCtrlr.attributes.enableAVE }},{{ controller.compCtrlr.attributes.enableTag }},{{ controller.compCtrlr.attributes.enableVmFolder }},{{ controller.compCtrlr.attributes.epRetTime }},{{ controller.compCtrlr.attributes.hostOrIp }},{{ controller.compCtrlr.attributes.id }},{{ controller.compCtrlr.attributes.inventoryStartTS }},{{ controller.compCtrlr.attributes.inventoryTrigSt }},{{ controller.compCtrlr.attributes.issues }},{{ controller.compCtrlr.attributes.key }},{{ controller.compCtrlr.attributes.lagPolicyName }},{{ controller.compCtrlr.attributes.lastEventCollectorId }},{{ controller.compCtrlr.attributes.lastEventId }},{{ controller.compCtrlr.attributes.lastEventTS }},{{ controller.compCtrlr.attributes.lastInventorySt }},{{ controller.compCtrlr.attributes.lastInventoryTS }},{{ controller.compCtrlr.attributes.lcOwn }},{{ controller.compCtrlr.attributes.maxWorkerQSize }},{{ controller.compCtrlr.attributes.modTs }},{{ controller.compCtrlr.attributes.mode }},{{ controller.compCtrlr.attributes.model }},{{ controller.compCtrlr.attributes.monPolDn }},{{ controller.compCtrlr.attributes.operSt }},{{ controller.compCtrlr.attributes.port }},{{ controller.compCtrlr.attributes.remoteErrMsg }},{{ controller.compCtrlr.attributes.remoteOperIssues }},{{ controller.compCtrlr.attributes.rev }},{{ controller.compCtrlr.attributes.rootContName }},{{ controller.compCtrlr.attributes.scope }},{{ controller.compCtrlr.attributes.ser }},{{ controller.compCtrlr.attributes.setDeployIssues }},{{ controller.compCtrlr.attributes.setRemoteOperIssues }},{{ controller.compCtrlr.attributes.status }},{{ controller.compCtrlr.attributes.unsetDeployIssues }},{{ controller.compCtrlr.attributes.unsetRemoteOperIssues }},{{ controller.compCtrlr.attributes.usr }},{{ controller.compCtrlr.attributes.vendor }},{{ controller.compCtrlr.attributes.vspherePHA }},{{ controller.compCtrlr.attributes.vsphereTag }},{{ controller.compCtrlr.attributes.vxlanDeplPref }}
{%-     endfor %}
{%- elif "compDom" in api %}Name,Name Alias,Child Action,Description,DN,Enable AVE,ID,Issues,Local Owner,Last Modified,Mode,Monitoring Policy DN,Status
{%-     for domain in data_to_template['imdata'] %}
{{ domain.compDom.attributes.name }},{{ domain.compDom.attributes.nameAlias }},{{ domain.compDom.attributes.childAction }},{{ domain.compDom.attributes.descr }},{{ domain.compDom.attributes.dn }},{{ domain.compDom.attributes.enableAVE }},{{ domain.compDom.attributes.id }},{{ domain.compDom.attributes.issues }},{{ domain.compDom.attributes.lcOwn }},{{ domain.compDom.attributes.modTs }},{{ domain.compDom.attributes.mode }},{{ domain.compDom.attributes.monPolDn }},{{ domain.compDom.attributes.status }}
{%-     endfor %}
{%- elif "compEpPD" in api %}Name,Name Alias,Allocation Mode,Bridge Domain DN,Binding Type,Block All Ports,Configured Delimiter,Child Action,Class Preference,Configuration Flags,Controller Enabled,Context DN,Custom EPG Name,Deployment Issues,Description,DN,Encapsulation,Encapsulation Allocated Key,Encapsulation Changed,Encapsulation Context,Encapsulation Mode,Encapsulation Mode Override,EPG COS,EPG COS Preference,EPG P Key,EPP DN,Fault D Key,Forged Transmit,ID,ID Consumer DN,Inherited,Instr Immediacy,Intra Sec Conf,Issues,Lag Policy Name,Load Balance Algorithm,Local Owner,MAC Change,Multicast Address,Last Modified,Monitoring Policy DN,Netflow Direction,Netflow Preferred,Number Ports,Oper Delimiter,Oper Flags,PC Enforced Preference,Port Allocation,Primary Encapsulation,Primary Encapsulation Inner,Prom Mode,Remote Error Message,Remote Oper Issues,Res Immediacy,Secondary Encapsulation Inner,Stats Collection State,Status,Switching Mode,TX ID,Type,Untagged,Update Timestamp,VNET Only,VXVLAN Deploy Preference
{%-     for policy in data_to_template['imdata'] %}
{{ policy.compEpPD.attributes.name }},{{ policy.compEpPD.attributes.nameAlias }},{{ policy.compEpPD.attributes.allocMode }},{{ policy.compEpPD.attributes.bdDn }},{{ policy.compEpPD.attributes.bindingType }},{{ policy.compEpPD.attributes.blockAllPorts }},{{ policy.compEpPD.attributes.cfgdDelimiter }},{{ policy.compEpPD.attributes.childAction }},{{ policy.compEpPD.attributes.classPref }},{{ policy.compEpPD.attributes.configFlags }},{{ policy.compEpPD.attributes.crtrnEnabled }},{{ policy.compEpPD.attributes.ctxDn }},{{ policy.compEpPD.attributes.customEpgName }},{{ policy.compEpPD.attributes.deployIssues }},{{ policy.compEpPD.attributes.descr }},{{ policy.compEpPD.attributes.dn }},{{ policy.compEpPD.attributes.encap }},{{ policy.compEpPD.attributes.encapAllocKey }},{{ policy.compEpPD.attributes.encapChanged }},{{ policy.compEpPD.attributes.encapCtx }},{{ policy.compEpPD.attributes.encapMode }},{{ policy.compEpPD.attributes.encapModeOverride }},{{ policy.compEpPD.attributes.epgCos }},{{ policy.compEpPD.attributes.epgCosPref }},{{ policy.compEpPD.attributes.epgPKey }},{{ policy.compEpPD.attributes.eppDn }},{{ policy.compEpPD.attributes.faultDKey }},{{ policy.compEpPD.attributes.forgedTransmit }},{{ policy.compEpPD.attributes.id }},{{ policy.compEpPD.attributes.idConsumerDn }},{{ policy.compEpPD.attributes.inherited }},{{ policy.compEpPD.attributes.instrImedcy }},{{ policy.compEpPD.attributes.intraSecConf }},{{ policy.compEpPD.attributes.issues }},{{ policy.compEpPD.attributes.lagPolicyName }},{{ policy.compEpPD.attributes.lbAlgo }},{{ policy.compEpPD.attributes.lcOwn }},{{ policy.compEpPD.attributes.macChange }},{{ policy.compEpPD.attributes.mcastAddr }},{{ policy.compEpPD.attributes.modTs }},{{ policy.compEpPD.attributes.monPolDn }},{{ policy.compEpPD.attributes.netflowDir }},{{ policy.compEpPD.attributes.netflowPref }},{{ policy.compEpPD.attributes.numPorts }},{{ policy.compEpPD.attributes.operDelimiter }},{{ policy.compEpPD.attributes.operFlags }},{{ policy.compEpPD.attributes.pcEnfPref }},{{ policy.compEpPD.attributes.portAllocation }},{{ policy.compEpPD.attributes.primaryEncap }},{{ policy.compEpPD.attributes.primaryEncapInner }},{{ policy.compEpPD.attributes.promMode }},{{ policy.compEpPD.attributes.remoteErrMsg }},{{ policy.compEpPD.attributes.remoteOperIssues }},{{ policy.compEpPD.attributes.resImedcy }},{{ policy.compEpPD.attributes.secondaryEncapInner }},{{ policy.compEpPD.attributes.statsCollectionState }},{{ policy.compEpPD.attributes.status }},{{ policy.compEpPD.attributes.switchingMode }},{{ policy.compEpPD.attributes.txId }},{{ policy.compEpPD.attributes.type }},{{ policy.compEpPD.attributes.untagged }},{{ policy.compEpPD.attributes.updateTs }},{{ policy.compEpPD.attributes.vnetOnly }},{{ policy.compEpPD.attributes.vxlanDeplPref }}
{%-     endfor %}
{%- elif "compProv" in api %}Name,Name Alias,Child Action,Description,DN,ID,Issues,Local Owner,Last Modified,Monitoring Policy DN,Status,Vendor
{%-     for provider in data_to_template['imdata'] %}
{{ provider.compProv.attributes.name }},{{ provider.compProv.attributes.nameAlias }},{{ provider.compProv.attributes.childAction }},{{ provider.compProv.attributes.descr }},{{ provider.compProv.attributes.dn }},{{ provider.compProv.attributes.id }},{{ provider.compProv.attributes.issues }},{{ provider.compProv.attributes.lcOwn }},{{ provider.compProv.attributes.modTs }},{{ provider.compProv.attributes.monPolDn }},{{ provider.compProv.attributes.status }},{{ provider.compProv.attributes.vendor }}
{%-     endfor %}
{%- elif "arpAdjEp" in api %}Name,Child Action,DN,Interface ID,IP,MAC,Last Modified,Operational State,Physical Interface ID,Status,Last Updated
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.arpAdjEp.attributes.name }},{{ endpoint.arpAdjEp.attributes.childAction }},{{ endpoint.arpAdjEp.attributes.dn }},{{ endpoint.arpAdjEp.attributes.ifId }},{{ endpoint.arpAdjEp.attributes.ip }},{{ endpoint.arpAdjEp.attributes.mac }},{{ endpoint.arpAdjEp.attributes.modTs }},{{ endpoint.arpAdjEp.attributes.operSt }},{{ endpoint.arpAdjEp.attributes.physIfId }},{{ endpoint.arpAdjEp.attributes.status }},{{ endpoint.arpAdjEp.attributes.upTS }}
{%-     endfor %}
{%- elif "arpDb" in api %}Name,Child Action,DN,Last Modified,Status,Type
{%-     for entry in data_to_template['imdata'] %}
{{ entry.arpDb.attributes.name }},{{ entry.arpDb.attributes.childAction }},{{ entry.arpDb.attributes.dn }},{{ entry.arpDb.attributes.modTs }},{{ entry.arpDb.attributes.status }},{{ entry.arpDb.attributes.type }}
{%-     endfor %}
{%- elif "arpDom" in api %}Name,Child Action,DN,Encapsulation,Local Owner,Last Modified,Monitoring Policy DN,Status
{%-     for domain in data_to_template['imdata'] %}
{{ domain.arpDom.attributes.name }},{{ domain.arpDom.attributes.childAction }},{{ domain.arpDom.attributes.dn }},{{ domain.arpDom.attributes.encap }},{{ domain.arpDom.attributes.lcOwn }},{{ domain.arpDom.attributes.modTs }},{{ domain.arpDom.attributes.monPolDn }},{{ domain.arpDom.attributes.status }}
{%-     endfor %}
{%- elif "arpEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Operational Error,Operational State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.arpEntity.attributes.name }},{{ entity.arpEntity.attributes.adminSt }},{{ entity.arpEntity.attributes.childAction }},{{ entity.arpEntity.attributes.dn }},{{ entity.arpEntity.attributes.lcOwn }},{{ entity.arpEntity.attributes.modTs }},{{ entity.arpEntity.attributes.monPolDn }},{{ entity.arpEntity.attributes.operErr }},{{ entity.arpEntity.attributes.operSt }},{{ entity.arpEntity.attributes.status }}
{%-     endfor %}
{%- elif "arpIf" in api %}Name,Admin State,Child Action,Control,Description,DN,ID,Local Owner,Last Modified,Monitoring Policy DN,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.arpIf.attributes.name }},{{ interface.arpIf.attributes.adminSt }},{{ interface.arpIf.attributes.childAction }},{{ interface.arpIf.attributes.ctrl }},{{ interface.arpIf.attributes.descr }},{{ interface.arpIf.attributes.dn }},{{ interface.arpIf.attributes.id }},{{ interface.arpIf.attributes.lcOwn }},{{ interface.arpIf.attributes.modTs }},{{ interface.arpIf.attributes.monPolDn }},{{ interface.arpIf.attributes.status }}
{%-     endfor %}
{%- elif "arpInst" in api %}Name,Admin State,Child Action,Control,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Err,Status
{%-     for instance in data_to_template['imdata'] %}
{{ instance.arpInst.attributes.name }},{{ instance.arpInst.attributes.adminSt }},{{ instance.arpInst.attributes.childAction }},{{ instance.arpInst.attributes.ctrl }},{{ instance.arpInst.attributes.dn }},{{ instance.arpInst.attributes.lcOwn }},{{ instance.arpInst.attributes.modTs }},{{ instance.arpInst.attributes.monPolDn }},{{ instance.arpInst.attributes.operErr }},{{ instance.arpInst.attributes.status }}
{%-     endfor %}
{%- elif "bgpDom" in api %}
{%-     if "Af" in api%}Name,Best Path Complete Timestamp,Best Path Signature Timestamp,Child Action,Crit Nh Timeout,DN,Local Owner,Max ECMP,Max ECMP IBGP,Last Modified,Non Crit Nh Timeout,Status,Table Version,Type
{%-          for family in data_to_template['imdata'] %}
{{ family.bgpDomAf.attributes.name }},{{ family.bgpDomAf.attributes.bestPathCmpltTs }},{{ family.bgpDomAf.attributes.bestPathSigTs }},{{ family.bgpDomAf.attributes.childAction }},{{ family.bgpDomAf.attributes.critNhTimeout }},{{ family.bgpDomAf.attributes.dn }},{{ family.bgpDomAf.attributes.lcOwn }},{{ family.bgpDomAf.attributes.maxEcmp }},{{ family.bgpDomAf.attributes.maxEcmpIbgp }},{{ family.bgpDomAf.attributes.modTs }},{{ family.bgpDomAf.attributes.nonCritNhTimeout }},{{ family.bgpDomAf.attributes.status }},{{ family.bgpDomAf.attributes.tblVer }},{{ family.bgpDomAf.attributes.type }}
{%-          endfor %}
{%-     else %}Name,BGP Configuration Failed Bmp,BGP Configuration Failed Timestamp,BGP Configuration State,Child Action,Cluster ID,Control,DN,Encapsulation,First Best Path Delay,First Peer Uptime Timestamp,Flags,Hold Interval,ka Interval,Local Owner,Max AS Limit,Last Modified,Mode,Monitoring Policy DN,MSite Cluster ID,Number of Established Peers,Number of Peers,Oper Router ID,Oper State,RD,Router ID,Status,Type
{%-          for domain in data_to_template['imdata'] %}
{{ domain.bgpDom.attributes.name }},{{ domain.bgpDom.attributes.bgpCfgFailedBmp }},{{ domain.bgpDom.attributes.bgpCfgFailedTs }},{{ domain.bgpDom.attributes.bgpCfgState }},{{ domain.bgpDom.attributes.childAction }},{{ domain.bgpDom.attributes.clusterId }},{{ domain.bgpDom.attributes.ctrl }},{{ domain.bgpDom.attributes.dn }},{{ domain.bgpDom.attributes.encap }},{{ domain.bgpDom.attributes.firstBestPathDelay }},{{ domain.bgpDom.attributes.firstPeerUpTs }},{{ domain.bgpDom.attributes.flags | replace(","," ")}},{{ domain.bgpDom.attributes.holdIntvl }},{{ domain.bgpDom.attributes.kaIntvl }},{{ domain.bgpDom.attributes.lcOwn }},{{ domain.bgpDom.attributes.maxAsLimit }},{{ domain.bgpDom.attributes.modTs }},{{ domain.bgpDom.attributes.mode }},{{ domain.bgpDom.attributes.monPolDn }},{{ domain.bgpDom.attributes.msiteClusterId }},{{ domain.bgpDom.attributes.numEstPeers }},{{ domain.bgpDom.attributes.numPeers }},{{ domain.bgpDom.attributes.operRtrId }},{{ domain.bgpDom.attributes.operSt }},{{ domain.bgpDom.attributes.rd }},{{ domain.bgpDom.attributes.rtrId }},{{ domain.bgpDom.attributes.status }},{{ domain.bgpDom.attributes.type }}
{%-          endfor %}
{%-     endif %}
{%- elif "bgpEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.bgpEntity.attributes.name }},{{ entity.bgpEntity.attributes.adminSt }},{{ entity.bgpEntity.attributes.childAction }},{{ entity.bgpEntity.attributes.dn }},{{ entity.bgpEntity.attributes.lcOwn }},{{ entity.bgpEntity.attributes.modTs }},{{ entity.bgpEntity.attributes.monPolDn }},{{ entity.bgpEntity.attributes.operErr }},{{ entity.bgpEntity.attributes.operSt }},{{ entity.bgpEntity.attributes.status }}
{%-     endfor %}
{%- elif "bgpInst" in api %}
{%-     if "InstPol" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-         for policy in data_to_template['imdata'] %}
{{ policy.bgpInstPol.attributes.name }},{{ policy.bgpInstPol.attributes.nameAlias }},{{ policy.bgpInstPol.attributes.annotation }},{{ policy.bgpInstPol.attributes.childAction }},{{ policy.bgpInstPol.attributes.descr }},{{ policy.bgpInstPol.attributes.dn }},{{ policy.bgpInstPol.attributes.extMngdBy }},{{ policy.bgpInstPol.attributes.lcOwn }},{{ policy.bgpInstPol.attributes.modTs }},{{ policy.bgpInstPol.attributes.monPolDn }},{{ policy.bgpInstPol.attributes.ownerKey }},{{ policy.bgpInstPol.attributes.ownerTag }},{{ policy.bgpInstPol.attributes.status }},{{ policy.bgpInstPol.attributes.uid }}
{%-         endfor %}
{%-     else %}
{%-         for instance in data_to_template['imdata'] %}Name,Activated Timestamp,Admin State,AS Path DB Size,ASN,Attribute DB Size,Child Action,Created Timestamp,Control,DN,Fabric SoO,Local Owner,mSite SoO,Memory Alert,Last Modified,Monitoring Policy DN,Number AS Path,Number RT Attributes,Oper Error,Pod SoO,SNMP Trap State,Spine Role,Status,Suppr RT,Syslog Level,Version,Wait Done Timestamp
{{ instance.bgpInst.attributes.name }},{{ instance.bgpInst.attributes.activateTs }},{{ instance.bgpInst.attributes.adminSt }},{{ instance.bgpInst.attributes.asPathDbSz }},{{ instance.bgpInst.attributes.asn }},{{ instance.bgpInst.attributes.attribDbSz }},{{ instance.bgpInst.attributes.childAction }},{{ instance.bgpInst.attributes.createTs }},{{ instance.bgpInst.attributes.ctrl }},{{ instance.bgpInst.attributes.dn }},{{ instance.bgpInst.attributes.fabricSoO }},{{ instance.bgpInst.attributes.lcOwn }},{{ instance.bgpInst.attributes.mSiteSoO }},{{ instance.bgpInst.attributes.memAlert }},{{ instance.bgpInst.attributes.modTs }},{{ instance.bgpInst.attributes.monPolDn }},{{ instance.bgpInst.attributes.numAsPath }},{{ instance.bgpInst.attributes.numRtAttrib }},{{ instance.bgpInst.attributes.operErr }},{{ instance.bgpInst.attributes.podSoO }},{{ instance.bgpInst.attributes.snmpTrapSt }},{{ instance.bgpInst.attributes.spineRole }},{{ instance.bgpInst.attributes.status }},{{ instance.bgpInst.attributes.supprRt }},{{ instance.bgpInst.attributes.syslogLvl }},{{ instance.bgpInst.attributes.ver }},{{ instance.bgpInst.attributes.waitDoneTs }}
{%-         endfor %}
{%-     endif %}
{%- elif "bgpPeer" in api %}
{%-     if "bgpPeerAf" in api %}Name,Accepted Paths,Child Action,DN,First Eor Received Timestamp,Flags,Last Eor Received Timestamp,Memory Acc Paths,Last Modified,Monitoring Policy DN,Peer Table Version,Prefix Flushed,Prefix Saved,Prefix Sent,Status,Table State,Table Version,Type
{%-         for af in data_to_template['imdata'] %}
{{ af.bgpPeerAfEntry.attributes.name }},{{ af.bgpPeerAfEntry.attributes.acceptedPaths }},{{ af.bgpPeerAfEntry.attributes.childAction }},{{ af.bgpPeerAfEntry.attributes.dn }},{{ af.bgpPeerAfEntry.attributes.firstEorRcvdTs }},{{ af.bgpPeerAfEntry.attributes.flags | replace(","," ")}},{{ af.bgpPeerAfEntry.attributes.lastEorRcvdTs }},{{ af.bgpPeerAfEntry.attributes.memAccPaths }},{{ af.bgpPeerAfEntry.attributes.modTs }},{{ af.bgpPeerAfEntry.attributes.monPolDn }},{{ af.bgpPeerAfEntry.attributes.peerTblVer }},{{ af.bgpPeerAfEntry.attributes.pfxFlushed }},{{ af.bgpPeerAfEntry.attributes.pfxSaved }},{{ af.bgpPeerAfEntry.attributes.pfxSent }},{{ af.bgpPeerAfEntry.attributes.status }},{{ af.bgpPeerAfEntry.attributes.tblSt }},{{ af.bgpPeerAfEntry.attributes.tblVer }},{{ af.bgpPeerAfEntry.attributes.type }}
{%-         endfor %}
{%-     else %}
{%-         if "bgpPeerEntry" in api %}Name,Address,Advertised Capabilites,Child Action,Connection Attempts,Connection Drop,Connection Established,Connection Interface,DN,FD,Flags,Hold Interval,ka Interval,Last Flap Timestamp,Local IP,Local Port,Last Modified,Monitoring Policy DN,Oper State,Password Set,Peer Index,Previous Oper State,Received Capabilites,Remote Port,Router ID,Shut State Quality,State Reason,Status,Type,Update Elapsed Timestamp
{%-             for entry in data_to_template['imdata'] %}
{{ entry.bgpPeerEntry.attributes.name }},{{ entry.bgpPeerEntry.attributes.addr }},{{ entry.bgpPeerEntry.attributes.advCap | replace(","," ") }},{{ entry.bgpPeerEntry.attributes.childAction }},{{ entry.bgpPeerEntry.attributes.connAttempts }},{{ entry.bgpPeerEntry.attributes.connDrop }},{{ entry.bgpPeerEntry.attributes.connEst }},{{ entry.bgpPeerEntry.attributes.connIf }},{{ entry.bgpPeerEntry.attributes.dn }},{{ entry.bgpPeerEntry.attributes.fd }},{{ entry.bgpPeerEntry.attributes.flags | replace(","," ") }},{{ entry.bgpPeerEntry.attributes.holdIntvl }},{{ entry.bgpPeerEntry.attributes.kaIntvl }},{{ entry.bgpPeerEntry.attributes.lastFlapTs }},{{ entry.bgpPeerEntry.attributes.localIp }},{{ entry.bgpPeerEntry.attributes.localPort }},{{ entry.bgpPeerEntry.attributes.modTs }},{{ entry.bgpPeerEntry.attributes.monPolDn }},{{ entry.bgpPeerEntry.attributes.operSt }},{{ entry.bgpPeerEntry.attributes.passwdSet }},{{ entry.bgpPeerEntry.attributes.peerIdx }},{{ entry.bgpPeerEntry.attributes.prevOperSt }},{{ entry.bgpPeerEntry.attributes.rcvCap | replace(","," ") }},{{ entry.bgpPeerEntry.attributes.remotePort }},{{ entry.bgpPeerEntry.attributes.rtrId }},{{ entry.bgpPeerEntry.attributes.shutStQual }},{{ entry.bgpPeerEntry.attributes.stReason }},{{ entry.bgpPeerEntry.attributes.status }},{{ entry.bgpPeerEntry.attributes.type }},{{ entry.bgpPeerEntry.attributes.updateElapsedTs }}
{%-             endfor %}
{%-         else %}Name,Active Prefix Peers,Address,Admin State,ASN,BGP Config Failed Bmp,BGP Config Failed Timestamp,BGP Config State,Child Action,Control,Current Prefix Peers,DN,Local Owner,Maximum Current Peers,Maximum Prefix Peers,Last Modified,Monitoring Policy DN,Password Set,Peer Role,Private AS Control,Source Interface,Status,Total Prefix Peers,TTL,Type
{%-             for peer in data_to_template['imdata'] %}
{{ peer.bgpPeer.attributes.name }},{{ peer.bgpPeer.attributes.activePfxPeers }},{{ peer.bgpPeer.attributes.addr }},{{ peer.bgpPeer.attributes.adminSt }},{{ peer.bgpPeer.attributes.asn }},{{ peer.bgpPeer.attributes.bgpCfgFailedBmp }},{{ peer.bgpPeer.attributes.bgpCfgFailedTs }},{{ peer.bgpPeer.attributes.bgpCfgState }},{{ peer.bgpPeer.attributes.childAction }},{{ peer.bgpPeer.attributes.ctrl }},{{ peer.bgpPeer.attributes.curPfxPeers }},{{ peer.bgpPeer.attributes.dn }},{{ peer.bgpPeer.attributes.lcOwn }},{{ peer.bgpPeer.attributes.maxCurPeers }},{{ peer.bgpPeer.attributes.maxPfxPeers }},{{ peer.bgpPeer.attributes.modTs }},{{ peer.bgpPeer.attributes.monPolDn }},{{ peer.bgpPeer.attributes.passwdSet }},{{ peer.bgpPeer.attributes.peerRole }},{{ peer.bgpPeer.attributes.privateASctrl }},{{ peer.bgpPeer.attributes.srcIf }},{{ peer.bgpPeer.attributes.status }},{{ peer.bgpPeer.attributes.totalPfxPeers }},{{ peer.bgpPeer.attributes.ttl }},{{ peer.bgpPeer.attributes.type }}
{%-             endfor %}
{%-         endif %}
{%-     endif %}
{%- elif "bgpRRP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Status,UID
{%-     for policy in data_to_template['imdata'] %}
{{ policy.bgpRRP.attributes.name }},{{ policy.bgpRRP.attributes.nameAlias }},{{ policy.bgpRRP.attributes.annotation }},{{ policy.bgpRRP.attributes.childAction }},{{ policy.bgpRRP.attributes.descr }},{{ policy.bgpRRP.attributes.dn }},{{ policy.bgpRRP.attributes.extMngdBy }},{{ policy.bgpRRP.attributes.lcOwn }},{{ policy.bgpRRP.attributes.modTs }},{{ policy.bgpRRP.attributes.monPolDn }},{{ policy.bgpRRP.attributes.status }},{{ policy.bgpRRP.attributes.uid }}
{%-     endfor %}
{%- elif "cdpAdjEp" in api %}Name,Capabilites,Child Action,Device ID,DN,Duplex,Index,Last Modified,Monitoring Policy DN,MTU,Native VLAN,Platform ID,Port ID,State Quality,Status,System Location,System Name,System Object ID L,System Object ID V,Version
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.cdpAdjEp.attributes.name }},{{ endpoint.cdpAdjEp.attributes.cap | replace(","," ") }},{{ endpoint.cdpAdjEp.attributes.childAction }},{{ endpoint.cdpAdjEp.attributes.devId }},{{ endpoint.cdpAdjEp.attributes.dn }},{{ endpoint.cdpAdjEp.attributes.duplex }},{{ endpoint.cdpAdjEp.attributes.index }},{{ endpoint.cdpAdjEp.attributes.modTs }},{{ endpoint.cdpAdjEp.attributes.monPolDn }},{{ endpoint.cdpAdjEp.attributes.mtu }},{{ endpoint.cdpAdjEp.attributes.nativeVlan }},{{ endpoint.cdpAdjEp.attributes.platId }},{{ endpoint.cdpAdjEp.attributes.portId }},{{ endpoint.cdpAdjEp.attributes.stQual }},{{ endpoint.cdpAdjEp.attributes.status }},{{ endpoint.cdpAdjEp.attributes.sysLoc }},{{ endpoint.cdpAdjEp.attributes.sysName }},{{ endpoint.cdpAdjEp.attributes.sysObjIdL }},{{ endpoint.cdpAdjEp.attributes.sysObjIdV | replace(","," ") }},{{ endpoint.cdpAdjEp.attributes.ver | replace(","," ") | replace("\n"," ") }}
{%-     endfor %}
{%- elif "cdpEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.cdpEntity.attributes.name }},{{ entity.cdpEntity.attributes.adminSt }},{{ entity.cdpEntity.attributes.childAction }},{{ entity.cdpEntity.attributes.dn }},{{ entity.cdpEntity.attributes.lcOwn }},{{ entity.cdpEntity.attributes.modTs }},{{ entity.cdpEntity.attributes.operErr }},{{ entity.cdpEntity.attributes.operSt }},{{ entity.cdpEntity.attributes.status }}
{%-     endfor %}
{%- elif "cdpIf" in api %}Name,Admin State,Child Action,Description,DN,ID,Local Owner,Local Description,Last Modified,Monitoring Policy DN,Native VLAN,Oper State,Oper State Quality,Port Description,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.cdpIf.attributes.name }},{{ interface.cdpIf.attributes.adminSt }},{{ interface.cdpIf.attributes.childAction }},{{ interface.cdpIf.attributes.descr }},{{ interface.cdpIf.attributes.dn }},{{ interface.cdpIf.attributes.id }},{{ interface.cdpIf.attributes.lcOwn }},{{ interface.cdpIf.attributes.locDesc }},{{ interface.cdpIf.attributes.modTs }},{{ interface.cdpIf.attributes.monPolDn }},{{ interface.cdpIf.attributes.nativeVlan }},{{ interface.cdpIf.attributes.operSt }},{{ interface.cdpIf.attributes.operStQual }},{{ interface.cdpIf.attributes.portDesc }},{{ interface.cdpIf.attributes.status }}
{%-     endfor %}
{%- elif "cdpInst" in api %}Name,Admin State,Child Action,Control,Device ID Type,DN,Hold Interval,Local Owner,Last Modified,Monitoring Policy DN,Number CDP Hifs,Oper Error,Status,System Name,TX Frequency,Version
{%-     for instance in data_to_template['imdata'] %}
{{ instance.cdpInst.attributes.name }},{{ instance.cdpInst.attributes.adminSt }},{{ instance.cdpInst.attributes.childAction }},{{ instance.cdpInst.attributes.ctrl }},{{ instance.cdpInst.attributes.devIdType }},{{ instance.cdpInst.attributes.dn }},{{ instance.cdpInst.attributes.holdIntvl }},{{ instance.cdpInst.attributes.lcOwn }},{{ instance.cdpInst.attributes.modTs }},{{ instance.cdpInst.attributes.monPolDn }},{{ instance.cdpInst.attributes.numCdpHifs }},{{ instance.cdpInst.attributes.operErr }},{{ instance.cdpInst.attributes.status }},{{ instance.cdpInst.attributes.sysName }},{{ instance.cdpInst.attributes.txFreq }},{{ instance.cdpInst.attributes.ver }}
{%-     endfor %}
{%- elif "cdpIntfAddr" in api %}Address,Child Action,DN,Last Modified,Status
{%-     for address in data_to_template['imdata'] %}
{{ address.cdpIntfAddr.attributes.addr }},{{ address.cdpIntfAddr.attributes.childAction }},{{ address.cdpIntfAddr.attributes.dn }},{{ address.cdpIntfAddr.attributes.modTs }},{{ address.cdpIntfAddr.attributes.status }}
{%-     endfor %}
{%- elif "cdpMgmtAddr" in api %}Address,Child Action,DN,Last Modified,Status
{%-     for address in data_to_template['imdata'] %}
{{ address.cdpMgmtAddr.attributes.addr }},{{ address.cdpMgmtAddr.attributes.childAction }},{{ address.cdpMgmtAddr.attributes.dn }},{{ address.cdpMgmtAddr.attributes.modTs }},{{ address.cdpMgmtAddr.attributes.status }}
{%-     endfor %}
{%- elif "cnwRsMbrIfs" in api %}tDN,Child Action,DN,Force Resolve,Local Owner,Last Modified,Parent SKey,rType,State,State Quality,Status,tCl,tSKey,tType
{%-     for interface in data_to_template['imdata'] %}
{{ interface.cnwRsMbrIfs.attributes.tDn }},{{ interface.cnwRsMbrIfs.attributes.childAction }},{{ interface.cnwRsMbrIfs.attributes.dn }},{{ interface.cnwRsMbrIfs.attributes.forceResolve }},{{ interface.cnwRsMbrIfs.attributes.lcOwn }},{{ interface.cnwRsMbrIfs.attributes.modTs }},{{ interface.cnwRsMbrIfs.attributes.parentSKey }},{{ interface.cnwRsMbrIfs.attributes.rType }},{{ interface.cnwRsMbrIfs.attributes.state }},{{ interface.cnwRsMbrIfs.attributes.stateQual }},{{ interface.cnwRsMbrIfs.attributes.status }},{{ interface.cnwRsMbrIfs.attributes.tCl }},{{ interface.cnwRsMbrIfs.attributes.tSKey }},{{ interface.cnwRsMbrIfs.attributes.tType }}
{%-     endfor %}
{%- elif "compRsDomP" in api %}DN,Child Action,Force Resolve,Local Owner,Last Modified,rType,State,State Quality,Status,tCl,tDn,tType
{%-     for policy in data_to_template['imdata'] %}
{{ policy.compRsDomP.attributes.dn }},{{ policy.compRsDomP.attributes.childAction }},{{ policy.compRsDomP.attributes.forceResolve }},{{ policy.compRsDomP.attributes.lcOwn }},{{ policy.compRsDomP.attributes.modTs }},{{ policy.compRsDomP.attributes.rType }},{{ policy.compRsDomP.attributes.state }},{{ policy.compRsDomP.attributes.stateQual }},{{ policy.compRsDomP.attributes.status }},{{ policy.compRsDomP.attributes.tCl }},{{ policy.compRsDomP.attributes.tDn }},{{ policy.compRsDomP.attributes.tType }}
{%-     endfor %}
{%- elif "eqptBSlot" in api %}ID,Card Oper State,Child Action,Description,DN,Local Owner,Location,Last Modified,Monitoring Policy DN,Oper State,Physical ID,Status,Type
{%-     for slot in data_to_template['imdata'] %}
{{ slot.eqptBSlot.attributes.id }},{{ slot.eqptBSlot.attributes.cardOperSt }},{{ slot.eqptBSlot.attributes.childAction }},{{ slot.eqptBSlot.attributes.descr }},{{ slot.eqptBSlot.attributes.dn }},{{ slot.eqptBSlot.attributes.lcOwn }},{{ slot.eqptBSlot.attributes.loc }},{{ slot.eqptBSlot.attributes.modTs }},{{ slot.eqptBSlot.attributes.monPolDn }},{{ slot.eqptBSlot.attributes.operSt }},{{ slot.eqptBSlot.attributes.physId }},{{ slot.eqptBSlot.attributes.status }},{{ slot.eqptBSlot.attributes.type }}
{%-     endfor %}
{%- elif "eqptBoard" in api %}ID,Child Action,CIMC Version,Description,DN,Hardware Version,Local Owner,MAC B,MAC L,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number P,Oper State,Power State,rd State,Revision,Serial Number,Status,SW CID,Type,Uptime,vID,Vendor
{%-     for board in data_to_template['imdata'] %}
{{ board.eqptBoard.attributes.id }},{{ board.eqptBoard.attributes.childAction }},{{ board.eqptBoard.attributes.cimcVersion }},{{ board.eqptBoard.attributes.descr }},{{ board.eqptBoard.attributes.dn }},{{ board.eqptBoard.attributes.hwVer }},{{ board.eqptBoard.attributes.lcOwn }},{{ board.eqptBoard.attributes.macB }},{{ board.eqptBoard.attributes.macL }},{{ board.eqptBoard.attributes.mfgTm }},{{ board.eqptBoard.attributes.modTs }},{{ board.eqptBoard.attributes.model }},{{ board.eqptBoard.attributes.monPolDn }},{{ board.eqptBoard.attributes.numP }},{{ board.eqptBoard.attributes.operSt }},{{ board.eqptBoard.attributes.pwrSt }},{{ board.eqptBoard.attributes.rdSt }},{{ board.eqptBoard.attributes.rev }},{{ board.eqptBoard.attributes.ser }},{{ board.eqptBoard.attributes.status }},{{ board.eqptBoard.attributes.swCId }},{{ board.eqptBoard.attributes.type }},{{ board.eqptBoard.attributes.upTs }},{{ board.eqptBoard.attributes.vId }},{{ board.eqptBoard.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptCPU" in api %}ID,Architecture,Child Action,CIMC Version,Cores,Cores Enabled,Description,DN,MFG Timestamp,Last Modified,Model,Revision,Serial Number,Socket,Speed,Status,Threads,Vendor
{%-     for cpu in data_to_template['imdata'] %}
{{ cpu.eqptCPU.attributes.id }},{{ cpu.eqptCPU.attributes.arch }},{{ cpu.eqptCPU.attributes.childAction }},{{ cpu.eqptCPU.attributes.cimcVersion }},{{ cpu.eqptCPU.attributes.cores }},{{ cpu.eqptCPU.attributes.coresEn }},{{ cpu.eqptCPU.attributes.descr }},{{ cpu.eqptCPU.attributes.dn }},{{ cpu.eqptCPU.attributes.mfgTm }},{{ cpu.eqptCPU.attributes.modTs }},{{ cpu.eqptCPU.attributes.model }},{{ cpu.eqptCPU.attributes.rev }},{{ cpu.eqptCPU.attributes.ser }},{{ cpu.eqptCPU.attributes.sock }},{{ cpu.eqptCPU.attributes.speed }},{{ cpu.eqptCPU.attributes.status }},{{ cpu.eqptCPU.attributes.thrds }},{{ cpu.eqptCPU.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptCh" in api %}ID,Child Action,CIMC Version,Configured Role,Description,DN,Hybrid Mode,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Oper State,Oper State Quality,Revision,Role,Serial Number,Status,vID,Vendor,Virtual Mode
{%-     for chassis in data_to_template['imdata'] %}
{{ chassis.eqptCh.attributes.id }},{{ chassis.eqptCh.attributes.childAction }},{{ chassis.eqptCh.attributes.cimcVersion }},{{ chassis.eqptCh.attributes.configRole }},{{ chassis.eqptCh.attributes.descr }},{{ chassis.eqptCh.attributes.dn }},{{ chassis.eqptCh.attributes.hybridMode }},{{ chassis.eqptCh.attributes.mfgTm }},{{ chassis.eqptCh.attributes.modTs }},{{ chassis.eqptCh.attributes.model }},{{ chassis.eqptCh.attributes.monPolDn }},{{ chassis.eqptCh.attributes.operSt }},{{ chassis.eqptCh.attributes.operStQual }},{{ chassis.eqptCh.attributes.rev }},{{ chassis.eqptCh.attributes.role }},{{ chassis.eqptCh.attributes.ser }},{{ chassis.eqptCh.attributes.status }},{{ chassis.eqptCh.attributes.vId }},{{ chassis.eqptCh.attributes.vendor | replace(","," ") }},{{ chassis.eqptCh.attributes.virtualMode }}
{%-     endfor %}
{%- elif "eqptDimm" in api %}ID,Acc,Capacity,Child Action,CIMC Version,Description,DN,MGF Timestamp,Last Modified,Model,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for dimm in data_to_template['imdata'] %}
{{ dimm.eqptDimm.attributes.id }},{{ dimm.eqptDimm.attributes.acc }},{{ dimm.eqptDimm.attributes.cap }},{{ dimm.eqptDimm.attributes.childAction }},{{ dimm.eqptDimm.attributes.cimcVersion }},{{ dimm.eqptDimm.attributes.descr }},{{ dimm.eqptDimm.attributes.dn }},{{ dimm.eqptDimm.attributes.mfgTm }},{{ dimm.eqptDimm.attributes.modTs }},{{ dimm.eqptDimm.attributes.model }},{{ dimm.eqptDimm.attributes.operSt }},{{ dimm.eqptDimm.attributes.rev }},{{ dimm.eqptDimm.attributes.ser }},{{ dimm.eqptDimm.attributes.status }},{{ dimm.eqptDimm.attributes.type }},{{ dimm.eqptDimm.attributes.vendor | replace(","," ")}}
{%-     endfor %}
{%- elif "eqptExtCh" in api %}ID,Child Action,CIMC Version,Control FPort SDP Timeout,Description,DN,External Chassis State,MAC Address,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number of MACs,Number of Uplink Ports,Part Number,Revision,Serial Number,Status,Vendor
{%-     for fabricextender in data_to_template['imdata'] %}
{{ fabricextender.eqptExtCh.attributes.id }},{{ fabricextender.eqptExtCh.attributes.childAction }},{{ fabricextender.eqptExtCh.attributes.cimcVersion }},{{ fabricextender.eqptExtCh.attributes.controlFPortSDPTimeout }},{{ fabricextender.eqptExtCh.attributes.descr }},{{ fabricextender.eqptExtCh.attributes.dn }},{{ fabricextender.eqptExtCh.attributes.extChSt }},{{ fabricextender.eqptExtCh.attributes.macAddr }},{{ fabricextender.eqptExtCh.attributes.mfgTm }},{{ fabricextender.eqptExtCh.attributes.modTs }},{{ fabricextender.eqptExtCh.attributes.model }},{{ fabricextender.eqptExtCh.attributes.monPolDn }},{{ fabricextender.eqptExtCh.attributes.numMacs }},{{ fabricextender.eqptExtCh.attributes.numUplinkP }},{{ fabricextender.eqptExtCh.attributes.partNum }},{{ fabricextender.eqptExtCh.attributes.rev }},{{ fabricextender.eqptExtCh.attributes.ser }},{{ fabricextender.eqptExtCh.attributes.status }},{{ fabricextender.eqptExtCh.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptFabP" in api %}ID,Child Action,Description,DN,Flags,Last Modified,Monitoring Policy DN,Speed,Status,Type
{%-     for port in data_to_template['imdata'] %}
{{ port.eqptFabP.attributes.id }},{{ port.eqptFabP.attributes.childAction }},{{ port.eqptFabP.attributes.descr }},{{ port.eqptFabP.attributes.dn }},{{ port.eqptFabP.attributes.flags | replace(","," ") }},{{ port.eqptFabP.attributes.modTs }},{{ port.eqptFabP.attributes.monPolDn }},{{ port.eqptFabP.attributes.speed }},{{ port.eqptFabP.attributes.status }},{{ port.eqptFabP.attributes.type }}
{%-     endfor %}
{%- elif "eqptFan" in api %}ID,Child Action,CIMC Version,Description,Direction,DN,Max Speed,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Oper State,Revision,Serial Number,Speed,Status,vID,Vendor
{%-     for fan in data_to_template['imdata'] %}
{{ fan.eqptFan.attributes.id }},{{ fan.eqptFan.attributes.childAction }},{{ fan.eqptFan.attributes.cimcVersion }},{{ fan.eqptFan.attributes.descr }},{{ fan.eqptFan.attributes.dir }},{{ fan.eqptFan.attributes.dn }},{{ fan.eqptFan.attributes.maxSpeed }},{{ fan.eqptFan.attributes.mfgTm }},{{ fan.eqptFan.attributes.modTs }},{{ fan.eqptFan.attributes.model }},{{ fan.eqptFan.attributes.monPolDn }},{{ fan.eqptFan.attributes.operSt }},{{ fan.eqptFan.attributes.rev }},{{ fan.eqptFan.attributes.ser }},{{ fan.eqptFan.attributes.speed }},{{ fan.eqptFan.attributes.status }},{{ fan.eqptFan.attributes.vId }},{{ fan.eqptFan.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptFpga" in api %}ID,Child Action,CIMC Version,Description,DN,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for array in data_to_template['imdata'] %}
{{ array.eqptFpga.attributes.id }},{{ array.eqptFpga.attributes.childAction }},{{ array.eqptFpga.attributes.cimcVersion }},{{ array.eqptFpga.attributes.descr }},{{ array.eqptFpga.attributes.dn }},{{ array.eqptFpga.attributes.mfgTm }},{{ array.eqptFpga.attributes.modTs }},{{ array.eqptFpga.attributes.model }},{{ array.eqptFpga.attributes.monPolDn }},{{ array.eqptFpga.attributes.operSt }},{{ array.eqptFpga.attributes.rev }},{{ array.eqptFpga.attributes.ser }},{{ array.eqptFpga.attributes.status }},{{ array.eqptFpga.attributes.type }},{{ array.eqptFpga.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptFt" in api %}
{%-     if "Slot" in api %}ID,Card Oper State,Child Action,Description,DN,Location,Last Modified,Monitoring Policy DN,Oper State,Physical ID,Status,Type
{%-         for slot in data_to_template['imdata'] %}
{{ slot.eqptFtSlot.attributes.id }},{{ slot.eqptFtSlot.attributes.cardOperSt }},{{ slot.eqptFtSlot.attributes.childAction }},{{ slot.eqptFtSlot.attributes.descr }},{{ slot.eqptFtSlot.attributes.dn }},{{ slot.eqptFtSlot.attributes.loc }},{{ slot.eqptFtSlot.attributes.modTs }},{{ slot.eqptFtSlot.attributes.monPolDn }},{{ slot.eqptFtSlot.attributes.operSt }},{{ slot.eqptFtSlot.attributes.physId }},{{ slot.eqptFtSlot.attributes.status }},{{ slot.eqptFtSlot.attributes.type }}
{%-         endfor %}
{%-     else %}ID,Child Action,CIMC Version,Description,DN,Fan Name,Fanlet Fail String,Hardware Version,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Oper State,Revision,Serial Number,Status,Vendor
{%-         for trays in data_to_template['imdata'] %}
{{ trays.eqptFt.attributes.id }},{{ trays.eqptFt.attributes.childAction }},{{ trays.eqptFt.attributes.cimcVersion }},{{ trays.eqptFt.attributes.descr }},{{ trays.eqptFt.attributes.dn }},{{ trays.eqptFt.attributes.fanName }},{{ trays.eqptFt.attributes.fanletFailString }},{{ trays.eqptFt.attributes.hwVer }},{{ trays.eqptFt.attributes.mfgTm }},{{ trays.eqptFt.attributes.modTs }},{{ trays.eqptFt.attributes.model }},{{ trays.eqptFt.attributes.monPolDn }},{{ trays.eqptFt.attributes.operSt }},{{ trays.eqptFt.attributes.rev }},{{ trays.eqptFt.attributes.ser }},{{ trays.eqptFt.attributes.status }},{{ trays.eqptFt.attributes.vendor | replace(","," ")}}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptIndLed" in api %}ID,Child Action,CIMC Version,Color,Description,DN,MFG Timestamp,Last Modified,Model,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for led in data_to_template['imdata'] %}
{{ led.eqptIndLed.attributes.id }},{{ led.eqptIndLed.attributes.childAction }},{{ led.eqptIndLed.attributes.cimcVersion }},{{ led.eqptIndLed.attributes.color }},{{ led.eqptIndLed.attributes.descr }},{{ led.eqptIndLed.attributes.dn }},{{ led.eqptIndLed.attributes.mfgTm }},{{ led.eqptIndLed.attributes.modTs }},{{ led.eqptIndLed.attributes.model }},{{ led.eqptIndLed.attributes.operSt }},{{ led.eqptIndLed.attributes.rev }},{{ led.eqptIndLed.attributes.ser }},{{ led.eqptIndLed.attributes.status }},{{ led.eqptIndLed.attributes.type }},{{ led.eqptIndLed.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptLC" in api %}
{%-     if "Slot" in api %}ID,Card Oper State,Child Action,Description,DN,Location,Last Modified,Monitoring Policy DN,Oper State,Physical ID,Status,Type
{%-         for slot in data_to_template['imdata'] %}
{{ slot.eqptLCSlot.attributes.id }},{{ slot.eqptLCSlot.attributes.cardOperSt }},{{ slot.eqptLCSlot.attributes.childAction }},{{ slot.eqptLCSlot.attributes.descr }},{{ slot.eqptLCSlot.attributes.dn }},{{ slot.eqptLCSlot.attributes.loc }},{{ slot.eqptLCSlot.attributes.modTs }},{{ slot.eqptLCSlot.attributes.monPolDn }},{{ slot.eqptLCSlot.attributes.operSt }},{{ slot.eqptLCSlot.attributes.physId }},{{ slot.eqptLCSlot.attributes.status }},{{ slot.eqptLCSlot.attributes.type }}
{%-         endfor %}
{%-     else %}ID,Child Action,CIMC Version,Description,DN,Hardware Version,MAC B,MAC L,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number Ports,Oper State,Power State,rd State,Revision,Serial,Status,Software CID,Type,Uptime,vID,Vendor
{%-         for card in data_to_template['imdata'] %}
{{ card.eqptLC.attributes.id }},{{ card.eqptLC.attributes.childAction }},{{ card.eqptLC.attributes.cimcVersion }},{{ card.eqptLC.attributes.descr }},{{ card.eqptLC.attributes.dn }},{{ card.eqptLC.attributes.hwVer }},{{ card.eqptLC.attributes.macB }},{{ card.eqptLC.attributes.macL }},{{ card.eqptLC.attributes.mfgTm }},{{ card.eqptLC.attributes.modTs }},{{ card.eqptLC.attributes.model }},{{ card.eqptLC.attributes.monPolDn }},{{ card.eqptLC.attributes.numP }},{{ card.eqptLC.attributes.operSt }},{{ card.eqptLC.attributes.pwrSt }},{{ card.eqptLC.attributes.rdSt }},{{ card.eqptLC.attributes.rev }},{{ card.eqptLC.attributes.ser }},{{ card.eqptLC.attributes.status }},{{ card.eqptLC.attributes.swCId }},{{ card.eqptLC.attributes.type }},{{ card.eqptLC.attributes.upTs }},{{ card.eqptLC.attributes.vId }},{{ card.eqptLC.attributes.vendor | replace(","," ") }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptLeafP" in api %}ID,Child Action,Description,DN,Flags,Last Modified,Monitoring Policy DN,Speed,Status,Type
{%-     for port in data_to_template['imdata'] %}
{{ port.eqptLeafP.attributes.id }},{{ port.eqptLeafP.attributes.childAction }},{{ port.eqptLeafP.attributes.descr }},{{ port.eqptLeafP.attributes.dn }},{{ port.eqptLeafP.attributes.flags | replace(","," ") }},{{ port.eqptLeafP.attributes.modTs }},{{ port.eqptLeafP.attributes.monPolDn }},{{ port.eqptLeafP.attributes.speed }},{{ port.eqptLeafP.attributes.status }},{{ port.eqptLeafP.attributes.type }}
{%-     endfor %}
{%- elif "eqptLocLed" in api %}ID,Admin State,Child Action,CIMC Version,Color,Description,DN,MFG Timestamp,Last Modified,Model,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for led in data_to_template['imdata'] %}
{{ led.eqptLocLed.attributes.id }},{{ led.eqptLocLed.attributes.adminSt }},{{ led.eqptLocLed.attributes.childAction }},{{ led.eqptLocLed.attributes.cimcVersion }},{{ led.eqptLocLed.attributes.color }},{{ led.eqptLocLed.attributes.descr }},{{ led.eqptLocLed.attributes.dn }},{{ led.eqptLocLed.attributes.mfgTm }},{{ led.eqptLocLed.attributes.modTs }},{{ led.eqptLocLed.attributes.model }},{{ led.eqptLocLed.attributes.operSt }},{{ led.eqptLocLed.attributes.rev }},{{ led.eqptLocLed.attributes.ser }},{{ led.eqptLocLed.attributes.status }},{{ led.eqptLocLed.attributes.type }},{{ led.eqptLocLed.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptPsu" in api %}
{%-     if "Slot" in api %}ID,Card Oper State,Child Action,Description,DN,Location,Last Modified,Monitoring Policy DN,Oper State,Physical ID,Status,Type
{%-         for slot in data_to_template['imdata'] %}
{{ slot.eqptPsuSlot.attributes.id }},{{ slot.eqptPsuSlot.attributes.cardOperSt }},{{ slot.eqptPsuSlot.attributes.childAction }},{{ slot.eqptPsuSlot.attributes.descr }},{{ slot.eqptPsuSlot.attributes.dn }},{{ slot.eqptPsuSlot.attributes.loc }},{{ slot.eqptPsuSlot.attributes.modTs }},{{ slot.eqptPsuSlot.attributes.monPolDn }},{{ slot.eqptPsuSlot.attributes.operSt }},{{ slot.eqptPsuSlot.attributes.physId }},{{ slot.eqptPsuSlot.attributes.status }},{{ slot.eqptPsuSlot.attributes.type }}
{%-         endfor %}
{%-     else %}ID,Alarm Reg,Capacity,Child Action,CIMC Version,Description,DN,Drawn Current,Fan Oper State,Hardware Version,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Oper State,Revision,Serial Number,Status,TC,vID,vSrc,Vendor,Voltage
{%-         for psu in data_to_template['imdata'] %}
{{ psu.eqptPsu.attributes.id }},{{ psu.eqptPsu.attributes.almReg }},{{ psu.eqptPsu.attributes.cap }},{{ psu.eqptPsu.attributes.childAction }},{{ psu.eqptPsu.attributes.cimcVersion }},{{ psu.eqptPsu.attributes.descr }},{{ psu.eqptPsu.attributes.dn }},{{ psu.eqptPsu.attributes.drawnCurr }},{{ psu.eqptPsu.attributes.fanOpSt }},{{ psu.eqptPsu.attributes.hwVer }},{{ psu.eqptPsu.attributes.mfgTm }},{{ psu.eqptPsu.attributes.modTs }},{{ psu.eqptPsu.attributes.model }},{{ psu.eqptPsu.attributes.monPolDn }},{{ psu.eqptPsu.attributes.operSt }},{{ psu.eqptPsu.attributes.rev }},{{ psu.eqptPsu.attributes.ser }},{{ psu.eqptPsu.attributes.status }},{{ psu.eqptPsu.attributes.tc }},{{ psu.eqptPsu.attributes.vId }},{{ psu.eqptPsu.attributes.vSrc }},{{ psu.eqptPsu.attributes.vendor | replace(","," ") }},{{ psu.eqptPsu.attributes.volt }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptRsIoPPhysConf" in api %}tSKey,Child Action,DN,Force Resolve,Local Owner,Last Modified,rType,State,State Quality,Status,tCL,tDN,tType
{%-     for port in data_to_template['imdata'] %}
{{ port.eqptRsIoPPhysConf.attributes.tSKey }},{{ port.eqptRsIoPPhysConf.attributes.childAction }},{{ port.eqptRsIoPPhysConf.attributes.dn }},{{ port.eqptRsIoPPhysConf.attributes.forceResolve }},{{ port.eqptRsIoPPhysConf.attributes.lcOwn }},{{ port.eqptRsIoPPhysConf.attributes.modTs }},{{ port.eqptRsIoPPhysConf.attributes.rType }},{{ port.eqptRsIoPPhysConf.attributes.state }},{{ port.eqptRsIoPPhysConf.attributes.stateQual }},{{ port.eqptRsIoPPhysConf.attributes.status }},{{ port.eqptRsIoPPhysConf.attributes.tCl }},{{ port.eqptRsIoPPhysConf.attributes.tDn }},{{ port.eqptRsIoPPhysConf.attributes.tType }}
{%-     endfor %}
{%- elif "eqptSensor" in api %}ID,Child Action,CIMC Version,Description,DN,Major Threshold,MFG Timestamp,Minor Threshold,Last Modified,Model,Monitoring Policy DN,Oper State,Revision,Serial Number,Status,Type,Value,Vendor
{%-     for sensor in data_to_template['imdata'] %}
{{ sensor.eqptSensor.attributes.id }},{{ sensor.eqptSensor.attributes.childAction }},{{ sensor.eqptSensor.attributes.cimcVersion }},{{ sensor.eqptSensor.attributes.descr }},{{ sensor.eqptSensor.attributes.dn }},{{ sensor.eqptSensor.attributes.majorThresh }},{{ sensor.eqptSensor.attributes.mfgTm }},{{ sensor.eqptSensor.attributes.minorThresh }},{{ sensor.eqptSensor.attributes.modTs }},{{ sensor.eqptSensor.attributes.model }},{{ sensor.eqptSensor.attributes.monPolDn }},{{ sensor.eqptSensor.attributes.operSt }},{{ sensor.eqptSensor.attributes.rev }},{{ sensor.eqptSensor.attributes.ser }},{{ sensor.eqptSensor.attributes.status }},{{ sensor.eqptSensor.attributes.type }},{{ sensor.eqptSensor.attributes.value }},{{ sensor.eqptSensor.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptSpCmnBlk" in api %}PD Number,Port Number,Child Action,Checksum,CLEI,Count,DN,Eng Bits,Hardware Revision Major,Hardware Revision Minor,Length,Major,MFG Bits,MFG Dev,Minor,Last Modified,OEM,pRevision,Power Consumption,RAM FL,Serial Number,Signature,Size,Status,Vendor ID,Version
{%-     for common_block in data_to_template['imdata'] %}
{{ common_block.eqptSpCmnBlk.attributes.pdNum }},{{ common_block.eqptSpCmnBlk.attributes.prtNum }},{{ common_block.eqptSpCmnBlk.attributes.childAction }},{{ common_block.eqptSpCmnBlk.attributes.cksum }},{{ common_block.eqptSpCmnBlk.attributes.clei }},{{ common_block.eqptSpCmnBlk.attributes.count }},{{ common_block.eqptSpCmnBlk.attributes.dn }},{{ common_block.eqptSpCmnBlk.attributes.engBits }},{{ common_block.eqptSpCmnBlk.attributes.hwRevMaj }},{{ common_block.eqptSpCmnBlk.attributes.hwRevMin }},{{ common_block.eqptSpCmnBlk.attributes.len }},{{ common_block.eqptSpCmnBlk.attributes.major }},{{ common_block.eqptSpCmnBlk.attributes.mfgBits }},{{ common_block.eqptSpCmnBlk.attributes.mfgDev }},{{ common_block.eqptSpCmnBlk.attributes.minor }},{{ common_block.eqptSpCmnBlk.attributes.modTs }},{{ common_block.eqptSpCmnBlk.attributes.oem | replace(","," ") }},{{ common_block.eqptSpCmnBlk.attributes.pRev }},{{ common_block.eqptSpCmnBlk.attributes.pwrCon }},{{ common_block.eqptSpCmnBlk.attributes.ramFl }},{{ common_block.eqptSpCmnBlk.attributes.serNum }},{{ common_block.eqptSpCmnBlk.attributes.sig }},{{ common_block.eqptSpCmnBlk.attributes.size }},{{ common_block.eqptSpCmnBlk.attributes.status }},{{ common_block.eqptSpCmnBlk.attributes.vdrId }},{{ common_block.eqptSpCmnBlk.attributes.ver }}
{%-     endfor %}
{%- elif "eqptSpromLc" in api %}ID,Access,Capacity,Child Action,CIMC Version,Description,DN,Error Reason,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number Blocks,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for lc in data_to_template['imdata'] %}
{{ lc.eqptSpromLc.attributes.id }},{{ lc.eqptSpromLc.attributes.acc }},{{ lc.eqptSpromLc.attributes.cap }},{{ lc.eqptSpromLc.attributes.childAction }},{{ lc.eqptSpromLc.attributes.cimcVersion }},{{ lc.eqptSpromLc.attributes.descr }},{{ lc.eqptSpromLc.attributes.dn }},{{ lc.eqptSpromLc.attributes.errRsn }},{{ lc.eqptSpromLc.attributes.mfgTm }},{{ lc.eqptSpromLc.attributes.modTs }},{{ lc.eqptSpromLc.attributes.model }},{{ lc.eqptSpromLc.attributes.monPolDn }},{{ lc.eqptSpromLc.attributes.numBlk }},{{ lc.eqptSpromLc.attributes.operSt }},{{ lc.eqptSpromLc.attributes.rev }},{{ lc.eqptSpromLc.attributes.ser }},{{ lc.eqptSpromLc.attributes.status }},{{ lc.eqptSpromLc.attributes.type }},{{ lc.eqptSpromLc.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptSpromPsu" in api %}
{%-     if "Blk" in api %}DN,c110v,c220v,Child Action,Checksum,F Bits,Length,Last Modified,Power Supply CMd1,Power Supply CMd2,Power Supply CMd3,Power Supply CMd4,Power Supply CMxMd1,Power Supply CMxMd2,Power Supply CMxMd3,Power Supply CMxMd4,Signature,smOID,Status,Version
{%-         for psu_block in data_to_template['imdata'] %}
{{ psu_block.eqptSpromPsuBlk.attributes.dn }},{{ psu_block.eqptSpromPsuBlk.attributes.c110v }},{{ psu_block.eqptSpromPsuBlk.attributes.c220v }},{{ psu_block.eqptSpromPsuBlk.attributes.childAction }},{{ psu_block.eqptSpromPsuBlk.attributes.cksum }},{{ psu_block.eqptSpromPsuBlk.attributes.fbits }},{{ psu_block.eqptSpromPsuBlk.attributes.len }},{{ psu_block.eqptSpromPsuBlk.attributes.modTs }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMd1 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMd2 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMd3 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMd4 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd1 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd2 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd3 }},{{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd4 }},{{ psu_block.eqptSpromPsuBlk.attributes.sig }},{{ psu_block.eqptSpromPsuBlk.attributes.smOID }},{{ psu_block.eqptSpromPsuBlk.attributes.status }},{{ psu_block.eqptSpromPsuBlk.attributes.ver }}
{%-         endfor %}
{%-     else %}ID,Access,Capacity,Child Action,CIMC Version,Description,DN,Error Reason,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number Blocks,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-         for psu in data_to_template['imdata'] %}
{{ psu.eqptSpromPsu.attributes.id }},{{ psu.eqptSpromPsu.attributes.acc }},{{ psu.eqptSpromPsu.attributes.cap }},{{ psu.eqptSpromPsu.attributes.childAction }},{{ psu.eqptSpromPsu.attributes.cimcVersion }},{{ psu.eqptSpromPsu.attributes.descr }},{{ psu.eqptSpromPsu.attributes.dn }},{{ psu.eqptSpromPsu.attributes.errRsn }},{{ psu.eqptSpromPsu.attributes.mfgTm }},{{ psu.eqptSpromPsu.attributes.modTs }},{{ psu.eqptSpromPsu.attributes.model }},{{ psu.eqptSpromPsu.attributes.monPolDn }},{{ psu.eqptSpromPsu.attributes.numBlk }},{{ psu.eqptSpromPsu.attributes.operSt }},{{ psu.eqptSpromPsu.attributes.rev }},{{ psu.eqptSpromPsu.attributes.ser }},{{ psu.eqptSpromPsu.attributes.status }},{{ psu.eqptSpromPsu.attributes.type }},{{ psu.eqptSpromPsu.attributes.vendor | replace(","," ") }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptSpromSup" in api %}ID,Access,Capacity,Child Action,CIMC Version,Description,DN,Error Reason,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number Blocks,Oper State,Revision,Serial Number,Status,Type,Vendor
{%-     for sup in data_to_template['imdata'] %}
{{ sup.eqptSpromSup.attributes.id }},{{ sup.eqptSpromSup.attributes.acc }},{{ sup.eqptSpromSup.attributes.cap }},{{ sup.eqptSpromSup.attributes.childAction }},{{ sup.eqptSpromSup.attributes.cimcVersion }},{{ sup.eqptSpromSup.attributes.descr }},{{ sup.eqptSpromSup.attributes.dn }},{{ sup.eqptSpromSup.attributes.errRsn }},{{ sup.eqptSpromSup.attributes.mfgTm }},{{ sup.eqptSpromSup.attributes.modTs }},{{ sup.eqptSpromSup.attributes.model }},{{ sup.eqptSpromSup.attributes.monPolDn }},{{ sup.eqptSpromSup.attributes.numBlk }},{{ sup.eqptSpromSup.attributes.operSt }},{{ sup.eqptSpromSup.attributes.rev }},{{ sup.eqptSpromSup.attributes.ser }},{{ sup.eqptSpromSup.attributes.status }},{{ sup.eqptSpromSup.attributes.type }},{{ sup.eqptSpromSup.attributes.vendor | replace(","," ") }}
{%-     endfor %}
{%- elif "eqptStorage" in api %}Name,Name Alias,Available,Blocks,Capacity Utilized,Child Action,Device,DN,Fail Reason,File System,Firmware Version,Local Owner,Media Wearout,Last Modified,Model,Monitoring Policy DN,Mount,Oper State,Serial Number,Status,Used
{%-     for storage in data_to_template['imdata'] %}
{{ storage.eqptStorage.attributes.name }},{{ storage.eqptStorage.attributes.nameAlias }},{{ storage.eqptStorage.attributes.available }},{{ storage.eqptStorage.attributes.blocks }},{{ storage.eqptStorage.attributes.capUtilized }},{{ storage.eqptStorage.attributes.childAction }},{{ storage.eqptStorage.attributes.device }},{{ storage.eqptStorage.attributes.dn }},{{ storage.eqptStorage.attributes.failReason }},{{ storage.eqptStorage.attributes.fileSystem }},{{ storage.eqptStorage.attributes.firmwareVersion }},{{ storage.eqptStorage.attributes.lcOwn }},{{ storage.eqptStorage.attributes.mediaWearout }},{{ storage.eqptStorage.attributes.modTs }},{{ storage.eqptStorage.attributes.model }},{{ storage.eqptStorage.attributes.monPolDn }},{{ storage.eqptStorage.attributes.mount }},{{ storage.eqptStorage.attributes.operSt }},{{ storage.eqptStorage.attributes.serial }},{{ storage.eqptStorage.attributes.status }},{{ storage.eqptStorage.attributes.used }}
{%-     endfor %}
{%- elif "eqptSupC" in api %}
{%-     if "Slot" in api %}ID,Card Oper State,Child Action,Description,DN,Location,Last Modified,Monitoring Policy DN,Oper State,Physical ID,Status,Type
{%-         for slot in data_to_template['imdata'] %}
{{ slot.eqptSupCSlot.attributes.id }},{{ slot.eqptSupCSlot.attributes.cardOperSt }},{{ slot.eqptSupCSlot.attributes.childAction }},{{ slot.eqptSupCSlot.attributes.descr }},{{ slot.eqptSupCSlot.attributes.dn }},{{ slot.eqptSupCSlot.attributes.loc }},{{ slot.eqptSupCSlot.attributes.modTs }},{{ slot.eqptSupCSlot.attributes.monPolDn }},{{ slot.eqptSupCSlot.attributes.operSt }},{{ slot.eqptSupCSlot.attributes.physId }},{{ slot.eqptSupCSlot.attributes.status }},{{ slot.eqptSupCSlot.attributes.type }}
{%-         endfor %}
{%-     else %}ID,Child Action,CIMC Version,Description,DN,Hardware Version,MAC B,MAC L,MFG Timestamp,Last Modified,Model,Monitoring Policy DN,Number of Ports,Oper State,Power State,rd State,Revision,Serial Number,Status,Software CID,Type,Uptime,vID,Vendor
{%-         for supervisor in data_to_template['imdata'] %}
{{ supervisor.eqptSupC.attributes.id }},{{ supervisor.eqptSupC.attributes.childAction }},{{ supervisor.eqptSupC.attributes.cimcVersion }},{{ supervisor.eqptSupC.attributes.descr }},{{ supervisor.eqptSupC.attributes.dn }},{{ supervisor.eqptSupC.attributes.hwVer }},{{ supervisor.eqptSupC.attributes.macB }},{{ supervisor.eqptSupC.attributes.macL }},{{ supervisor.eqptSupC.attributes.mfgTm }},{{ supervisor.eqptSupC.attributes.modTs }},{{ supervisor.eqptSupC.attributes.model }},{{ supervisor.eqptSupC.attributes.monPolDn }},{{ supervisor.eqptSupC.attributes.numP }},{{ supervisor.eqptSupC.attributes.operSt }},{{ supervisor.eqptSupC.attributes.pwrSt }},{{ supervisor.eqptSupC.attributes.rdSt }},{{ supervisor.eqptSupC.attributes.rev }},{{ supervisor.eqptSupC.attributes.ser }},{{ supervisor.eqptSupC.attributes.status }},{{ supervisor.eqptSupC.attributes.swCId }},{{ supervisor.eqptSupC.attributes.type }},{{ supervisor.eqptSupC.attributes.upTs }},{{ supervisor.eqptSupC.attributes.vId }},{{ supervisor.eqptSupC.attributes.vendor | replace(","," ") }}
{%-         endfor %}
{%-     endif %}
{%- elif "ethpmPhysIf" in api %}DN,Access VLAN,Allowed VLANs,Backplane MAC,Bundle Bup ID,Bundle Index,Configured Access VLAN,Confgured Native VLAN,Child Action,Current Error Index,Diagnostics,Encapsulation,Error Display Timer Running,Error VLAN Status Ht,Error VLANs,Hardware Bd ID,Hardware Resource ID,Interface Type,IOD,Last Errors,Last Link State Change,Media,Last Modified,Monitoring Policy DN,Native VLAN,Number of SI,Oper Bitset,Oper Dce Mode,Oper Duplex,Oper EEE Rx Wk Time,Oper EEE State,Oper EEE Tx Wk Time,Oper Error Display Quality,Oper FEC Mode,Oper Flow Control,Oper MDIX,Oper Mode,Oper Mode Detail,Oper Physical En State,Oper Router MAC,Oper Speed,Oper State,Oper State Quality,Oper State Quality Code,Oper VLANs,OS Sum,Port Config Wait Flags,Primary VLAN,Reset Counter,SI List,Status,TX Type,Usage,User Configured Flags,VDC ID
{%-     for interface in data_to_template['imdata'] %}
{{ interface.ethpmPhysIf.attributes.dn }},{{ interface.ethpmPhysIf.attributes.accessVlan }},{{ interface.ethpmPhysIf.attributes.allowedVlans | replace(","," ") }},{{ interface.ethpmPhysIf.attributes.backplaneMac }},{{ interface.ethpmPhysIf.attributes.bundleBupId }},{{ interface.ethpmPhysIf.attributes.bundleIndex }},{{ interface.ethpmPhysIf.attributes.cfgAccessVlan }},{{ interface.ethpmPhysIf.attributes.cfgNativeVlan }},{{ interface.ethpmPhysIf.attributes.childAction }},{{ interface.ethpmPhysIf.attributes.currErrIndex }},{{ interface.ethpmPhysIf.attributes.diags }},{{ interface.ethpmPhysIf.attributes.encap }},{{ interface.ethpmPhysIf.attributes.errDisTimerRunning }},{{ interface.ethpmPhysIf.attributes.errVlanStatusHt }},{{ interface.ethpmPhysIf.attributes.errVlans }},{{ interface.ethpmPhysIf.attributes.hwBdId }},{{ interface.ethpmPhysIf.attributes.hwResourceId }},{{ interface.ethpmPhysIf.attributes.intfT }},{{ interface.ethpmPhysIf.attributes.iod }},{{ interface.ethpmPhysIf.attributes.lastErrors }},{{ interface.ethpmPhysIf.attributes.lastLinkStChg }},{{ interface.ethpmPhysIf.attributes.media }},{{ interface.ethpmPhysIf.attributes.modTs }},{{ interface.ethpmPhysIf.attributes.monPolDn }},{{ interface.ethpmPhysIf.attributes.nativeVlan }},{{ interface.ethpmPhysIf.attributes.numOfSI }},{{ interface.ethpmPhysIf.attributes.operBitset | replace(","," ") }},{{ interface.ethpmPhysIf.attributes.operDceMode }},{{ interface.ethpmPhysIf.attributes.operDuplex }},{{ interface.ethpmPhysIf.attributes.operEEERxWkTime }},{{ interface.ethpmPhysIf.attributes.operEEEState }},{{ interface.ethpmPhysIf.attributes.operEEETxWkTime }},{{ interface.ethpmPhysIf.attributes.operErrDisQual }},{{ interface.ethpmPhysIf.attributes.operFecMode }},{{ interface.ethpmPhysIf.attributes.operFlowCtrl }},{{ interface.ethpmPhysIf.attributes.operMdix }},{{ interface.ethpmPhysIf.attributes.operMode }},{{ interface.ethpmPhysIf.attributes.operModeDetail }},{{ interface.ethpmPhysIf.attributes.operPhyEnSt }},{{ interface.ethpmPhysIf.attributes.operRouterMac }},{{ interface.ethpmPhysIf.attributes.operSpeed }},{{ interface.ethpmPhysIf.attributes.operSt }},{{ interface.ethpmPhysIf.attributes.operStQual }},{{ interface.ethpmPhysIf.attributes.operStQualCode }},{{ interface.ethpmPhysIf.attributes.operVlans | replace(","," ") }},{{ interface.ethpmPhysIf.attributes.osSum }},{{ interface.ethpmPhysIf.attributes.portCfgWaitFlags }},{{ interface.ethpmPhysIf.attributes.primaryVlan }},{{ interface.ethpmPhysIf.attributes.resetCtr }},{{ interface.ethpmPhysIf.attributes.siList }},{{ interface.ethpmPhysIf.attributes.status }},{{ interface.ethpmPhysIf.attributes.txT }},{{ interface.ethpmPhysIf.attributes.usage | replace(","," ") }},{{ interface.ethpmPhysIf.attributes.userCfgdFlags }},{{ interface.ethpmPhysIf.attributes.vdcId }}
{%-     endfor %}
{%- elif "fabricExtPathEpCont" in api %}DN,Child Action,Extended Ch ID,Local Owner,Last Modified,Monitoring Policy DN,Status
{%-     for container in data_to_template['imdata'] %}
{{ container.fabricExtPathEpCont.attributes.dn }},{{ container.fabricExtPathEpCont.attributes.childAction }},{{ container.fabricExtPathEpCont.attributes.extChId }},{{ container.fabricExtPathEpCont.attributes.lcOwn }},{{ container.fabricExtPathEpCont.attributes.modTs }},{{ container.fabricExtPathEpCont.attributes.monPolDn }},{{ container.fabricExtPathEpCont.attributes.status }}
{%-     endfor %}
{%- elif "fabricInst" in api %}Name,Name Alias,Annotation,Child Action,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for instance in data_to_template['imdata'] %}
{{ instance.fabricInst.attributes.name }},{{ instance.fabricInst.attributes.nameAlias }},{{ instance.fabricInst.attributes.annotation }},{{ instance.fabricInst.attributes.childAction }},{{ instance.fabricInst.attributes.dn }},{{ instance.fabricInst.attributes.extMngdBy }},{{ instance.fabricInst.attributes.lcOwn }},{{ instance.fabricInst.attributes.modTs }},{{ instance.fabricInst.attributes.monPolDn }},{{ instance.fabricInst.attributes.ownerKey }},{{ instance.fabricInst.attributes.ownerTag }},{{ instance.fabricInst.attributes.status }},{{ instance.fabricInst.attributes.uid }}
{%-     endfor %}
{%- elif "fabricLink" in api %}
{%-     if "Cont" in api %}Node,DN,Child Action,Local Owner,Last Modified,Monitoring Policy DN,Status
{%-         for container in data_to_template['imdata'] %}
{{ container.fabricLinkCont.attributes.n }},{{ container.fabricLinkCont.attributes.dn }},{{ container.fabricLinkCont.attributes.childAction }},{{ container.fabricLinkCont.attributes.lcOwn }},{{ container.fabricLinkCont.attributes.modTs }},{{ container.fabricLinkCont.attributes.monPolDn }},{{ container.fabricLinkCont.attributes.status }}
{%-         endfor %}
{%-     else %}DN,Child Action,Local Owner,Link State,Last Modified,Monitoring Policy DN,Node 1,Node 2,Port 1,Port 2,Router 1,Router 2,Switch 1,Switch 2,Status,Wiring Issues
{%-         for link in data_to_template['imdata'] %}
{{ link.fabricLink.attributes.dn }},{{ link.fabricLink.attributes.childAction }},{{ link.fabricLink.attributes.lcOwn }},{{ link.fabricLink.attributes.linkState }},{{ link.fabricLink.attributes.modTs }},{{ link.fabricLink.attributes.monPolDn }},{{ link.fabricLink.attributes.n1 }},{{ link.fabricLink.attributes.n2 }},{{ link.fabricLink.attributes.p1 }},{{ link.fabricLink.attributes.p2 }},{{ link.fabricLink.attributes.r1 }},{{ link.fabricLink.attributes.r2 }},{{ link.fabricLink.attributes.s1 }},{{ link.fabricLink.attributes.s2 }},{{ link.fabricLink.attributes.status }},{{ link.fabricLink.attributes.wiringIssues }}
{%-         endfor %}
{%-     endif %}
{%- elif "fabricLooseLink" in api %}Name,Name Alias,Child Action,DN,is Edm Managed,Local Owner,Last Modified,Node DN,Port DN,Status
{%-     for link in data_to_template['imdata'] %}
{{ link.fabricLooseLink.attributes.name }},{{ link.fabricLooseLink.attributes.nameAlias }},{{ link.fabricLooseLink.attributes.childAction }},{{ link.fabricLooseLink.attributes.dn }},{{ link.fabricLooseLink.attributes.isEdmManaged }},{{ link.fabricLooseLink.attributes.lcOwn }},{{ link.fabricLooseLink.attributes.modTs }},{{ link.fabricLooseLink.attributes.nodeDn }},{{ link.fabricLooseLink.attributes.portDn }},{{ link.fabricLooseLink.attributes.status }}
{%-     endfor %}
{%- elif "fabricLooseNode" in api %}Name,Name Alias,Child Action,DN,ID,Is Managed,Local Owner,Manager Key,Last Modified,Monitoring Policy DN,Oper Issues,Pod ID,Status,System Description,System Name
{%-     for node in data_to_template['imdata'] %}
{{ node.fabricLooseNode.attributes.name }},{{ node.fabricLooseNode.attributes.nameAlias }},{{ node.fabricLooseNode.attributes.childAction }},{{ node.fabricLooseNode.attributes.dn }},{{ node.fabricLooseNode.attributes.id }},{{ node.fabricLooseNode.attributes.isManaged }},{{ node.fabricLooseNode.attributes.lcOwn }},{{ node.fabricLooseNode.attributes.mgrKey }},{{ node.fabricLooseNode.attributes.modTs }},{{ node.fabricLooseNode.attributes.monPolDn }},{{ node.fabricLooseNode.attributes.operIssues }},{{ node.fabricLooseNode.attributes.podId }},{{ node.fabricLooseNode.attributes.status }},{{ node.fabricLooseNode.attributes.sysDesc | replace("\n"," ") | replace(","," ")}},{{ node.fabricLooseNode.attributes.sysName }}
{%-     endfor %}
{%- elif "fabricProtPathEpCont" in api %}DN,Child Action,Local Owner,Last Modified,Monitoring Policy DN,Node AId,Node BId,Status
{%-     for container in data_to_template['imdata'] %}
{{ container.fabricProtPathEpCont.attributes.dn }},{{ container.fabricProtPathEpCont.attributes.childAction }},{{ container.fabricProtPathEpCont.attributes.lcOwn }},{{ container.fabricProtPathEpCont.attributes.modTs }},{{ container.fabricProtPathEpCont.attributes.monPolDn }},{{ container.fabricProtPathEpCont.attributes.nodeAId }},{{ container.fabricProtPathEpCont.attributes.nodeBId }},{{ container.fabricProtPathEpCont.attributes.status }}
{%-     endfor %}
{%- elif "fcEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.fcEntity.attributes.name }},{{ entity.fcEntity.attributes.adminSt }},{{ entity.fcEntity.attributes.childAction }},{{ entity.fcEntity.attributes.dn }},{{ entity.fcEntity.attributes.modTs }},{{ entity.fcEntity.attributes.monPolDn }},{{ entity.fcEntity.attributes.operErr }},{{ entity.fcEntity.attributes.operSt }},{{ entity.fcEntity.attributes.status }}
{%-     endfor %}
{%- elif "firmwareCardRunning" in api %}DN,BIOS Version,Child Action,Description,Expected Version,Interim Version,Internal Label,Last Modified,Mode,Monitoring Policy DN,Oper State,sr Firmware Flash Rec Version,sr Firmware Flash Version,sr Firmware Image Version,sr Firmware Running Source,sr Firmware Running Version,Status,Timestamp,Type,Version
{%-     for card in data_to_template['imdata'] %}
{{ card.firmwareCardRunning.attributes.dn }},{{ card.firmwareCardRunning.attributes.biosVer }},{{ card.firmwareCardRunning.attributes.childAction }},{{ card.firmwareCardRunning.attributes.descr }},{{ card.firmwareCardRunning.attributes.expectedVer }},{{ card.firmwareCardRunning.attributes.interimVer }},{{ card.firmwareCardRunning.attributes.internalLabel }},{{ card.firmwareCardRunning.attributes.modTs }},{{ card.firmwareCardRunning.attributes.mode }},{{ card.firmwareCardRunning.attributes.monPolDn }},{{ card.firmwareCardRunning.attributes.operSt }},{{ card.firmwareCardRunning.attributes.srFwFlashRecVer }},{{ card.firmwareCardRunning.attributes.srFwFlashVer }},{{ card.firmwareCardRunning.attributes.srFwImageVer }},{{ card.firmwareCardRunning.attributes.srFwRunningSrc }},{{ card.firmwareCardRunning.attributes.srFwRunningVer }},{{ card.firmwareCardRunning.attributes.status }},{{ card.firmwareCardRunning.attributes.ts }},{{ card.firmwareCardRunning.attributes.type }},{{ card.firmwareCardRunning.attributes.version }}
{%-     endfor %}
{%- elif "firmwareCompRunning" in api %}DN,Child Action,Description,Expected Version,Internal Label,Last Modified,Mode,Monitoring Policy DN,Oper State,Status,Timestamp,Type,Version
{%-     for compute in data_to_template['imdata'] %}
{{ compute.firmwareCompRunning.attributes.dn }},{{ compute.firmwareCompRunning.attributes.childAction }},{{ compute.firmwareCompRunning.attributes.descr }},{{ compute.firmwareCompRunning.attributes.expectedVer }},{{ compute.firmwareCompRunning.attributes.internalLabel }},{{ compute.firmwareCompRunning.attributes.modTs }},{{ compute.firmwareCompRunning.attributes.mode }},{{ compute.firmwareCompRunning.attributes.monPolDn }},{{ compute.firmwareCompRunning.attributes.operSt }},{{ compute.firmwareCompRunning.attributes.status }},{{ compute.firmwareCompRunning.attributes.ts }},{{ compute.firmwareCompRunning.attributes.type }},{{ compute.firmwareCompRunning.attributes.version }}
{%-     endfor %}
{%- elif "firmwareRunning" in api %}DN,BIOS Timestamp,BIOS Version,Child Action,Description,Internal Label,Kickstart File,Last Modified,Mode,PE Version,sr Firmware Flash Rec Timestamp,sr Firmware Flash Rec Version,sr Firmware Flash Timestamp,sr Firmware Flash Version,sr Firmware Image Timestamp,sr Firmware Image Version,sr Firmware Running Source,sr Firmware Running Version,Status,System File,Timestamp,Type,Version
{%-     for firmware in data_to_template['imdata'] %}
{{ firmware.firmwareRunning.attributes.dn }},{{ firmware.firmwareRunning.attributes.biosTs }},{{ firmware.firmwareRunning.attributes.biosVer }},{{ firmware.firmwareRunning.attributes.childAction }},{{ firmware.firmwareRunning.attributes.descr }},{{ firmware.firmwareRunning.attributes.internalLabel }},{{ firmware.firmwareRunning.attributes.ksFile }},{{ firmware.firmwareRunning.attributes.modTs }},{{ firmware.firmwareRunning.attributes.mode }},{{ firmware.firmwareRunning.attributes.peVer }},{{ firmware.firmwareRunning.attributes.srFwFlashRecTs }},{{ firmware.firmwareRunning.attributes.srFwFlashRecVer }},{{ firmware.firmwareRunning.attributes.srFwFlashTs }},{{ firmware.firmwareRunning.attributes.srFwFlashVer }},{{ firmware.firmwareRunning.attributes.srFwImageTs }},{{ firmware.firmwareRunning.attributes.srFwImageVer }},{{ firmware.firmwareRunning.attributes.srFwRunningSrc }},{{ firmware.firmwareRunning.attributes.srFwRunningVer }},{{ firmware.firmwareRunning.attributes.status }},{{ firmware.firmwareRunning.attributes.sysFile }},{{ firmware.firmwareRunning.attributes.ts }},{{ firmware.firmwareRunning.attributes.type }},{{ firmware.firmwareRunning.attributes.version }}
{%-     endfor %}
{%- elif "fvEpPCont" in api %}Name,Name Alias,Aggregation Enabled,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status
{%-     for container in data_to_template['imdata'] %}
{{ container.fvEpPCont.attributes.name }},{{ container.fvEpPCont.attributes.nameAlias }},{{ container.fvEpPCont.attributes.aggrEnabled }},{{ container.fvEpPCont.attributes.childAction }},{{ container.fvEpPCont.attributes.dn }},{{ container.fvEpPCont.attributes.lcOwn }},{{ container.fvEpPCont.attributes.modTs }},{{ container.fvEpPCont.attributes.monPolDn }},{{ container.fvEpPCont.attributes.ownerKey }},{{ container.fvEpPCont.attributes.ownerTag }},{{ container.fvEpPCont.attributes.status }}
{%-     endfor %}
{%- elif "fvLocale" in api %}ID,Boostrap Triggered,Child Action,Deploy All Ports,DN,Fabric Ext Control Peering,Fabric Ext Intersite Control Peering,Fabric Ext Intersite Peering,First Update Deployed,Instruction Immediacy,IPv4 Load Balancer Address,IPv6 Load Balancer Address,Local Owner,Last Modified,Mode Misconfiguration,Monitoring Policy DN,Oper State,Router ID,Router ID Loopback,Status,Summary Needed
{%-     for locale in data_to_template['imdata'] %}
{{ locale.fvLocale.attributes.id }},{{ locale.fvLocale.attributes.boostrapTriggered }},{{ locale.fvLocale.attributes.childAction }},{{ locale.fvLocale.attributes.deployAllPorts }},{{ locale.fvLocale.attributes.dn }},{{ locale.fvLocale.attributes.fabricExtCtrlPeering }},{{ locale.fvLocale.attributes.fabricExtIntersiteCtrlPeering }},{{ locale.fvLocale.attributes.fabricExtIntersitePeering }},{{ locale.fvLocale.attributes.firstUpdateDeployed }},{{ locale.fvLocale.attributes.instrImedcy }},{{ locale.fvLocale.attributes.ipv4LbAddr }},{{ locale.fvLocale.attributes.ipv6LbAddr }},{{ locale.fvLocale.attributes.lcOwn }},{{ locale.fvLocale.attributes.modTs }},{{ locale.fvLocale.attributes.modeMisconfiguration }},{{ locale.fvLocale.attributes.monPolDn }},{{ locale.fvLocale.attributes.operSt }},{{ locale.fvLocale.attributes.rtrId }},{{ locale.fvLocale.attributes.rtrIdLoopBack }},{{ locale.fvLocale.attributes.status }},{{ locale.fvLocale.attributes.summaryNeeded }}
{%-     endfor %}
{%- elif "fvRsBDToOut" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tn L3 Ext Out Name
{%-     for bd in data_to_template['imdata'] %}
{{ bd.fvRsBDToOut.attributes.uid }},{{ bd.fvRsBDToOut.attributes.annotation }},{{ bd.fvRsBDToOut.attributes.childAction }},{{ bd.fvRsBDToOut.attributes.dn }},{{ bd.fvRsBDToOut.attributes.extMngdBy }},{{ bd.fvRsBDToOut.attributes.forceResolve }},{{ bd.fvRsBDToOut.attributes.lcOwn }},{{ bd.fvRsBDToOut.attributes.modTs }},{{ bd.fvRsBDToOut.attributes.monPolDn }},{{ bd.fvRsBDToOut.attributes.rType }},{{ bd.fvRsBDToOut.attributes.state }},{{ bd.fvRsBDToOut.attributes.stateQual }},{{ bd.fvRsBDToOut.attributes.status }},{{ bd.fvRsBDToOut.attributes.tCl }},{{ bd.fvRsBDToOut.attributes.tContextDn }},{{ bd.fvRsBDToOut.attributes.tDn }},{{ bd.fvRsBDToOut.attributes.tRn }},{{ bd.fvRsBDToOut.attributes.tType }},{{ bd.fvRsBDToOut.attributes.tnL3extOutName }}
{%-     endfor %}
{%- elif "fvRsBd" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnFvBDName
{%-     for bd in data_to_template['imdata'] %}
{{ bd.fvRsBd.attributes.uid }},{{ bd.fvRsBd.attributes.annotation }},{{ bd.fvRsBd.attributes.childAction }},{{ bd.fvRsBd.attributes.dn }},{{ bd.fvRsBd.attributes.extMngdBy }},{{ bd.fvRsBd.attributes.forceResolve }},{{ bd.fvRsBd.attributes.lcOwn }},{{ bd.fvRsBd.attributes.modTs }},{{ bd.fvRsBd.attributes.monPolDn }},{{ bd.fvRsBd.attributes.rType }},{{ bd.fvRsBd.attributes.state }},{{ bd.fvRsBd.attributes.stateQual }},{{ bd.fvRsBd.attributes.status }},{{ bd.fvRsBd.attributes.tCl }},{{ bd.fvRsBd.attributes.tContextDn }},{{ bd.fvRsBd.attributes.tDn }},{{ bd.fvRsBd.attributes.tRn }},{{ bd.fvRsBd.attributes.tType }},{{ bd.fvRsBd.attributes.tnFvBDName }}
{%-     endfor %}
{%- elif "fvRsCEpToPathEp" in api %}DN,Child Action,Force Resolve,lcC,Local Owner,Last Modified,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.fvRsCEpToPathEp.attributes.dn }},{{ endpoint.fvRsCEpToPathEp.attributes.childAction }},{{ endpoint.fvRsCEpToPathEp.attributes.forceResolve }},{{ endpoint.fvRsCEpToPathEp.attributes.lcC }},{{ endpoint.fvRsCEpToPathEp.attributes.lcOwn }},{{ endpoint.fvRsCEpToPathEp.attributes.modTs }},{{ endpoint.fvRsCEpToPathEp.attributes.rType }},{{ endpoint.fvRsCEpToPathEp.attributes.state }},{{ endpoint.fvRsCEpToPathEp.attributes.stateQual }},{{ endpoint.fvRsCEpToPathEp.attributes.status }},{{ endpoint.fvRsCEpToPathEp.attributes.tCl }},{{ endpoint.fvRsCEpToPathEp.attributes.tDn }},{{ endpoint.fvRsCEpToPathEp.attributes.tType }}
{%-     endfor %}
{%- elif "fvRsCons" in api %}
{%-     if "If" in api %}UID,Annotation,Child Action,Deployment Info,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,Priority,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnVz CP Interface Name,Update Collection
{%-         for interface in data_to_template['imdata'] %}
{{ interface.fvRsConsIf.attributes.uid }},{{ interface.fvRsConsIf.attributes.annotation }},{{ interface.fvRsConsIf.attributes.childAction }},{{ interface.fvRsConsIf.attributes.deplInfo }},{{ interface.fvRsConsIf.attributes.dn }},{{ interface.fvRsConsIf.attributes.extMngdBy }},{{ interface.fvRsConsIf.attributes.forceResolve }},{{ interface.fvRsConsIf.attributes.lcOwn }},{{ interface.fvRsConsIf.attributes.modTs }},{{ interface.fvRsConsIf.attributes.monPolDn }},{{ interface.fvRsConsIf.attributes.prio }},{{ interface.fvRsConsIf.attributes.rType }},{{ interface.fvRsConsIf.attributes.state }},{{ interface.fvRsConsIf.attributes.stateQual }},{{ interface.fvRsConsIf.attributes.status }},{{ interface.fvRsConsIf.attributes.tCl }},{{ interface.fvRsConsIf.attributes.tContextDn }},{{ interface.fvRsConsIf.attributes.tDn }},{{ interface.fvRsConsIf.attributes.tRn }},{{ interface.fvRsConsIf.attributes.tType }},{{ interface.fvRsConsIf.attributes.tnVzCPIfName }},{{ interface.fvRsConsIf.attributes.updateCollection }}
{%-         endfor %}
{%-     else %}UID,Annotation,Child Action,Contract Update,Deployment Info,DN,Externally Managed By,Force Resolve,Intent,Local Owner,Last Modified,Monitoring Policy DN,Priority,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnVz Br CP Name,Trigger State,Update Collection
{%-         for consumer in data_to_template['imdata'] %}
{{ consumer.fvRsCons.attributes.uid }},{{ consumer.fvRsCons.attributes.annotation }},{{ consumer.fvRsCons.attributes.childAction }},{{ consumer.fvRsCons.attributes.ctrctUpd }},{{ consumer.fvRsCons.attributes.deplInfo }},{{ consumer.fvRsCons.attributes.dn }},{{ consumer.fvRsCons.attributes.extMngdBy }},{{ consumer.fvRsCons.attributes.forceResolve }},{{ consumer.fvRsCons.attributes.intent }},{{ consumer.fvRsCons.attributes.lcOwn }},{{ consumer.fvRsCons.attributes.modTs }},{{ consumer.fvRsCons.attributes.monPolDn }},{{ consumer.fvRsCons.attributes.prio }},{{ consumer.fvRsCons.attributes.rType }},{{ consumer.fvRsCons.attributes.state }},{{ consumer.fvRsCons.attributes.stateQual }},{{ consumer.fvRsCons.attributes.status }},{{ consumer.fvRsCons.attributes.tCl }},{{ consumer.fvRsCons.attributes.tContextDn }},{{ consumer.fvRsCons.attributes.tDn }},{{ consumer.fvRsCons.attributes.tRn }},{{ consumer.fvRsCons.attributes.tType }},{{ consumer.fvRsCons.attributes.tnVzBrCPName }},{{ consumer.fvRsCons.attributes.triggerSt }},{{ consumer.fvRsCons.attributes.updateCollection }}
{%-         endfor %}
{%-     endif %}
{%- elif "fvRsCtx" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnFv Context Name
{%-     for context in data_to_template['imdata'] %}
{{ context.fvRsCtx.attributes.uid }},{{ context.fvRsCtx.attributes.annotation }},{{ context.fvRsCtx.attributes.childAction }},{{ context.fvRsCtx.attributes.dn }},{{ context.fvRsCtx.attributes.extMngdBy }},{{ context.fvRsCtx.attributes.forceResolve }},{{ context.fvRsCtx.attributes.lcOwn }},{{ context.fvRsCtx.attributes.modTs }},{{ context.fvRsCtx.attributes.monPolDn }},{{ context.fvRsCtx.attributes.rType }},{{ context.fvRsCtx.attributes.state }},{{ context.fvRsCtx.attributes.stateQual }},{{ context.fvRsCtx.attributes.status }},{{ context.fvRsCtx.attributes.tCl }},{{ context.fvRsCtx.attributes.tContextDn }},{{ context.fvRsCtx.attributes.tDn }},{{ context.fvRsCtx.attributes.tRn }},{{ context.fvRsCtx.attributes.tType }},{{ context.fvRsCtx.attributes.tnFvCtxName }}
{%-     endfor %}
{%- elif "fvRsDomAtt" in api %}UID,Annotation,Binding Type,Child Action,Class Preference,Config Issues,Custom EPG Name,Delimiter,DN,Encapsulation,Encapsulation Mode,EPG COS,EPG COS Preference,Externally Managed By,Force Resolve,Instruction Immediacy,LAG Policy Name,Local Owner,Last Modified,Mode,Monitoring Policy DN,Netflow Direction,Netflow Preference,Number of Ports,Port Allocation,Primary Encapsulation,Primary Encapsulation Inner,rType,Res Immediacy,Secondary Encapsulation Inner,State,State Quality,Status,Switching Mode,tCl,tDN,tType,Trigger State,TX ID,Untagged,VNET Only
{%-     for attachment in data_to_template['imdata'] %}
{{ attachment.fvRsDomAtt.attributes.uid }},{{ attachment.fvRsDomAtt.attributes.annotation }},{{ attachment.fvRsDomAtt.attributes.bindingType }},{{ attachment.fvRsDomAtt.attributes.childAction }},{{ attachment.fvRsDomAtt.attributes.classPref }},{{ attachment.fvRsDomAtt.attributes.configIssues }},{{ attachment.fvRsDomAtt.attributes.customEpgName }},{{ attachment.fvRsDomAtt.attributes.delimiter }},{{ attachment.fvRsDomAtt.attributes.dn }},{{ attachment.fvRsDomAtt.attributes.encap }},{{ attachment.fvRsDomAtt.attributes.encapMode }},{{ attachment.fvRsDomAtt.attributes.epgCos }},{{ attachment.fvRsDomAtt.attributes.epgCosPref }},{{ attachment.fvRsDomAtt.attributes.extMngdBy }},{{ attachment.fvRsDomAtt.attributes.forceResolve }},{{ attachment.fvRsDomAtt.attributes.instrImedcy }},{{ attachment.fvRsDomAtt.attributes.lagPolicyName }},{{ attachment.fvRsDomAtt.attributes.lcOwn }},{{ attachment.fvRsDomAtt.attributes.modTs }},{{ attachment.fvRsDomAtt.attributes.mode }},{{ attachment.fvRsDomAtt.attributes.monPolDn }},{{ attachment.fvRsDomAtt.attributes.netflowDir }},{{ attachment.fvRsDomAtt.attributes.netflowPref }},{{ attachment.fvRsDomAtt.attributes.numPorts }},{{ attachment.fvRsDomAtt.attributes.portAllocation }},{{ attachment.fvRsDomAtt.attributes.primaryEncap }},{{ attachment.fvRsDomAtt.attributes.primaryEncapInner }},{{ attachment.fvRsDomAtt.attributes.rType }},{{ attachment.fvRsDomAtt.attributes.resImedcy }},{{ attachment.fvRsDomAtt.attributes.secondaryEncapInner }},{{ attachment.fvRsDomAtt.attributes.state }},{{ attachment.fvRsDomAtt.attributes.stateQual }},{{ attachment.fvRsDomAtt.attributes.status }},{{ attachment.fvRsDomAtt.attributes.switchingMode }},{{ attachment.fvRsDomAtt.attributes.tCl }},{{ attachment.fvRsDomAtt.attributes.tDn }},{{ attachment.fvRsDomAtt.attributes.tType }},{{ attachment.fvRsDomAtt.attributes.triggerSt }},{{ attachment.fvRsDomAtt.attributes.txId }},{{ attachment.fvRsDomAtt.attributes.untagged }},{{ attachment.fvRsDomAtt.attributes.vnetOnly }}
{%-     endfor %}
{%- elif "fvRsPathAtt" in api %}UID,Annotation,Child Action,Description,DN,Encapsulation,Externally Managed By,Force Resolve,Instruction Immediacy,lcC,Local Owner,Last Modified,Mode,Monitoring Policy DN,Primary Encapsulation,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for attachment in data_to_template['imdata'] %}
{{ attachment.fvRsPathAtt.attributes.uid }},{{ attachment.fvRsPathAtt.attributes.annotation }},{{ attachment.fvRsPathAtt.attributes.childAction }},{{ attachment.fvRsPathAtt.attributes.descr }},{{ attachment.fvRsPathAtt.attributes.dn }},{{ attachment.fvRsPathAtt.attributes.encap }},{{ attachment.fvRsPathAtt.attributes.extMngdBy }},{{ attachment.fvRsPathAtt.attributes.forceResolve }},{{ attachment.fvRsPathAtt.attributes.instrImedcy }},{{ attachment.fvRsPathAtt.attributes.lcC }},{{ attachment.fvRsPathAtt.attributes.lcOwn }},{{ attachment.fvRsPathAtt.attributes.modTs }},{{ attachment.fvRsPathAtt.attributes.mode }},{{ attachment.fvRsPathAtt.attributes.monPolDn }},{{ attachment.fvRsPathAtt.attributes.primaryEncap }},{{ attachment.fvRsPathAtt.attributes.rType }},{{ attachment.fvRsPathAtt.attributes.state }},{{ attachment.fvRsPathAtt.attributes.stateQual }},{{ attachment.fvRsPathAtt.attributes.status }},{{ attachment.fvRsPathAtt.attributes.tCl }},{{ attachment.fvRsPathAtt.attributes.tDn }},{{ attachment.fvRsPathAtt.attributes.tType }}
{%-     endfor %}
{%- elif "fvRsProv" in api %}UID,Annotation,Child Action,Contract Update,DN,Externally Managed By,Force Resolve,Intent,Local Owner,Match Type,Last Modified,Monitoring Policy DN,Priority,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnVz Br CP Name,Trigger State,Update Collection
{%-     for provider in data_to_template['imdata'] %}
{{ provider.fvRsProv.attributes.uid }},{{ provider.fvRsProv.attributes.annotation }},{{ provider.fvRsProv.attributes.childAction }},{{ provider.fvRsProv.attributes.ctrctUpd }},{{ provider.fvRsProv.attributes.dn }},{{ provider.fvRsProv.attributes.extMngdBy }},{{ provider.fvRsProv.attributes.forceResolve }},{{ provider.fvRsProv.attributes.intent }},{{ provider.fvRsProv.attributes.lcOwn }},{{ provider.fvRsProv.attributes.matchT }},{{ provider.fvRsProv.attributes.modTs }},{{ provider.fvRsProv.attributes.monPolDn }},{{ provider.fvRsProv.attributes.prio }},{{ provider.fvRsProv.attributes.rType }},{{ provider.fvRsProv.attributes.state }},{{ provider.fvRsProv.attributes.stateQual }},{{ provider.fvRsProv.attributes.status }},{{ provider.fvRsProv.attributes.tCl }},{{ provider.fvRsProv.attributes.tContextDn }},{{ provider.fvRsProv.attributes.tDn }},{{ provider.fvRsProv.attributes.tRn }},{{ provider.fvRsProv.attributes.tType }},{{ provider.fvRsProv.attributes.tnVzBrCPName }},{{ provider.fvRsProv.attributes.triggerSt }},{{ provider.fvRsProv.attributes.updateCollection }}
{%-     endfor %}
{%- elif "fvRtBd" in api %}DN,Child Action,Local Owner,Last Modified,Status,tCl,tDN
{%-     for bd in data_to_template['imdata'] %}
{{ bd.fvRtBd.attributes.dn }},{{ bd.fvRtBd.attributes.childAction }},{{ bd.fvRtBd.attributes.lcOwn }},{{ bd.fvRtBd.attributes.modTs }},{{ bd.fvRtBd.attributes.status }},{{ bd.fvRtBd.attributes.tCl }},{{ bd.fvRtBd.attributes.tDn }}
{%-     endfor %}
{%- elif "fvRtCtx" in api %}DN,Child Action,Local Owner,Last Modified,Status,tCl,tDN
{%-     for context in data_to_template['imdata'] %}
{{ context.fvRtCtx.attributes.dn }},{{ context.fvRtCtx.attributes.childAction }},{{ context.fvRtCtx.attributes.lcOwn }},{{ context.fvRtCtx.attributes.modTs }},{{ context.fvRtCtx.attributes.status }},{{ context.fvRtCtx.attributes.tCl }},{{ context.fvRtCtx.attributes.tDn }}
{%-     endfor %}
{%- elif "fvnsEncapBlk" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Description,DN,Externally Managed By,From,To,Local Owner,Last Modified,Monitroing Policy DN,Role,Status,UID
{%-     for vlan in data_to_template['imdata'] %}
{{ vlan.fvnsEncapBlk.attributes.name }},{{ vlan.fvnsEncapBlk.attributes.nameAlias }},{{ vlan.fvnsEncapBlk.attributes.allocMode }},{{ vlan.fvnsEncapBlk.attributes.annotation }},{{ vlan.fvnsEncapBlk.attributes.childAction }},{{ vlan.fvnsEncapBlk.attributes.descr }},{{ vlan.fvnsEncapBlk.attributes.dn }},{{ vlan.fvnsEncapBlk.attributes.extMngdBy }},{{ vlan.fvnsEncapBlk.attributes.from }},{{ vlan.fvnsEncapBlk.attributes.to }},{{ vlan.fvnsEncapBlk.attributes.lcOwn }},{{ vlan.fvnsEncapBlk.attributes.modTs }},{{ vlan.fvnsEncapBlk.attributes.monPolDn }},{{ vlan.fvnsEncapBlk.attributes.role }},{{ vlan.fvnsEncapBlk.attributes.status }},{{ vlan.fvnsEncapBlk.attributes.uid }}
{%-     endfor %}
{%- elif "fvnsVlanInstP" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Config Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for policy in data_to_template['imdata'] %}
{{ policy.fvnsVlanInstP.attributes.name }},{{ policy.fvnsVlanInstP.attributes.nameAlias }},{{ policy.fvnsVlanInstP.attributes.allocMode }},{{ policy.fvnsVlanInstP.attributes.annotation }},{{ policy.fvnsVlanInstP.attributes.childAction }},{{ policy.fvnsVlanInstP.attributes.configIssues }},{{ policy.fvnsVlanInstP.attributes.descr }},{{ policy.fvnsVlanInstP.attributes.dn }},{{ policy.fvnsVlanInstP.attributes.extMngdBy }},{{ policy.fvnsVlanInstP.attributes.lcOwn }},{{ policy.fvnsVlanInstP.attributes.modTs }},{{ policy.fvnsVlanInstP.attributes.monPolDn }},{{ policy.fvnsVlanInstP.attributes.ownerKey }},{{ policy.fvnsVlanInstP.attributes.ownerTag }},{{ policy.fvnsVlanInstP.attributes.status }},{{ policy.fvnsVlanInstP.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccBndlGrp" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,LAG Type,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for group in data_to_template['imdata'] %}
{{ group.infraAccBndlGrp.attributes.name }},{{ group.infraAccBndlGrp.attributes.nameAlias }},{{ group.infraAccBndlGrp.attributes.annotation }},{{ group.infraAccBndlGrp.attributes.childAction }},{{ group.infraAccBndlGrp.attributes.descr }},{{ group.infraAccBndlGrp.attributes.dn }},{{ group.infraAccBndlGrp.attributes.extMngdBy }},{{ group.infraAccBndlGrp.attributes.lagT }},{{ group.infraAccBndlGrp.attributes.lcOwn }},{{ group.infraAccBndlGrp.attributes.modTs }},{{ group.infraAccBndlGrp.attributes.monPolDn }},{{ group.infraAccBndlGrp.attributes.ownerKey }},{{ group.infraAccBndlGrp.attributes.ownerTag }},{{ group.infraAccBndlGrp.attributes.status }},{{ group.infraAccBndlGrp.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccPortGrp" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for group in data_to_template['imdata'] %}
{{ group.infraAccPortGrp.attributes.name }},{{ group.infraAccPortGrp.attributes.nameAlias }},{{ group.infraAccPortGrp.attributes.annotation }},{{ group.infraAccPortGrp.attributes.childAction }},{{ group.infraAccPortGrp.attributes.descr }},{{ group.infraAccPortGrp.attributes.dn }},{{ group.infraAccPortGrp.attributes.extMngdBy }},{{ group.infraAccPortGrp.attributes.lcOwn }},{{ group.infraAccPortGrp.attributes.modTs }},{{ group.infraAccPortGrp.attributes.monPolDn }},{{ group.infraAccPortGrp.attributes.ownerKey }},{{ group.infraAccPortGrp.attributes.ownerTag }},{{ group.infraAccPortGrp.attributes.status }},{{ group.infraAccPortGrp.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraAccPortP.attributes.name }},{{ profile.infraAccPortP.attributes.nameAlias }},{{ profile.infraAccPortP.attributes.annotation }},{{ profile.infraAccPortP.attributes.childAction }},{{ profile.infraAccPortP.attributes.descr }},{{ profile.infraAccPortP.attributes.dn }},{{ profile.infraAccPortP.attributes.extMngdBy }},{{ profile.infraAccPortP.attributes.lcOwn }},{{ profile.infraAccPortP.attributes.modTs }},{{ profile.infraAccPortP.attributes.monPolDn }},{{ profile.infraAccPortP.attributes.ownerKey }},{{ profile.infraAccPortP.attributes.ownerTag }},{{ profile.infraAccPortP.attributes.status }},{{ profile.infraAccPortP.attributes.uid }}
{%-     endfor %}
{%- elif "infraCont" in api %}Name,Name Alias,Child Action,DN,DRR Mode,DSCV Mode,Fabric Domain Name,Local Owner,Last Modified,Monitoring Policy DN,Size,Status,Start Timestamp,UCT Difference
{%-     for controller in data_to_template['imdata'] %}
{{ controller.infraCont.attributes.name }},{{ controller.infraCont.attributes.nameAlias }},{{ controller.infraCont.attributes.childAction }},{{ controller.infraCont.attributes.dn }},{{ controller.infraCont.attributes.drrMd }},{{ controller.infraCont.attributes.dscvMd }},{{ controller.infraCont.attributes.fbDmNm }},{{ controller.infraCont.attributes.lcOwn }},{{ controller.infraCont.attributes.modTs }},{{ controller.infraCont.attributes.monPolDn }},{{ controller.infraCont.attributes.size }},{{ controller.infraCont.attributes.status }},{{ controller.infraCont.attributes.strtTs }},{{ controller.infraCont.attributes.uctDiff }}
{%-     endfor %}
{%- elif "infraFexP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for policy in data_to_template['imdata'] %}
{{ policy.infraFexP.attributes.name }},{{ policy.infraFexP.attributes.nameAlias }},{{ policy.infraFexP.attributes.annotation }},{{ policy.infraFexP.attributes.childAction }},{{ policy.infraFexP.attributes.descr }},{{ policy.infraFexP.attributes.dn }},{{ policy.infraFexP.attributes.extMngdBy }},{{ policy.infraFexP.attributes.lcOwn }},{{ policy.infraFexP.attributes.modTs }},{{ policy.infraFexP.attributes.monPolDn }},{{ policy.infraFexP.attributes.ownerKey }},{{ policy.infraFexP.attributes.ownerTag }},{{ policy.infraFexP.attributes.status }},{{ policy.infraFexP.attributes.uid }}
{%-     endfor %}
{%- elif "infraFuncP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for function in data_to_template['imdata'] %}
{{ function.infraFuncP.attributes.name }},{{ function.infraFuncP.attributes.nameAlias }},{{ function.infraFuncP.attributes.annotation }},{{ function.infraFuncP.attributes.childAction }},{{ function.infraFuncP.attributes.descr }},{{ function.infraFuncP.attributes.dn }},{{ function.infraFuncP.attributes.extMngdBy }},{{ function.infraFuncP.attributes.lcOwn }},{{ function.infraFuncP.attributes.modTs }},{{ function.infraFuncP.attributes.monPolDn }},{{ function.infraFuncP.attributes.ownerKey }},{{ function.infraFuncP.attributes.ownerTag }},{{ function.infraFuncP.attributes.status }},{{ function.infraFuncP.attributes.uid }}
{%-     endfor %}
{%- elif "infraHPortS" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Type,UID
{%-     for port in data_to_template['imdata'] %}
{{ port.infraHPortS.attributes.name }},{{ port.infraHPortS.attributes.nameAlias }},{{ port.infraHPortS.attributes.annotation }},{{ port.infraHPortS.attributes.childAction }},{{ port.infraHPortS.attributes.descr }},{{ port.infraHPortS.attributes.dn }},{{ port.infraHPortS.attributes.extMngdBy }},{{ port.infraHPortS.attributes.lcOwn }},{{ port.infraHPortS.attributes.modTs }},{{ port.infraHPortS.attributes.monPolDn }},{{ port.infraHPortS.attributes.ownerKey }},{{ port.infraHPortS.attributes.ownerTag }},{{ port.infraHPortS.attributes.status }},{{ port.infraHPortS.attributes.type }},{{ port.infraHPortS.attributes.uid }}
{%-     endfor %}
{%- elif "infraPortBlk" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,From Card,To Card,From Port,To Port,Local Owner,Last Modified,Monitoring Policy DN,Status,UID
{%-     for port_block in data_to_template['imdata'] %}
{{ port_block.infraPortBlk.attributes.name }},{{ port_block.infraPortBlk.attributes.nameAlias }},{{ port_block.infraPortBlk.attributes.annotation }},{{ port_block.infraPortBlk.attributes.childAction }},{{ port_block.infraPortBlk.attributes.descr }},{{ port_block.infraPortBlk.attributes.dn }},{{ port_block.infraPortBlk.attributes.extMngdBy }},{{ port_block.infraPortBlk.attributes.fromCard }},{{ port_block.infraPortBlk.attributes.toCard }},{{ port_block.infraPortBlk.attributes.fromPort }},{{ port_block.infraPortBlk.attributes.toPort }},{{ port_block.infraPortBlk.attributes.lcOwn }},{{ port_block.infraPortBlk.attributes.modTs }},{{ port_block.infraPortBlk.attributes.monPolDn }},{{ port_block.infraPortBlk.attributes.status }},{{ port_block.infraPortBlk.attributes.uid }}
{%-     endfor %}
{%- elif "infraRsAccBaseGrp" in api %}UID,Annotation,Child Action,DN,Externally Managed By,FEX ID,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for policy in data_to_template['imdata'] %}
{{ policy.infraRsAccBaseGrp.attributes.uid }},{{ policy.infraRsAccBaseGrp.attributes.annotation }},{{ policy.infraRsAccBaseGrp.attributes.childAction }},{{ policy.infraRsAccBaseGrp.attributes.dn }},{{ policy.infraRsAccBaseGrp.attributes.extMngdBy }},{{ policy.infraRsAccBaseGrp.attributes.fexId }},{{ policy.infraRsAccBaseGrp.attributes.forceResolve }},{{ policy.infraRsAccBaseGrp.attributes.lcOwn }},{{ policy.infraRsAccBaseGrp.attributes.modTs }},{{ policy.infraRsAccBaseGrp.attributes.monPolDn }},{{ policy.infraRsAccBaseGrp.attributes.rType }},{{ policy.infraRsAccBaseGrp.attributes.state }},{{ policy.infraRsAccBaseGrp.attributes.stateQual }},{{ policy.infraRsAccBaseGrp.attributes.status }},{{ policy.infraRsAccBaseGrp.attributes.tCl }},{{ policy.infraRsAccBaseGrp.attributes.tDn }},{{ policy.infraRsAccBaseGrp.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsAttEntP" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Is Using Connection Selector,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraRsAttEntP.attributes.uid }},{{ profile.infraRsAttEntP.attributes.annotation }},{{ profile.infraRsAttEntP.attributes.childAction }},{{ profile.infraRsAttEntP.attributes.dn }},{{ profile.infraRsAttEntP.attributes.extMngdBy }},{{ profile.infraRsAttEntP.attributes.forceResolve }},{{ profile.infraRsAttEntP.attributes.isUsingConnSel }},{{ profile.infraRsAttEntP.attributes.lcOwn }},{{ profile.infraRsAttEntP.attributes.modTs }},{{ profile.infraRsAttEntP.attributes.monPolDn }},{{ profile.infraRsAttEntP.attributes.rType }},{{ profile.infraRsAttEntP.attributes.state }},{{ profile.infraRsAttEntP.attributes.stateQual }},{{ profile.infraRsAttEntP.attributes.status }},{{ profile.infraRsAttEntP.attributes.tCl }},{{ profile.infraRsAttEntP.attributes.tDn }},{{ profile.infraRsAttEntP.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsDomP" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraRsDomP.attributes.uid }},{{ profile.infraRsDomP.attributes.annotation }},{{ profile.infraRsDomP.attributes.childAction }},{{ profile.infraRsDomP.attributes.dn }},{{ profile.infraRsDomP.attributes.extMngdBy }},{{ profile.infraRsDomP.attributes.forceResolve }},{{ profile.infraRsDomP.attributes.lcOwn }},{{ profile.infraRsDomP.attributes.modTs }},{{ profile.infraRsDomP.attributes.monPolDn }},{{ profile.infraRsDomP.attributes.rType }},{{ profile.infraRsDomP.attributes.state }},{{ profile.infraRsDomP.attributes.stateQual }},{{ profile.infraRsDomP.attributes.status }},{{ profile.infraRsDomP.attributes.tCl }},{{ profile.infraRsDomP.attributes.tDn }},{{ profile.infraRsDomP.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsSpAccGrp" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for group in data_to_template['imdata'] %}
{{ group.infraRsSpAccGrp.attributes.uid }},{{ group.infraRsSpAccGrp.attributes.annotation }},{{ group.infraRsSpAccGrp.attributes.childAction }},{{ group.infraRsSpAccGrp.attributes.dn }},{{ group.infraRsSpAccGrp.attributes.extMngdBy }},{{ group.infraRsSpAccGrp.attributes.forceResolve }},{{ group.infraRsSpAccGrp.attributes.lcOwn }},{{ group.infraRsSpAccGrp.attributes.modTs }},{{ group.infraRsSpAccGrp.attributes.monPolDn }},{{ group.infraRsSpAccGrp.attributes.rType }},{{ group.infraRsSpAccGrp.attributes.state }},{{ group.infraRsSpAccGrp.attributes.stateQual }},{{ group.infraRsSpAccGrp.attributes.status }},{{ group.infraRsSpAccGrp.attributes.tCl }},{{ group.infraRsSpAccGrp.attributes.tDn }},{{ group.infraRsSpAccGrp.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsVlanNs" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tType
{%-     for namespace in data_to_template['imdata'] %}
{{ namespace.infraRsVlanNs.attributes.uid }},{{ namespace.infraRsVlanNs.attributes.annotation }},{{ namespace.infraRsVlanNs.attributes.childAction }},{{ namespace.infraRsVlanNs.attributes.dn }},{{ namespace.infraRsVlanNs.attributes.extMngdBy }},{{ namespace.infraRsVlanNs.attributes.forceResolve }},{{ namespace.infraRsVlanNs.attributes.lcOwn }},{{ namespace.infraRsVlanNs.attributes.modTs }},{{ namespace.infraRsVlanNs.attributes.monPolDn }},{{ namespace.infraRsVlanNs.attributes.rType }},{{ namespace.infraRsVlanNs.attributes.state }},{{ namespace.infraRsVlanNs.attributes.stateQual }},{{ namespace.infraRsVlanNs.attributes.status }},{{ namespace.infraRsVlanNs.attributes.tCl }},{{ namespace.infraRsVlanNs.attributes.tDn }},{{ namespace.infraRsVlanNs.attributes.tType }}
{%-     endfor %}
{%- elif "infraSHPortS" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Type,UID
{%-     for selector in data_to_template['imdata'] %}
{{ selector.infraSHPortS.attributes.name }},{{ selector.infraSHPortS.attributes.nameAlias }},{{ selector.infraSHPortS.attributes.annotation }},{{ selector.infraSHPortS.attributes.childAction }},{{ selector.infraSHPortS.attributes.descr }},{{ selector.infraSHPortS.attributes.dn }},{{ selector.infraSHPortS.attributes.extMngdBy }},{{ selector.infraSHPortS.attributes.lcOwn }},{{ selector.infraSHPortS.attributes.modTs }},{{ selector.infraSHPortS.attributes.monPolDn }},{{ selector.infraSHPortS.attributes.ownerKey }},{{ selector.infraSHPortS.attributes.ownerTag }},{{ selector.infraSHPortS.attributes.status }},{{ selector.infraSHPortS.attributes.type }},{{ selector.infraSHPortS.attributes.uid }}
{%-     endfor %}
{%- elif "infraSpAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraSpAccPortP.attributes.name }},{{ profile.infraSpAccPortP.attributes.nameAlias }},{{ profile.infraSpAccPortP.attributes.annotation }},{{ profile.infraSpAccPortP.attributes.childAction }},{{ profile.infraSpAccPortP.attributes.descr }},{{ profile.infraSpAccPortP.attributes.dn }},{{ profile.infraSpAccPortP.attributes.extMngdBy }},{{ profile.infraSpAccPortP.attributes.lcOwn }},{{ profile.infraSpAccPortP.attributes.modTs }},{{ profile.infraSpAccPortP.attributes.monPolDn }},{{ profile.infraSpAccPortP.attributes.ownerKey }},{{ profile.infraSpAccPortP.attributes.ownerTag }},{{ profile.infraSpAccPortP.attributes.status }},{{ profile.infraSpAccPortP.attributes.uid }}
{%-     endfor %}
{%- elif "infraWiNode" in api %}Name,Name Alias,Address,Admin State,Annotation,APIC Mode,Chassis,Child Action,Controller Sbst State,DN,Externally Managed By,Failover Status,Health,ID,Local Owner,Motherboard Serial Number,Last Modified,Monitoring Policy DN,Mutn Timestamp,Node Name,Oper State,Pod ID,Routable IP Address,Status,Target Motherboard Serial Number,UID
{%-     for node in data_to_template['imdata'] %}
{{ node.infraWiNode.attributes.name }},{{ node.infraWiNode.attributes.nameAlias }},{{ node.infraWiNode.attributes.addr }},{{ node.infraWiNode.attributes.adminSt }},{{ node.infraWiNode.attributes.annotation }},{{ node.infraWiNode.attributes.apicMode }},{{ node.infraWiNode.attributes.chassis }},{{ node.infraWiNode.attributes.childAction }},{{ node.infraWiNode.attributes.cntrlSbstState }},{{ node.infraWiNode.attributes.dn }},{{ node.infraWiNode.attributes.extMngdBy }},{{ node.infraWiNode.attributes.failoverStatus }},{{ node.infraWiNode.attributes.health }},{{ node.infraWiNode.attributes.id }},{{ node.infraWiNode.attributes.lcOwn }},{{ node.infraWiNode.attributes.mbSn }},{{ node.infraWiNode.attributes.modTs }},{{ node.infraWiNode.attributes.monPolDn }},{{ node.infraWiNode.attributes.mutnTs }},{{ node.infraWiNode.attributes.nodeName }},{{ node.infraWiNode.attributes.operSt }},{{ node.infraWiNode.attributes.podId }},{{ node.infraWiNode.attributes.routableIpAddr }},{{ node.infraWiNode.attributes.status }},{{ node.infraWiNode.attributes.targetMbSn }},{{ node.infraWiNode.attributes.uid }}
{%-     endfor %}
{%- elif "ipNexthopP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Next Hop Address,Prefix,Status,Type,UID
{%-     for policy in data_to_template['imdata'] %}
{{ policy.ipNexthopP.attributes.name }},{{ policy.ipNexthopP.attributes.nameAlias }},{{ policy.ipNexthopP.attributes.annotation }},{{ policy.ipNexthopP.attributes.childAction }},{{ policy.ipNexthopP.attributes.descr }},{{ policy.ipNexthopP.attributes.dn }},{{ policy.ipNexthopP.attributes.extMngdBy }},{{ policy.ipNexthopP.attributes.lcOwn }},{{ policy.ipNexthopP.attributes.modTs }},{{ policy.ipNexthopP.attributes.monPolDn }},{{ policy.ipNexthopP.attributes.nhAddr }},{{ policy.ipNexthopP.attributes.pref }},{{ policy.ipNexthopP.attributes.status }},{{ policy.ipNexthopP.attributes.type }},{{ policy.ipNexthopP.attributes.uid }}
{%-     endfor %}
{%- elif "ipRouteP" in api %}Name,Name Alias,Aggregate,Annotation,Child Action,Description,DN,Externally Managed By,From Prefix Length,To Prefix Length,IP,Local Owner,Last Modified,Monitoring Policy DN,Prefix,Route Control,Status,Type,UID
{%-     for policy in data_to_template['imdata'] %}
{{ policy.ipRouteP.attributes.name }},{{ policy.ipRouteP.attributes.nameAlias }},{{ policy.ipRouteP.attributes.aggregate }},{{ policy.ipRouteP.attributes.annotation }},{{ policy.ipRouteP.attributes.childAction }},{{ policy.ipRouteP.attributes.descr }},{{ policy.ipRouteP.attributes.dn }},{{ policy.ipRouteP.attributes.extMngdBy }},{{ policy.ipRouteP.attributes.fromPfxLen }},{{ policy.ipRouteP.attributes.toPfxLen }},{{ policy.ipRouteP.attributes.ip }},{{ policy.ipRouteP.attributes.lcOwn }},{{ policy.ipRouteP.attributes.modTs }},{{ policy.ipRouteP.attributes.monPolDn }},{{ policy.ipRouteP.attributes.pref }},{{ policy.ipRouteP.attributes.rtCtrl }},{{ policy.ipRouteP.attributes.status }},{{ policy.ipRouteP.attributes.type }},{{ policy.ipRouteP.attributes.uid }}
{%-     endfor %}
{%- elif "ipv4Addr" in api %}Address,Child Action,Control,DN,IPv4 Config Failed Bmp,IPv4 Config Failed Timestamp,IPv4 Config State,Local Owner,Last Modified,Monitoring Policy DN,Oper State,Oper State Quality,Prefix,Status,Tag,Type,vPC Peer
{%-     for address in data_to_template['imdata'] %}
{{ address.ipv4Addr.attributes.addr }},{{ address.ipv4Addr.attributes.childAction }},{{ address.ipv4Addr.attributes.ctrl }},{{ address.ipv4Addr.attributes.dn }},{{ address.ipv4Addr.attributes.ipv4CfgFailedBmp }},{{ address.ipv4Addr.attributes.ipv4CfgFailedTs }},{{ address.ipv4Addr.attributes.ipv4CfgState }},{{ address.ipv4Addr.attributes.lcOwn }},{{ address.ipv4Addr.attributes.modTs }},{{ address.ipv4Addr.attributes.monPolDn }},{{ address.ipv4Addr.attributes.operSt }},{{ address.ipv4Addr.attributes.operStQual }},{{ address.ipv4Addr.attributes.pref }},{{ address.ipv4Addr.attributes.status }},{{ address.ipv4Addr.attributes.tag }},{{ address.ipv4Addr.attributes.type }},{{ address.ipv4Addr.attributes.vpcPeer }}
{%-     endfor %}
{%- elif "ipv4Dom" in api %}Name,Child Action,DN,Encapsulation,Local Owner,Last Modified,Monitoring Policy DN,Router ID,Status
{%-     for domain in data_to_template['imdata'] %}
{{ domain.ipv4Dom.attributes.name }},{{ domain.ipv4Dom.attributes.childAction }},{{ domain.ipv4Dom.attributes.dn }},{{ domain.ipv4Dom.attributes.encap }},{{ domain.ipv4Dom.attributes.lcOwn }},{{ domain.ipv4Dom.attributes.modTs }},{{ domain.ipv4Dom.attributes.monPolDn }},{{ domain.ipv4Dom.attributes.rtrId }},{{ domain.ipv4Dom.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Entity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.ipv4Entity.attributes.name }},{{ entity.ipv4Entity.attributes.adminSt }},{{ entity.ipv4Entity.attributes.childAction }},{{ entity.ipv4Entity.attributes.dn }},{{ entity.ipv4Entity.attributes.lcOwn }},{{ entity.ipv4Entity.attributes.modTs }},{{ entity.ipv4Entity.attributes.monPolDn }},{{ entity.ipv4Entity.attributes.operErr }},{{ entity.ipv4Entity.attributes.operSt }},{{ entity.ipv4Entity.attributes.status }}
{%-     endfor %}
{%- elif "ipv4If" in api %}Name,Admin State,Child Action,Control,Description,DN,Donor Interface,ID,Local Owner,Last Modified,Mode,Mode External,Monitoring Policy DN,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.ipv4If.attributes.name }},{{ interface.ipv4If.attributes.adminSt }},{{ interface.ipv4If.attributes.childAction }},{{ interface.ipv4If.attributes.ctrl }},{{ interface.ipv4If.attributes.descr }},{{ interface.ipv4If.attributes.dn }},{{ interface.ipv4If.attributes.donorIf }},{{ interface.ipv4If.attributes.id }},{{ interface.ipv4If.attributes.lcOwn }},{{ interface.ipv4If.attributes.modTs }},{{ interface.ipv4If.attributes.mode | replace(","," ") }},{{ interface.ipv4If.attributes.modeExtn | replace(","," ") }},{{ interface.ipv4If.attributes.monPolDn }},{{ interface.ipv4If.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Inst" in api %}Name,Admin State,Child Action,Control,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Status
{%-     for instance in data_to_template['imdata'] %}
{{ instance.ipv4Inst.attributes.name }},{{ instance.ipv4Inst.attributes.adminSt }},{{ instance.ipv4Inst.attributes.childAction }},{{ instance.ipv4Inst.attributes.ctrl }},{{ instance.ipv4Inst.attributes.dn }},{{ instance.ipv4Inst.attributes.lcOwn }},{{ instance.ipv4Inst.attributes.modTs }},{{ instance.ipv4Inst.attributes.monPolDn }},{{ instance.ipv4Inst.attributes.operErr }},{{ instance.ipv4Inst.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Nexthop" in api %}Name,Name Alias,Logical DN,Cached Route Control,Child Action,Context ID,Control,Description,DN,Flags,IPv4 Config Failed Bmp,IPv4 Config Failed Timestamps,IPv4 Config State,Local Owner,Last Modified,Monitoring Policy DN,Next Hop Address,Next Hop Interface,Next Hop VRF,Oper State,Oper State Quality,Prefix,RW Encapsulation,Status,Track ID
{%-     for nexthop in data_to_template['imdata'] %}
{{ nexthop.ipv4Nexthop.attributes.name }},{{ nexthop.ipv4Nexthop.attributes.nameAlias }},{{ nexthop.ipv4Nexthop.attributes.LogicalDn }},{{ nexthop.ipv4Nexthop.attributes.cachedRtCtrl | replace(","," ") }},{{ nexthop.ipv4Nexthop.attributes.childAction }},{{ nexthop.ipv4Nexthop.attributes.contextId }},{{ nexthop.ipv4Nexthop.attributes.ctrl | replace(","," ") }},{{ nexthop.ipv4Nexthop.attributes.descr }},{{ nexthop.ipv4Nexthop.attributes.dn }},{{ nexthop.ipv4Nexthop.attributes.flags | replace(","," ") }},{{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedBmp | replace(","," ") }},{{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedTs }},{{ nexthop.ipv4Nexthop.attributes.ipv4CfgState }},{{ nexthop.ipv4Nexthop.attributes.lcOwn }},{{ nexthop.ipv4Nexthop.attributes.modTs }},{{ nexthop.ipv4Nexthop.attributes.monPolDn }},{{ nexthop.ipv4Nexthop.attributes.nhAddr }},{{ nexthop.ipv4Nexthop.attributes.nhIf }},{{ nexthop.ipv4Nexthop.attributes.nhVrf }},{{ nexthop.ipv4Nexthop.attributes.operSt }},{{ nexthop.ipv4Nexthop.attributes.operStQual }},{{ nexthop.ipv4Nexthop.attributes.pref }},{{ nexthop.ipv4Nexthop.attributes.rwEncap }},{{ nexthop.ipv4Nexthop.attributes.status }},{{ nexthop.ipv4Nexthop.attributes.trackId }}
{%-     endfor %}
{%- elif "ipv4Route" in api %}Name,Name Alias,Child Action,Control,Description,DN,Flush Count,Local Owner,Last Modified,Monitoring Policy DN,PC Tag,Preference,Prefix,Shared Cons Count,Status,Tag,Track ID
{%-     for route in data_to_template['imdata'] %}
{{ route.ipv4Route.attributes.name }},{{ route.ipv4Route.attributes.nameAlias }},{{ route.ipv4Route.attributes.childAction }},{{ route.ipv4Route.attributes.ctrl | replace(","," ") }},{{ route.ipv4Route.attributes.descr }},{{ route.ipv4Route.attributes.dn }},{{ route.ipv4Route.attributes.flushCount }},{{ route.ipv4Route.attributes.lcOwn }},{{ route.ipv4Route.attributes.modTs }},{{ route.ipv4Route.attributes.monPolDn }},{{ route.ipv4Route.attributes.pcTag }},{{ route.ipv4Route.attributes.pref }},{{ route.ipv4Route.attributes.prefix }},{{ route.ipv4Route.attributes.sharedConsCount }},{{ route.ipv4Route.attributes.status }},{{ route.ipv4Route.attributes.tag }},{{ route.ipv4Route.attributes.trackId }}
{%-     endfor %}
{%- elif "isisAdjEp" in api %}Name,BFD Oper State,Child Action,Ckt Type,DN,Hold Expired Timestamp,LAN ID,Last Trans,Last Modified,Monitoring Policy DN,Number Adjacency Transactions,Oper State,Peer Ckt ID,Peer Ckt Priority,Peer Gr Flags,Status,Sys ID,Type
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.isisAdjEp.attributes.name }},{{ endpoint.isisAdjEp.attributes.bfdOperSt }},{{ endpoint.isisAdjEp.attributes.childAction }},{{ endpoint.isisAdjEp.attributes.cktType }},{{ endpoint.isisAdjEp.attributes.dn }},{{ endpoint.isisAdjEp.attributes.holdExpTs }},{{ endpoint.isisAdjEp.attributes.lanId }},{{ endpoint.isisAdjEp.attributes.lastTrans }},{{ endpoint.isisAdjEp.attributes.modTs }},{{ endpoint.isisAdjEp.attributes.monPolDn }},{{ endpoint.isisAdjEp.attributes.numAdjTrans }},{{ endpoint.isisAdjEp.attributes.operSt }},{{ endpoint.isisAdjEp.attributes.peerCktId }},{{ endpoint.isisAdjEp.attributes.peerCktPrio }},{{ endpoint.isisAdjEp.attributes.peerGrFlags }},{{ endpoint.isisAdjEp.attributes.status }},{{ endpoint.isisAdjEp.attributes.sysId }},{{ endpoint.isisAdjEp.attributes.type }}
{%-     endfor %}
{%- elif "isisDTEp" in api %}Name,Child Action,DN,Encapsulation Type,ID,Last Modified,Role,Status,Type
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.isisDTEp.attributes.name }},{{ endpoint.isisDTEp.attributes.childAction }},{{ endpoint.isisDTEp.attributes.dn }},{{ endpoint.isisDTEp.attributes.encapt }},{{ endpoint.isisDTEp.attributes.id }},{{ endpoint.isisDTEp.attributes.modTs }},{{ endpoint.isisDTEp.attributes.role }},{{ endpoint.isisDTEp.attributes.status }},{{ endpoint.isisDTEp.attributes.type | replace(","," ") }}
{%-     endfor %}
{%- elif "isisDom" in api %}
{%-     if "Lvl" in api %}Name,Child Action,Control,Distance,DN,Fast Csnp,Fast LISP,Local Owner,Last Modified,Monitoring Policy DN,Number Routes Summarized,SPF Resynced,SPF Scheduled,Status,Type
{%-         for level in data_to_template['imdata'] %}
{{ level.isisDomLvl.attributes.name }},{{ level.isisDomLvl.attributes.childAction }},{{ level.isisDomLvl.attributes.ctrl }},{{ level.isisDomLvl.attributes.dist }},{{ level.isisDomLvl.attributes.dn }},{{ level.isisDomLvl.attributes.fastCsnp }},{{ level.isisDomLvl.attributes.fastLsp }},{{ level.isisDomLvl.attributes.lcOwn }},{{ level.isisDomLvl.attributes.modTs }},{{ level.isisDomLvl.attributes.monPolDn }},{{ level.isisDomLvl.attributes.numRtSummarized }},{{ level.isisDomLvl.attributes.spfResynced }},{{ level.isisDomLvl.attributes.spfScheduled }},{{ level.isisDomLvl.attributes.status }},{{ level.isisDomLvl.attributes.type }}
{%-         endfor %}
{%-     else %}Name,Aggregation Fabric Adjacency Oper State,Area ID,Bandwidth Reference,Child Action,Context ID,Control,DN,Fast Csnps,Fast Lsps,Local Owner,LISP Purged,LISP Refreshed,LISP Sourced,Max ECMP,Metric Style,Last Modified,Mode,Monitoring Policy DN,MTS Error,MTU,nSel,Oper State,Redistribution Metric,Sequence Wrap Error,SPF Calculated,Status,System ID,System GIPO,System GIPO Oper State,Urib Error
{%-         for domain in data_to_template['imdata'] %}
{{ domain.isisDom.attributes.name }},{{ domain.isisDom.attributes.aggFabAdjOperSt }},{{ domain.isisDom.attributes.areaId }},{{ domain.isisDom.attributes.bwRef }},{{ domain.isisDom.attributes.childAction }},{{ domain.isisDom.attributes.contextId }},{{ domain.isisDom.attributes.ctrl }},{{ domain.isisDom.attributes.dn }},{{ domain.isisDom.attributes.fastCsnps }},{{ domain.isisDom.attributes.fastLsps }},{{ domain.isisDom.attributes.lcOwn }},{{ domain.isisDom.attributes.lspPurged }},{{ domain.isisDom.attributes.lspRefreshed }},{{ domain.isisDom.attributes.lspSourced }},{{ domain.isisDom.attributes.maxEcmp }},{{ domain.isisDom.attributes.metricStyle }},{{ domain.isisDom.attributes.modTs }},{{ domain.isisDom.attributes.mode }},{{ domain.isisDom.attributes.monPolDn }},{{ domain.isisDom.attributes.mtsError }},{{ domain.isisDom.attributes.mtu }},{{ domain.isisDom.attributes.nSel }},{{ domain.isisDom.attributes.operSt }},{{ domain.isisDom.attributes.redistribMetric }},{{ domain.isisDom.attributes.seqWrapError }},{{ domain.isisDom.attributes.spfCalculated }},{{ domain.isisDom.attributes.status }},{{ domain.isisDom.attributes.sysId }},{{ domain.isisDom.attributes.systemGipo }},{{ domain.isisDom.attributes.systemGipoOperSt }},{{ domain.isisDom.attributes.uribError }}
{%-         endfor %}
{%-     endif %}
{%- elif "isisEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.isisEntity.attributes.name }},{{ entity.isisEntity.attributes.adminSt }},{{ entity.isisEntity.attributes.childAction }},{{ entity.isisEntity.attributes.dn }},{{ entity.isisEntity.attributes.lcOwn }},{{ entity.isisEntity.attributes.modTs }},{{ entity.isisEntity.attributes.monPolDn }},{{ entity.isisEntity.attributes.operErr }},{{ entity.isisEntity.attributes.operSt }},{{ entity.isisEntity.attributes.status }}
{%-     endfor %}
{%- elif "isisIf" in api %}
{%-     if "Lvl" in api %}Name,Child Action,Csnp Interval,DN,Hello Interval,Hello Mult,Local Owner,Last Modified,Monitoring Policy DN,Next Csnp Timestamp,Priority,Protocol Error,Status,Type
{%-         for level in data_to_template['imdata'] %}
{{ level.isisIfLvl.attributes.name }},{{ level.isisIfLvl.attributes.childAction }},{{ level.isisIfLvl.attributes.csnpIntvl }},{{ level.isisIfLvl.attributes.dn }},{{ level.isisIfLvl.attributes.helloIntvl }},{{ level.isisIfLvl.attributes.helloMult }},{{ level.isisIfLvl.attributes.lcOwn }},{{ level.isisIfLvl.attributes.modTs }},{{ level.isisIfLvl.attributes.monPolDn }},{{ level.isisIfLvl.attributes.nextCsnpTs }},{{ level.isisIfLvl.attributes.priority }},{{ level.isisIfLvl.attributes.protoError }},{{ level.isisIfLvl.attributes.status }},{{ level.isisIfLvl.attributes.type }}
{%-         endfor %}
{%-     else %}Name,Admin State,Child Action,Ckt Type,Control,Description,DN,Extended Local Ckt ID,ID,IIB Index,IIB State,IIB Up Control,Init Error,Local Owner,Local Ckt ID,LISP Refresh Interval,Metric,Last Modified,Monitoring Policy DN,Next IIH Timestamp,P2P Ckt ID,Status
{%-         for interface in data_to_template['imdata'] %}
{{ interface.isisIf.attributes.name }},{{ interface.isisIf.attributes.adminSt }},{{ interface.isisIf.attributes.childAction }},{{ interface.isisIf.attributes.cktT }},{{ interface.isisIf.attributes.ctrl | replace(","," ")}},{{ interface.isisIf.attributes.descr }},{{ interface.isisIf.attributes.dn }},{{ interface.isisIf.attributes.extdLocalCktId }},{{ interface.isisIf.attributes.id }},{{ interface.isisIf.attributes.iibIdx }},{{ interface.isisIf.attributes.iibState }},{{ interface.isisIf.attributes.iibUpCtrl }},{{ interface.isisIf.attributes.initError }},{{ interface.isisIf.attributes.lcOwn }},{{ interface.isisIf.attributes.localCktId }},{{ interface.isisIf.attributes.lspRefreshIntvl }},{{ interface.isisIf.attributes.metric }},{{ interface.isisIf.attributes.modTs }},{{ interface.isisIf.attributes.monPolDn }},{{ interface.isisIf.attributes.nextIIHTs }},{{ interface.isisIf.attributes.p2pCktId }},{{ interface.isisIf.attributes.status }}
{%-         endfor %}
{%-     endif %}
{%- elif "isisInst" in api %}Name,Admin State,Child Action,Control,DN,Duplicate System ID Error,Local Owner,Memory Alert,Last Modified,Monitoring Policy DN,MTS Error,Oper Error,Oper State,Process Queue,Process Sap,Process Tag,Protocol Error,PSS Error,Status
{%-     for instance in data_to_template['imdata'] %}
{{ instance.isisInst.attributes.name }},{{ instance.isisInst.attributes.adminSt }},{{ instance.isisInst.attributes.childAction }},{{ instance.isisInst.attributes.ctrl }},{{ instance.isisInst.attributes.dn }},{{ instance.isisInst.attributes.dupSysIdErr }},{{ instance.isisInst.attributes.lcOwn }},{{ instance.isisInst.attributes.memAlert }},{{ instance.isisInst.attributes.modTs }},{{ instance.isisInst.attributes.monPolDn }},{{ instance.isisInst.attributes.mtsErr }},{{ instance.isisInst.attributes.operErr }},{{ instance.isisInst.attributes.operSt }},{{ instance.isisInst.attributes.processQueue }},{{ instance.isisInst.attributes.processSap }},{{ instance.isisInst.attributes.processTag }},{{ instance.isisInst.attributes.protoErr }},{{ instance.isisInst.attributes.pssErr }},{{ instance.isisInst.attributes.status }}
{%-     endfor %}
{%- elif "isisNexthop" in api %}Name,Address,Child Action,DN,Interface,Last Modified,Next Hop Interface,Status
{%-     for nexthop in data_to_template['imdata'] %}
{{ nexthop.isisNexthop.attributes.name }},{{ nexthop.isisNexthop.attributes.addr }},{{ nexthop.isisNexthop.attributes.childAction }},{{ nexthop.isisNexthop.attributes.dn }},{{ nexthop.isisNexthop.attributes.if }},{{ nexthop.isisNexthop.attributes.modTs }},{{ nexthop.isisNexthop.attributes.nhIf }},{{ nexthop.isisNexthop.attributes.status }}
{%-     endfor %}
{%- elif "isisRoute" in api %}Name,Child Action,DN,Metric,Last Modified,Monitoring Policy DN,Prefix,Preference,Status
{%-     for route in data_to_template['imdata'] %}
{{ route.isisRoute.attributes.name }},{{ route.isisRoute.attributes.childAction }},{{ route.isisRoute.attributes.dn }},{{ route.isisRoute.attributes.metric }},{{ route.isisRoute.attributes.modTs }},{{ route.isisRoute.attributes.monPolDn }},{{ route.isisRoute.attributes.pfx }},{{ route.isisRoute.attributes.pref }},{{ route.isisRoute.attributes.status }}
{%-     endfor %}
{%- elif "l2BD" in api %}Name,Access Encapsulation,Address,Admin State,BD Def DN,Bridge Mode,Child Action,Created,Control,DN,Endpoint Move Detect Mode,Endpoint Oper State,Endpoint Oper State Quality,Endpoint Up Sequence Number,Fabric Encapsulation,Forward Control,Forward Mode,Hardware ID,Hardware Resource ID,Hardware Shadow ID,ID,IPv6 Multicast Allow,Local Owner,Multicast Allow,Multicast Oper State,Last Modified,Mode,Monitoring Policy DN,Multi Destination Packet Action,Oper State,PC Tag,Q in Q L2 Protocol Tunnel Mask,QOS Priority,Status,Type,Unknown MAC Unicast Action,Unknown Multicast Action,v6 Unknown Multicast Action,VLAN Manager Config Failed Bmp,VLAN Manager Config Failed Timestamp,VLAN Manager Config State,VLAN Manager Custom Fault Bmp
{%-     for bd in data_to_template['imdata'] %}
{{ bd.l2BD.attributes.name }},{{ bd.l2BD.attributes.accEncap }},{{ bd.l2BD.attributes.addr }},{{ bd.l2BD.attributes.adminSt }},{{ bd.l2BD.attributes.bdDefDn }},{{ bd.l2BD.attributes.bridgeMode }},{{ bd.l2BD.attributes.childAction }},{{ bd.l2BD.attributes.createTs }},{{ bd.l2BD.attributes.ctrl }},{{ bd.l2BD.attributes.dn }},{{ bd.l2BD.attributes.epMoveDetectMode }},{{ bd.l2BD.attributes.epOperSt }},{{ bd.l2BD.attributes.epOperStQual }},{{ bd.l2BD.attributes.epUpSeqNum }},{{ bd.l2BD.attributes.fabEncap }},{{ bd.l2BD.attributes.fwdCtrl | replace(","," ") }},{{ bd.l2BD.attributes.fwdMode | replace(","," ") }},{{ bd.l2BD.attributes.hwId }},{{ bd.l2BD.attributes.hwResourceId }},{{ bd.l2BD.attributes.hwShadowId }},{{ bd.l2BD.attributes.id }},{{ bd.l2BD.attributes.ipv6McastAllow }},{{ bd.l2BD.attributes.lcOwn }},{{ bd.l2BD.attributes.mcastAllow }},{{ bd.l2BD.attributes.mcastOperSt }},{{ bd.l2BD.attributes.modTs }},{{ bd.l2BD.attributes.mode }},{{ bd.l2BD.attributes.monPolDn }},{{ bd.l2BD.attributes.multiDstPktAct }},{{ bd.l2BD.attributes.operSt }},{{ bd.l2BD.attributes.pcTag }},{{ bd.l2BD.attributes.qiqL2ProtTunMask }},{{ bd.l2BD.attributes.qosPrio }},{{ bd.l2BD.attributes.status }},{{ bd.l2BD.attributes.type }},{{ bd.l2BD.attributes.unkMacUcastAct }},{{ bd.l2BD.attributes.unkMcastAct }},{{ bd.l2BD.attributes.v6unkMcastAct }},{{ bd.l2BD.attributes.vlanmgrCfgFailedBmp }},{{ bd.l2BD.attributes.vlanmgrCfgFailedTs }},{{ bd.l2BD.attributes.vlanmgrCfgState }},{{ bd.l2BD.attributes.vlanmgrCustFaultBmp }}
{%-     endfor %}
{%- elif "l2ExtIf" in api %}Name,Child Action,Description,DN,External Chassis ID,ID,Local Owner,Last Modified,Monitoring Policy DN,SAT Manager Config Failed Bmp,SAT Manager Config Failed Timestamp,SAT Manager Config State,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l2ExtIf.attributes.name }},{{ interface.l2ExtIf.attributes.childAction }},{{ interface.l2ExtIf.attributes.descr }},{{ interface.l2ExtIf.attributes.dn }},{{ interface.l2ExtIf.attributes.extChasId }},{{ interface.l2ExtIf.attributes.id }},{{ interface.l2ExtIf.attributes.lcOwn }},{{ interface.l2ExtIf.attributes.modTs }},{{ interface.l2ExtIf.attributes.monPolDn }},{{ interface.l2ExtIf.attributes.satmgrCfgFailedBmp }},{{ interface.l2ExtIf.attributes.satmgrCfgFailedTs }},{{ interface.l2ExtIf.attributes.satmgrCfgState }},{{ interface.l2ExtIf.attributes.status }}
{%-     endfor %}
{%- elif "l2RsEthIf" in api %}DN,Child Action,Force Resolve,Local Owner,Last Modified,Parent Source Key,rType,State,State Quality,Status,tCl,tDN,tSKey,tType
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l2RsEthIf.attributes.dn }},{{ interface.l2RsEthIf.attributes.childAction }},{{ interface.l2RsEthIf.attributes.forceResolve }},{{ interface.l2RsEthIf.attributes.lcOwn }},{{ interface.l2RsEthIf.attributes.modTs }},{{ interface.l2RsEthIf.attributes.parentSKey }},{{ interface.l2RsEthIf.attributes.rType }},{{ interface.l2RsEthIf.attributes.state }},{{ interface.l2RsEthIf.attributes.stateQual }},{{ interface.l2RsEthIf.attributes.status }},{{ interface.l2RsEthIf.attributes.tCl }},{{ interface.l2RsEthIf.attributes.tDn }},{{ interface.l2RsEthIf.attributes.tSKey }},{{ interface.l2RsEthIf.attributes.tType }}
{%-     endfor %}
{%- elif "l2extInstP" in api %}Name,Name Alias,Annotation,Child Action,Config Issues,Config State,Description,DN,Exception Tag,Externally Managed By,Flood On Encapsulation,Is Shared Service Multisite EPG,Local Owner,Match Type,Last Modified,Monitoring Policy DN,PC Enforced Preference,PC Tag,Preferred Group Member,Priority,Scope,Status,Target DSCP,Trigger State,TX ID,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.l2extInstP.attributes.name }},{{ profile.l2extInstP.attributes.nameAlias }},{{ profile.l2extInstP.attributes.annotation }},{{ profile.l2extInstP.attributes.childAction }},{{ profile.l2extInstP.attributes.configIssues }},{{ profile.l2extInstP.attributes.configSt }},{{ profile.l2extInstP.attributes.descr }},{{ profile.l2extInstP.attributes.dn }},{{ profile.l2extInstP.attributes.exceptionTag }},{{ profile.l2extInstP.attributes.extMngdBy }},{{ profile.l2extInstP.attributes.floodOnEncap }},{{ profile.l2extInstP.attributes.isSharedSrvMsiteEPg }},{{ profile.l2extInstP.attributes.lcOwn }},{{ profile.l2extInstP.attributes.matchT }},{{ profile.l2extInstP.attributes.modTs }},{{ profile.l2extInstP.attributes.monPolDn }},{{ profile.l2extInstP.attributes.pcEnfPref }},{{ profile.l2extInstP.attributes.pcTag }},{{ profile.l2extInstP.attributes.prefGrMemb }},{{ profile.l2extInstP.attributes.prio }},{{ profile.l2extInstP.attributes.scope }},{{ profile.l2extInstP.attributes.status }},{{ profile.l2extInstP.attributes.targetDscp }},{{ profile.l2extInstP.attributes.triggerSt }},{{ profile.l2extInstP.attributes.txId }},{{ profile.l2extInstP.attributes.uid }}
{%-     endfor %}
{%- elif "l2extLIfP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Tag,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.l2extLIfP.attributes.name }},{{ profile.l2extLIfP.attributes.nameAlias }},{{ profile.l2extLIfP.attributes.annotation }},{{ profile.l2extLIfP.attributes.childAction }},{{ profile.l2extLIfP.attributes.descr }},{{ profile.l2extLIfP.attributes.dn }},{{ profile.l2extLIfP.attributes.extMngdBy }},{{ profile.l2extLIfP.attributes.lcOwn }},{{ profile.l2extLIfP.attributes.modTs }},{{ profile.l2extLIfP.attributes.monPolDn }},{{ profile.l2extLIfP.attributes.ownerKey }},{{ profile.l2extLIfP.attributes.ownerTag }},{{ profile.l2extLIfP.attributes.status }},{{ profile.l2extLIfP.attributes.tag }},{{ profile.l2extLIfP.attributes.uid }}
{%-     endfor %}
{%- elif "l2extLNodeP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Tag,UID
{%-     for node in data_to_template['imdata'] %}
{{ node.l2extLNodeP.attributes.name }},{{ node.l2extLNodeP.attributes.nameAlias }},{{ node.l2extLNodeP.attributes.annotation }},{{ node.l2extLNodeP.attributes.childAction }},{{ node.l2extLNodeP.attributes.descr }},{{ node.l2extLNodeP.attributes.dn }},{{ node.l2extLNodeP.attributes.extMngdBy }},{{ node.l2extLNodeP.attributes.lcOwn }},{{ node.l2extLNodeP.attributes.modTs }},{{ node.l2extLNodeP.attributes.monPolDn }},{{ node.l2extLNodeP.attributes.ownerKey }},{{ node.l2extLNodeP.attributes.ownerTag }},{{ node.l2extLNodeP.attributes.status }},{{ node.l2extLNodeP.attributes.tag }},{{ node.l2extLNodeP.attributes.uid }}
{%-     endfor %}
{%- elif "l2extRsEBd" in api %}UID,Annotation,Child Action,DN,Encapsulation,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnFv Bridge Domain Name
{%-     for epg in data_to_template['imdata'] %}
{{ epg.l2extRsEBd.attributes.uid }},{{ epg.l2extRsEBd.attributes.annotation }},{{ epg.l2extRsEBd.attributes.childAction }},{{ epg.l2extRsEBd.attributes.dn }},{{ epg.l2extRsEBd.attributes.encap }},{{ epg.l2extRsEBd.attributes.extMngdBy }},{{ epg.l2extRsEBd.attributes.forceResolve }},{{ epg.l2extRsEBd.attributes.lcOwn }},{{ epg.l2extRsEBd.attributes.modTs }},{{ epg.l2extRsEBd.attributes.monPolDn }},{{ epg.l2extRsEBd.attributes.rType }},{{ epg.l2extRsEBd.attributes.state }},{{ epg.l2extRsEBd.attributes.stateQual }},{{ epg.l2extRsEBd.attributes.status }},{{ epg.l2extRsEBd.attributes.tCl }},{{ epg.l2extRsEBd.attributes.tContextDn }},{{ epg.l2extRsEBd.attributes.tDn }},{{ epg.l2extRsEBd.attributes.tRn }},{{ epg.l2extRsEBd.attributes.tType }},{{ epg.l2extRsEBd.attributes.tnFvBDName }}
{%-     endfor %}
{%- elif "l2extRsPathL2OutAtt" in api %}UID,Annotation,Child Action,Description,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,rType,State,State Quality,Status,tCl,tDn,tType,Target DSCP
{%-     for path in data_to_template['imdata'] %}
{{ path.l2extRsPathL2OutAtt.attributes.uid }},{{ path.l2extRsPathL2OutAtt.attributes.annotation }},{{ path.l2extRsPathL2OutAtt.attributes.childAction }},{{ path.l2extRsPathL2OutAtt.attributes.descr }},{{ path.l2extRsPathL2OutAtt.attributes.dn }},{{ path.l2extRsPathL2OutAtt.attributes.extMngdBy }},{{ path.l2extRsPathL2OutAtt.attributes.forceResolve }},{{ path.l2extRsPathL2OutAtt.attributes.lcOwn }},{{ path.l2extRsPathL2OutAtt.attributes.modTs }},{{ path.l2extRsPathL2OutAtt.attributes.rType }},{{ path.l2extRsPathL2OutAtt.attributes.state }},{{ path.l2extRsPathL2OutAtt.attributes.stateQual }},{{ path.l2extRsPathL2OutAtt.attributes.status }},{{ path.l2extRsPathL2OutAtt.attributes.tCl }},{{ path.l2extRsPathL2OutAtt.attributes.tDn }},{{ path.l2extRsPathL2OutAtt.attributes.tType }},{{ path.l2extRsPathL2OutAtt.attributes.targetDscp }}
{%-     endfor %}
{%- elif "l3Ctx" in api %}Name,Admin State,Bridge Domain Enforced Enable,BGP RD,BGP RD Display,Child Action,Created,Context P Key,DN,Encapsulation,GSDB Context,Hardware Resource ID,ID,IP Learning Disable,L3 VM Config Failed Bmp,L3 VM Config Failed Timestamp,L3 VM Config State,Last Changed Timestamp,Local Owner,Management PC Tag,Last Modified,Monitoring Policy DN,NG AVS,Old Oper State Quality,Oper State Quality,Oper State,OUI,PC Enforced Direction,PC Enforced Preference,PC Tag,Pending,Port CL Bmp,Resource ID,Scope,Status,Type,v4 TIB ID,v4 TIB Name,v4 TIB Old Oper State Quality,v4 TIB Oper State Quality,v4 TIB Oper State,v4 TIB Pending,v4 TIB Valid,v6 TIB ID,v6 TIB Name,v6 TIB Old Oper State Quality,v6 TIB Oper State Quality,v6 TIB Oper State,v6 TIB Pending,v6 TIB Valid,VPN ID
{%-     for context in data_to_template['imdata'] %}
{{ context.l3Ctx.attributes.name }},{{ context.l3Ctx.attributes.adminState }},{{ context.l3Ctx.attributes.bdEnforcedEnable }},{{ context.l3Ctx.attributes.bgpRd | replace(","," ") }},{{ context.l3Ctx.attributes.bgpRdDisp }},{{ context.l3Ctx.attributes.childAction }},{{ context.l3Ctx.attributes.createTs }},{{ context.l3Ctx.attributes.ctxPKey }},{{ context.l3Ctx.attributes.dn }},{{ context.l3Ctx.attributes.encap }},{{ context.l3Ctx.attributes.gsdbCtx }},{{ context.l3Ctx.attributes.hwResourceId }},{{ context.l3Ctx.attributes.id }},{{ context.l3Ctx.attributes.ipLearnDisable }},{{ context.l3Ctx.attributes.l3vmCfgFailedBmp }},{{ context.l3Ctx.attributes.l3vmCfgFailedTs }},{{ context.l3Ctx.attributes.l3vmCfgState }},{{ context.l3Ctx.attributes.lastChgdTs }},{{ context.l3Ctx.attributes.lcOwn }},{{ context.l3Ctx.attributes.mgmtPcTag }},{{ context.l3Ctx.attributes.modTs }},{{ context.l3Ctx.attributes.monPolDn }},{{ context.l3Ctx.attributes.ngAvs }},{{ context.l3Ctx.attributes.oldOperStQual }},{{ context.l3Ctx.attributes.operStQual }},{{ context.l3Ctx.attributes.operState }},{{ context.l3Ctx.attributes.oui }},{{ context.l3Ctx.attributes.pcEnfDir }},{{ context.l3Ctx.attributes.pcEnfPref }},{{ context.l3Ctx.attributes.pcTag }},{{ context.l3Ctx.attributes.pending }},{{ context.l3Ctx.attributes.prtclBmp }},{{ context.l3Ctx.attributes.resourceId }},{{ context.l3Ctx.attributes.scope }},{{ context.l3Ctx.attributes.status }},{{ context.l3Ctx.attributes.type }},{{ context.l3Ctx.attributes.v4TibId }},{{ context.l3Ctx.attributes.v4TibName }},{{ context.l3Ctx.attributes.v4TibOldOperStQual }},{{ context.l3Ctx.attributes.v4TibOperStQual }},{{ context.l3Ctx.attributes.v4TibOperState }},{{ context.l3Ctx.attributes.v4TibPending }},{{ context.l3Ctx.attributes.v4TibValid }},{{ context.l3Ctx.attributes.v6TibId }},{{ context.l3Ctx.attributes.v6TibName }},{{ context.l3Ctx.attributes.v6TibOldOperStQual }},{{ context.l3Ctx.attributes.v6TibOperStQual }},{{ context.l3Ctx.attributes.v6TibOperState }},{{ context.l3Ctx.attributes.v6TibPending }},{{ context.l3Ctx.attributes.v6TibValid }},{{ context.l3Ctx.attributes.vpnId }}
{%-     endfor %}
{%- elif "l3EncRtdIf" in api %}Name,Admin State,Bandwidth,Child Action,Delay,Description,DN,Encapsulation,Ethernet PM Config Failed Bmp,Ethernet PM Config Failed Timestamp,Ethernet PM Config State,ID,Interface Connection DN,Local Owner,Link Log Enable,Last Modified,Monitoring Policy DN,MTU,MTU Inherit,QOS Priority,Router MAC,Routed Out Def DN,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l3EncRtdIf.attributes.name }},{{ interface.l3EncRtdIf.attributes.adminSt }},{{ interface.l3EncRtdIf.attributes.bw }},{{ interface.l3EncRtdIf.attributes.childAction }},{{ interface.l3EncRtdIf.attributes.delay }},{{ interface.l3EncRtdIf.attributes.descr }},{{ interface.l3EncRtdIf.attributes.dn }},{{ interface.l3EncRtdIf.attributes.encap }},{{ interface.l3EncRtdIf.attributes.ethpmCfgFailedBmp }},{{ interface.l3EncRtdIf.attributes.ethpmCfgFailedTs }},{{ interface.l3EncRtdIf.attributes.ethpmCfgState }},{{ interface.l3EncRtdIf.attributes.id }},{{ interface.l3EncRtdIf.attributes.ifConnDn }},{{ interface.l3EncRtdIf.attributes.lcOwn }},{{ interface.l3EncRtdIf.attributes.linkLogEn }},{{ interface.l3EncRtdIf.attributes.modTs }},{{ interface.l3EncRtdIf.attributes.monPolDn }},{{ interface.l3EncRtdIf.attributes.mtu }},{{ interface.l3EncRtdIf.attributes.mtuInherit }},{{ interface.l3EncRtdIf.attributes.qosPrio }},{{ interface.l3EncRtdIf.attributes.routerMac }},{{ interface.l3EncRtdIf.attributes.rtdOutDefDn }},{{ interface.l3EncRtdIf.attributes.status }}
{%-     endfor %}
{%- elif "l3Inst" in api %}Name,Admin State,BGP RD,BGP RD Display,Child Action,Created,Context P Key,DN,Encapsulation,GSDB Context,ID,L3 VM Config Failed Bmp,L3 VM Config Failed Timestamp,L3 VM Config State,Last Chaged,Local Owner,Last Modified,Monitoring Policy DN,Old Oper State Quality,Oper State Quality,Oper State,OUI,Pending,Protocol Bmp,Resource ID,Scope,Status,v4 TIB ID,v4 TIB Name,v4 TIB Old Oper State Quality,v4 TIB Oper State Quality,v4 TIB Oper State,v4 TIB Pending,v4 TIB Valid,v6 TIB ID,v6 TIB Name,v6 TIB Old Oper State Quality,v6 TIB Oper State Quality,v6 TIB Oper State,v6 TIB Pending,v6 TIB Valid,VPN ID
{%-     for instance in data_to_template['imdata'] %}
{{ instance.l3Inst.attributes.name }},{{ instance.l3Inst.attributes.adminState }},{{ instance.l3Inst.attributes.bgpRd | replace(","," ") }},{{ instance.l3Inst.attributes.bgpRdDisp }},{{ instance.l3Inst.attributes.childAction }},{{ instance.l3Inst.attributes.createTs }},{{ instance.l3Inst.attributes.ctxPKey }},{{ instance.l3Inst.attributes.dn }},{{ instance.l3Inst.attributes.encap }},{{ instance.l3Inst.attributes.gsdbCtx }},{{ instance.l3Inst.attributes.id }},{{ instance.l3Inst.attributes.l3vmCfgFailedBmp }},{{ instance.l3Inst.attributes.l3vmCfgFailedTs }},{{ instance.l3Inst.attributes.l3vmCfgState }},{{ instance.l3Inst.attributes.lastChgdTs }},{{ instance.l3Inst.attributes.lcOwn }},{{ instance.l3Inst.attributes.modTs }},{{ instance.l3Inst.attributes.monPolDn }},{{ instance.l3Inst.attributes.oldOperStQual }},{{ instance.l3Inst.attributes.operStQual }},{{ instance.l3Inst.attributes.operState }},{{ instance.l3Inst.attributes.oui }},{{ instance.l3Inst.attributes.pending }},{{ instance.l3Inst.attributes.prtclBmp }},{{ instance.l3Inst.attributes.resourceId }},{{ instance.l3Inst.attributes.scope }},{{ instance.l3Inst.attributes.status }},{{ instance.l3Inst.attributes.v4TibId }},{{ instance.l3Inst.attributes.v4TibName }},{{ instance.l3Inst.attributes.v4TibOldOperStQual }},{{ instance.l3Inst.attributes.v4TibOperStQual }},{{ instance.l3Inst.attributes.v4TibOperState }},{{ instance.l3Inst.attributes.v4TibPending }},{{ instance.l3Inst.attributes.v4TibValid }},{{ instance.l3Inst.attributes.v6TibId }},{{ instance.l3Inst.attributes.v6TibName }},{{ instance.l3Inst.attributes.v6TibOldOperStQual }},{{ instance.l3Inst.attributes.v6TibOperStQual }},{{ instance.l3Inst.attributes.v6TibOperState }},{{ instance.l3Inst.attributes.v6TibPending }},{{ instance.l3Inst.attributes.v6TibValid }},{{ instance.l3Inst.attributes.vpnId }}
{%-     endfor %}
{%- elif "l3LbRtdIf" in api %}Name,Admin State,Child Action,Description,DN,ID,Local Owner,Link Log,Last Modified,Monitoring Policy DN,QOS Priority,Routed Out Def DN,Status,Type
{%-     for loopback in data_to_template['imdata'] %}
{{ loopback.l3LbRtdIf.attributes.name }},{{ loopback.l3LbRtdIf.attributes.adminSt }},{{ loopback.l3LbRtdIf.attributes.childAction }},{{ loopback.l3LbRtdIf.attributes.descr }},{{ loopback.l3LbRtdIf.attributes.dn }},{{ loopback.l3LbRtdIf.attributes.id }},{{ loopback.l3LbRtdIf.attributes.lcOwn }},{{ loopback.l3LbRtdIf.attributes.linkLog }},{{ loopback.l3LbRtdIf.attributes.modTs }},{{ loopback.l3LbRtdIf.attributes.monPolDn }},{{ loopback.l3LbRtdIf.attributes.qosPrio }},{{ loopback.l3LbRtdIf.attributes.rtdOutDefDn }},{{ loopback.l3LbRtdIf.attributes.status }},{{ loopback.l3LbRtdIf.attributes.type }}
{%-     endfor %}
{%- elif "l3RsEncPhysRtdConf" in api %}DN,Child Action,Force Resolve,Local Owner,Last Modified,Parent S Key,rType,State,State Quality,Status,tCl,tDN,tSKey,tType
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l3RsEncPhysRtdConf.attributes.dn }},{{ interface.l3RsEncPhysRtdConf.attributes.childAction }},{{ interface.l3RsEncPhysRtdConf.attributes.forceResolve }},{{ interface.l3RsEncPhysRtdConf.attributes.lcOwn }},{{ interface.l3RsEncPhysRtdConf.attributes.modTs }},{{ interface.l3RsEncPhysRtdConf.attributes.parentSKey }},{{ interface.l3RsEncPhysRtdConf.attributes.rType }},{{ interface.l3RsEncPhysRtdConf.attributes.state }},{{ interface.l3RsEncPhysRtdConf.attributes.stateQual }},{{ interface.l3RsEncPhysRtdConf.attributes.status }},{{ interface.l3RsEncPhysRtdConf.attributes.tCl }},{{ interface.l3RsEncPhysRtdConf.attributes.tDn }},{{ interface.l3RsEncPhysRtdConf.attributes.tSKey }},{{ interface.l3RsEncPhysRtdConf.attributes.tType }}
{%-     endfor %}
{%- elif "l3RtdIf" in api %}Name,Admin State,Child Action,Description,DN,ID,Local Owner,Last Modified,Monitoring Policy DN,QOS Priority,Routed Out Def DN,Status
{%-     for interface in data_to_template['imdata'] %}
{{ interface.l3RtdIf.attributes.name }},{{ interface.l3RtdIf.attributes.adminSt }},{{ interface.l3RtdIf.attributes.childAction }},{{ interface.l3RtdIf.attributes.descr }},{{ interface.l3RtdIf.attributes.dn }},{{ interface.l3RtdIf.attributes.id }},{{ interface.l3RtdIf.attributes.lcOwn }},{{ interface.l3RtdIf.attributes.modTs }},{{ interface.l3RtdIf.attributes.monPolDn }},{{ interface.l3RtdIf.attributes.qosPrio }},{{ interface.l3RtdIf.attributes.rtdOutDefDn }},{{ interface.l3RtdIf.attributes.status }}
{%-     endfor %}
{%- elif "l3extInstP" in api %}Name,Name Alias,Annotation,Child Action,Config Issues,Config State,Description,DN,Exception Tag,Externally Managed By,Flood On Encapsulation,Is Shared Service Multisite EPG,Local Owner,Match Type,Multicast,Last Modified,Monitoring Policy DN,PC Tag,Preferred Group Member,Priority,Scope,Status,Target DSCP,Trigger State,TX ID,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.l3extInstP.attributes.name }},{{ profile.l3extInstP.attributes.nameAlias }},{{ profile.l3extInstP.attributes.annotation }},{{ profile.l3extInstP.attributes.childAction }},{{ profile.l3extInstP.attributes.configIssues }},{{ profile.l3extInstP.attributes.configSt }},{{ profile.l3extInstP.attributes.descr }},{{ profile.l3extInstP.attributes.dn }},{{ profile.l3extInstP.attributes.exceptionTag }},{{ profile.l3extInstP.attributes.extMngdBy }},{{ profile.l3extInstP.attributes.floodOnEncap }},{{ profile.l3extInstP.attributes.isSharedSrvMsiteEPg }},{{ profile.l3extInstP.attributes.lcOwn }},{{ profile.l3extInstP.attributes.matchT }},{{ profile.l3extInstP.attributes.mcast }},{{ profile.l3extInstP.attributes.modTs }},{{ profile.l3extInstP.attributes.monPolDn }},{{ profile.l3extInstP.attributes.pcTag }},{{ profile.l3extInstP.attributes.prefGrMemb }},{{ profile.l3extInstP.attributes.prio }},{{ profile.l3extInstP.attributes.scope }},{{ profile.l3extInstP.attributes.status }},{{ profile.l3extInstP.attributes.targetDscp }},{{ profile.l3extInstP.attributes.triggerSt }},{{ profile.l3extInstP.attributes.txId }},{{ profile.l3extInstP.attributes.uid }}
{%-     endfor %}
{%- elif "l3extIp" in api %}Name,Name Alias,Address,Annotation,Child Action,Description,DN,Externally Managed By,IPv6 DAD,Local Owner,Last Modified,Monitoring Policy DN,Status,UID
{%-     for ip in data_to_template['imdata'] %}
{{ ip.l3extIp.attributes.name }},{{ ip.l3extIp.attributes.nameAlias }},{{ ip.l3extIp.attributes.addr }},{{ ip.l3extIp.attributes.annotation }},{{ ip.l3extIp.attributes.childAction }},{{ ip.l3extIp.attributes.descr }},{{ ip.l3extIp.attributes.dn }},{{ ip.l3extIp.attributes.extMngdBy }},{{ ip.l3extIp.attributes.ipv6Dad }},{{ ip.l3extIp.attributes.lcOwn }},{{ ip.l3extIp.attributes.modTs }},{{ ip.l3extIp.attributes.monPolDn }},{{ ip.l3extIp.attributes.status }},{{ ip.l3extIp.attributes.uid }}
{%-     endfor %}
{%- elif "l3extLIfP" in api %}Name,Name Alias,Address,Annotation,Child Action,Description,DN,Encapsulation,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Priority,Status,Tag,Target DSCP,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.l3extLIfP.attributes.name }},{{ profile.l3extLIfP.attributes.nameAlias }},{{ profile.l3extLIfP.attributes.addr }},{{ profile.l3extLIfP.attributes.annotation }},{{ profile.l3extLIfP.attributes.childAction }},{{ profile.l3extLIfP.attributes.descr }},{{ profile.l3extLIfP.attributes.dn }},{{ profile.l3extLIfP.attributes.encap }},{{ profile.l3extLIfP.attributes.extMngdBy }},{{ profile.l3extLIfP.attributes.lcOwn }},{{ profile.l3extLIfP.attributes.modTs }},{{ profile.l3extLIfP.attributes.monPolDn }},{{ profile.l3extLIfP.attributes.ownerKey }},{{ profile.l3extLIfP.attributes.ownerTag }},{{ profile.l3extLIfP.attributes.prio }},{{ profile.l3extLIfP.attributes.status }},{{ profile.l3extLIfP.attributes.tag }},{{ profile.l3extLIfP.attributes.targetDscp }},{{ profile.l3extLIfP.attributes.uid }}
{%-     endfor %}
{%- elif "l3extLNodeP" in api %}Name,Name Alias,Annotation,Child Action,Config Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Tag,Target DSCP,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.l3extLNodeP.attributes.name }},{{ profile.l3extLNodeP.attributes.nameAlias }},{{ profile.l3extLNodeP.attributes.annotation }},{{ profile.l3extLNodeP.attributes.childAction }},{{ profile.l3extLNodeP.attributes.configIssues }},{{ profile.l3extLNodeP.attributes.descr }},{{ profile.l3extLNodeP.attributes.dn }},{{ profile.l3extLNodeP.attributes.extMngdBy }},{{ profile.l3extLNodeP.attributes.lcOwn }},{{ profile.l3extLNodeP.attributes.modTs }},{{ profile.l3extLNodeP.attributes.monPolDn }},{{ profile.l3extLNodeP.attributes.ownerKey }},{{ profile.l3extLNodeP.attributes.ownerTag }},{{ profile.l3extLNodeP.attributes.status }},{{ profile.l3extLNodeP.attributes.tag }},{{ profile.l3extLNodeP.attributes.targetDscp }},{{ profile.l3extLNodeP.attributes.uid }}
{%-     endfor %}
{%- elif "l3extMember" in api %}Name,Name Alias,Address,Annotation,Child Action,Description,DN,Externally Managed By,IPv6 DAD,Local Owner,Logical Link Address,Last Modified,Monitoring Policy DN,Side,Status,UID
{%-     for member in data_to_template['imdata'] %}
{{ member.l3extMember.attributes.name }},{{ member.l3extMember.attributes.nameAlias }},{{ member.l3extMember.attributes.addr }},{{ member.l3extMember.attributes.annotation }},{{ member.l3extMember.attributes.childAction }},{{ member.l3extMember.attributes.descr }},{{ member.l3extMember.attributes.dn }},{{ member.l3extMember.attributes.extMngdBy }},{{ member.l3extMember.attributes.ipv6Dad }},{{ member.l3extMember.attributes.lcOwn }},{{ member.l3extMember.attributes.llAddr }},{{ member.l3extMember.attributes.modTs }},{{ member.l3extMember.attributes.monPolDn }},{{ member.l3extMember.attributes.side }},{{ member.l3extMember.attributes.status }},{{ member.l3extMember.attributes.uid }}
{%-     endfor %}
{%- elif "l3extRsEctx" in api %}UID,Annotation,Child Action,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tContext DN,tDN,tRN,tType,tnFv Context Name
{%-     for context in data_to_template['imdata'] %}
{{ context.l3extRsEctx.attributes.uid }},{{ context.l3extRsEctx.attributes.annotation }},{{ context.l3extRsEctx.attributes.childAction }},{{ context.l3extRsEctx.attributes.dn }},{{ context.l3extRsEctx.attributes.extMngdBy }},{{ context.l3extRsEctx.attributes.forceResolve }},{{ context.l3extRsEctx.attributes.lcOwn }},{{ context.l3extRsEctx.attributes.modTs }},{{ context.l3extRsEctx.attributes.monPolDn }},{{ context.l3extRsEctx.attributes.rType }},{{ context.l3extRsEctx.attributes.state }},{{ context.l3extRsEctx.attributes.stateQual }},{{ context.l3extRsEctx.attributes.status }},{{ context.l3extRsEctx.attributes.tCl }},{{ context.l3extRsEctx.attributes.tContextDn }},{{ context.l3extRsEctx.attributes.tDn }},{{ context.l3extRsEctx.attributes.tRn }},{{ context.l3extRsEctx.attributes.tType }},{{ context.l3extRsEctx.attributes.tnFvCtxName }}
{%-     endfor %}
{%- elif "l3extRsL3DomAtt" in api %}UID,Annotation,Child Action,DN,External Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDn,tType
{%-     for domain in data_to_template['imdata'] %}
{{ domain.l3extRsL3DomAtt.attributes.uid }},{{ domain.l3extRsL3DomAtt.attributes.annotation }},{{ domain.l3extRsL3DomAtt.attributes.childAction }},{{ domain.l3extRsL3DomAtt.attributes.dn }},{{ domain.l3extRsL3DomAtt.attributes.extMngdBy }},{{ domain.l3extRsL3DomAtt.attributes.forceResolve }},{{ domain.l3extRsL3DomAtt.attributes.lcOwn }},{{ domain.l3extRsL3DomAtt.attributes.modTs }},{{ domain.l3extRsL3DomAtt.attributes.monPolDn }},{{ domain.l3extRsL3DomAtt.attributes.rType }},{{ domain.l3extRsL3DomAtt.attributes.state }},{{ domain.l3extRsL3DomAtt.attributes.stateQual }},{{ domain.l3extRsL3DomAtt.attributes.status }},{{ domain.l3extRsL3DomAtt.attributes.tCl }},{{ domain.l3extRsL3DomAtt.attributes.tDn }},{{ domain.l3extRsL3DomAtt.attributes.tType }}
{%-     endfor %}
{%- elif "l3extRsNodeL3OutAtt" in api %}UID,Annotation,Child Action,Config Issues,DN,Externally Managed By,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,Router ID,Router ID Loopback,State,State Quality,Status,tCl,tDn,tType
{%-     for node in data_to_template['imdata'] %}
{{ node.l3extRsNodeL3OutAtt.attributes.uid }},{{ node.l3extRsNodeL3OutAtt.attributes.annotation }},{{ node.l3extRsNodeL3OutAtt.attributes.childAction }},{{ node.l3extRsNodeL3OutAtt.attributes.configIssues }},{{ node.l3extRsNodeL3OutAtt.attributes.dn }},{{ node.l3extRsNodeL3OutAtt.attributes.extMngdBy }},{{ node.l3extRsNodeL3OutAtt.attributes.forceResolve }},{{ node.l3extRsNodeL3OutAtt.attributes.lcOwn }},{{ node.l3extRsNodeL3OutAtt.attributes.modTs }},{{ node.l3extRsNodeL3OutAtt.attributes.monPolDn }},{{ node.l3extRsNodeL3OutAtt.attributes.rType }},{{ node.l3extRsNodeL3OutAtt.attributes.rtrId }},{{ node.l3extRsNodeL3OutAtt.attributes.rtrIdLoopBack }},{{ node.l3extRsNodeL3OutAtt.attributes.state }},{{ node.l3extRsNodeL3OutAtt.attributes.stateQual }},{{ node.l3extRsNodeL3OutAtt.attributes.status }},{{ node.l3extRsNodeL3OutAtt.attributes.tCl }},{{ node.l3extRsNodeL3OutAtt.attributes.tDn }},{{ node.l3extRsNodeL3OutAtt.attributes.tType }}
{%-     endfor %}
{%- elif "l3extRsPathL3OutAtt" in api %}UID,Address,Annotation,Auto State,Child Action,Config Issues,Description,DN,Encapsulation,Encapsulation Scope,Externally Managed By,Force Resolve,Interface Instance Type,IPv6 DAD,Local Owner,Link Local Address,MAC,Last Modified,Mode,Monitoring Policy DN,MTU,rType,State,State Quality,Status,tCl,tDN,tType,Target DSCP
{%-     for path in data_to_template['imdata'] %}
{{ path.l3extRsPathL3OutAtt.attributes.uid }},{{ path.l3extRsPathL3OutAtt.attributes.addr }},{{ path.l3extRsPathL3OutAtt.attributes.annotation }},{{ path.l3extRsPathL3OutAtt.attributes.autostate }},{{ path.l3extRsPathL3OutAtt.attributes.childAction }},{{ path.l3extRsPathL3OutAtt.attributes.configIssues }},{{ path.l3extRsPathL3OutAtt.attributes.descr }},{{ path.l3extRsPathL3OutAtt.attributes.dn }},{{ path.l3extRsPathL3OutAtt.attributes.encap }},{{ path.l3extRsPathL3OutAtt.attributes.encapScope }},{{ path.l3extRsPathL3OutAtt.attributes.extMngdBy }},{{ path.l3extRsPathL3OutAtt.attributes.forceResolve }},{{ path.l3extRsPathL3OutAtt.attributes.ifInstT }},{{ path.l3extRsPathL3OutAtt.attributes.ipv6Dad }},{{ path.l3extRsPathL3OutAtt.attributes.lcOwn }},{{ path.l3extRsPathL3OutAtt.attributes.llAddr }},{{ path.l3extRsPathL3OutAtt.attributes.mac }},{{ path.l3extRsPathL3OutAtt.attributes.modTs }},{{ path.l3extRsPathL3OutAtt.attributes.mode }},{{ path.l3extRsPathL3OutAtt.attributes.monPolDn }},{{ path.l3extRsPathL3OutAtt.attributes.mtu }},{{ path.l3extRsPathL3OutAtt.attributes.rType }},{{ path.l3extRsPathL3OutAtt.attributes.state }},{{ path.l3extRsPathL3OutAtt.attributes.stateQual }},{{ path.l3extRsPathL3OutAtt.attributes.status }},{{ path.l3extRsPathL3OutAtt.attributes.tCl }},{{ path.l3extRsPathL3OutAtt.attributes.tDn }},{{ path.l3extRsPathL3OutAtt.attributes.tType }},{{ path.l3extRsPathL3OutAtt.attributes.targetDscp }}
{%-     endfor %}
{%- elif "l3extSubnet" in api %}Name,Name Alias,Aggregate,Annotation,Child Action,Description,DN,Externally Managed By,IP,Local Owner,Last Modified,Monitoring Policy DN,Scope,Status,UID
{%-     for subnet in data_to_template['imdata'] %}
{{ subnet.l3extSubnet.attributes.name }},{{ subnet.l3extSubnet.attributes.nameAlias }},{{ subnet.l3extSubnet.attributes.aggregate }},{{ subnet.l3extSubnet.attributes.annotation }},{{ subnet.l3extSubnet.attributes.childAction }},{{ subnet.l3extSubnet.attributes.descr }},{{ subnet.l3extSubnet.attributes.dn }},{{ subnet.l3extSubnet.attributes.extMngdBy }},{{ subnet.l3extSubnet.attributes.ip }},{{ subnet.l3extSubnet.attributes.lcOwn }},{{ subnet.l3extSubnet.attributes.modTs }},{{ subnet.l3extSubnet.attributes.monPolDn }},{{ subnet.l3extSubnet.attributes.scope | replace(","," ") }},{{ subnet.l3extSubnet.attributes.status }},{{ subnet.l3extSubnet.attributes.uid }}
{%-     endfor %}
{%- elif "lacpEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.lacpEntity.attributes.name }},{{ entity.lacpEntity.attributes.adminSt }},{{ entity.lacpEntity.attributes.childAction }},{{ entity.lacpEntity.attributes.dn }},{{ entity.lacpEntity.attributes.lcOwn }},{{ entity.lacpEntity.attributes.modTs }},{{ entity.lacpEntity.attributes.operErr }},{{ entity.lacpEntity.attributes.openSt }},{{ entity.lacpEntity.attributes.status }}
{%-     endfor %}
{%- elif "lacpIf" in api %}Name,Activity Flags,Admin State,Child Action,Description,DN,ID,Key,Last Active,Local Owner,Last Modified,Monitoring Policy DN,Oper Priority,Port,Priority,Status,TX Rate
{%-     for interface in data_to_template['imdata'] %}
{{ interface.lacpIf.attributes.name }},{{ interface.lacpIf.attributes.activityFlags | replace(","," ") }},{{ interface.lacpIf.attributes.adminSt }},{{ interface.lacpIf.attributes.childAction }},{{ interface.lacpIf.attributes.descr }},{{ interface.lacpIf.attributes.dn }},{{ interface.lacpIf.attributes.id }},{{ interface.lacpIf.attributes.key }},{{ interface.lacpIf.attributes.lastActive }},{{ interface.lacpIf.attributes.lcOwn }},{{ interface.lacpIf.attributes.modTs }},{{ interface.lacpIf.attributes.monPolDn }},{{ interface.lacpIf.attributes.operPrio }},{{ interface.lacpIf.attributes.port }},{{ interface.lacpIf.attributes.prio }},{{ interface.lacpIf.attributes.status }},{{ interface.lacpIf.attributes.txRate }}
{%-     endfor %}
{%- elif "lacpInst" in api %}Name,Admin Priority,Admin State,Child Action,Control,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper Priority,Status,System MAC
{%-     for instance in data_to_template['imdata'] %}
{{ instance.lacpInst.attributes.name }},{{ instance.lacpInst.attributes.adminPrio }},{{ instance.lacpInst.attributes.adminSt }},{{ instance.lacpInst.attributes.childAction }},{{ instance.lacpInst.attributes.ctrl }},{{ instance.lacpInst.attributes.dn }},{{ instance.lacpInst.attributes.lcOwn }},{{ instance.lacpInst.attributes.modTs }},{{ instance.lacpInst.attributes.monPolDn }},{{ instance.lacpInst.attributes.operErr }},{{ instance.lacpInst.attributes.operPrio }},{{ instance.lacpInst.attributes.status }},{{ instance.lacpInst.attributes.sysMac }}
{%-     endfor %}
{%- elif "leqptLooseNode" in api %}Name,Name Alias,Child Action,DN,Edm Node DN,ID,Local Owner,Managed Loose Node,Last Modified,Monitoring Policy DN,Status,System Description,System Name
{%-     for node in data_to_template['imdata'] %}
{{ node.leqptLooseNode.attributes.name }},{{ node.leqptLooseNode.attributes.nameAlias }},{{ node.leqptLooseNode.attributes.childAction }},{{ node.leqptLooseNode.attributes.dn }},{{ node.leqptLooseNode.attributes.edmNodeDn }},{{ node.leqptLooseNode.attributes.id }},{{ node.leqptLooseNode.attributes.lcOwn }},{{ node.leqptLooseNode.attributes.managedLooseNode }},{{ node.leqptLooseNode.attributes.modTs }},{{ node.leqptLooseNode.attributes.monPolDn }},{{ node.leqptLooseNode.attributes.status }},{{ node.leqptLooseNode.attributes.sysDesc | replace("\n"," ") | replace(","," ") }},{{ node.leqptLooseNode.attributes.sysName }}
{%-     endfor %}
{%- elif "leqptRsLsNodeToIf" in api %}DN,Child Action,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,rType,State,State Quality,Status,tCl,tDN,tSKey,tType
{%-     for interface in data_to_template['imdata'] %}
{{ interface.leqptRsLsNodeToIf.attributes.dn }},{{ interface.leqptRsLsNodeToIf.attributes.childAction }},{{ interface.leqptRsLsNodeToIf.attributes.forceResolve }},{{ interface.leqptRsLsNodeToIf.attributes.lcOwn }},{{ interface.leqptRsLsNodeToIf.attributes.modTs }},{{ interface.leqptRsLsNodeToIf.attributes.monPolDn }},{{ interface.leqptRsLsNodeToIf.attributes.rType }},{{ interface.leqptRsLsNodeToIf.attributes.state }},{{ interface.leqptRsLsNodeToIf.attributes.stateQual }},{{ interface.leqptRsLsNodeToIf.attributes.status }},{{ interface.leqptRsLsNodeToIf.attributes.tCl }},{{ interface.leqptRsLsNodeToIf.attributes.tDn }},{{ interface.leqptRsLsNodeToIf.attributes.tSKey }},{{ interface.leqptRsLsNodeToIf.attributes.tType }}
{%-     endfor %}
{%- elif "lldpAdjEp" in api %}Name,Capability,Chassis ID Type,Chassis ID Version,Child Action,DN,Encapsulation,ID,Management ID,Management IP,Management Port MAC,Last Modified,Monitoring Polily DN,Port Description,Port ID Type,Port ID Version,Port VLAN,State Quality,Status,System Description,System Name,TTL
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.lldpAdjEp.attributes.name }},{{ endpoint.lldpAdjEp.attributes.capability | replace(","," ") }},{{ endpoint.lldpAdjEp.attributes.chassisIdT }},{{ endpoint.lldpAdjEp.attributes.chassisIdV }},{{ endpoint.lldpAdjEp.attributes.childAction }},{{ endpoint.lldpAdjEp.attributes.dn }},{{ endpoint.lldpAdjEp.attributes.enCap | replace(","," ") }},{{ endpoint.lldpAdjEp.attributes.id }},{{ endpoint.lldpAdjEp.attributes.mgmtId }},{{ endpoint.lldpAdjEp.attributes.mgmtIp }},{{ endpoint.lldpAdjEp.attributes.mgmtPortMac }},{{ endpoint.lldpAdjEp.attributes.modTs }},{{ endpoint.lldpAdjEp.attributes.monPolDn }},{{ endpoint.lldpAdjEp.attributes.portDesc }},{{ endpoint.lldpAdjEp.attributes.portIdT }},{{ endpoint.lldpAdjEp.attributes.portIdV }},{{ endpoint.lldpAdjEp.attributes.portVlan }},{{ endpoint.lldpAdjEp.attributes.stQual }},{{ endpoint.lldpAdjEp.attributes.status }},{{ endpoint.lldpAdjEp.attributes.sysDesc | replace("\n"," ") | replace(","," ") }},{{ endpoint.lldpAdjEp.attributes.sysName }},{{ endpoint.lldpAdjEp.attributes.ttl }}
{%-     endfor %}
{%- elif "lldpEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.lldpEntity.attributes.name }},{{ entity.lldpEntity.attributes.adminSt }},{{ entity.lldpEntity.attributes.childAction }},{{ entity.lldpEntity.attributes.dn }},{{ entity.lldpEntity.attributes.lcOwn }},{{ entity.lldpEntity.attributes.modTs }},{{ entity.lldpEntity.attributes.monPolDn }},{{ entity.lldpEntity.attributes.operErr }},{{ entity.lldpEntity.attributes.operSt }},{{ entity.lldpEntity.attributes.status }}
{%-     endfor %}
{%- elif "lldpIf" in api %}Name,Admin RX State,Admin State,Admin TX State,Child Action,Description,DN,ID,Local Owner,MAC,Last Modified,Monitoring Policy DN,Oper RX State,Oper TX State,Port Description,Port Mode,Port VLAN,Status,System Description,Wiring Issues
{%-     for interface in data_to_template['imdata'] %}
{{ interface.lldpIf.attributes.name }},{{ interface.lldpIf.attributes.adminRxSt }},{{ interface.lldpIf.attributes.adminSt }},{{ interface.lldpIf.attributes.adminTxSt }},{{ interface.lldpIf.attributes.childAction }},{{ interface.lldpIf.attributes.descr }},{{ interface.lldpIf.attributes.dn }},{{ interface.lldpIf.attributes.id }},{{ interface.lldpIf.attributes.lcOwn }},{{ interface.lldpIf.attributes.mac }},{{ interface.lldpIf.attributes.modTs }},{{ interface.lldpIf.attributes.monPolDn }},{{ interface.lldpIf.attributes.operRxSt }},{{ interface.lldpIf.attributes.operTxSt }},{{ interface.lldpIf.attributes.portDesc }},{{ interface.lldpIf.attributes.portMode }},{{ interface.lldpIf.attributes.portVlan }},{{ interface.lldpIf.attributes.status }},{{ interface.lldpIf.attributes.sysDesc }},{{ interface.lldpIf.attributes.wiringIssues }}
{%-     endfor %}
{%- elif "lldpInst" in api %}Name,Admin State,Child Action,Control,DN,Hold Time,Infra VLAN,Init Delay Time,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Opt Tlv Sel,Status,System Description,TX Frequency
{%-     for instance in data_to_template['imdata'] %}
{{ instance.lldpInst.attributes.name }},{{ instance.lldpInst.attributes.adminSt }},{{ instance.lldpInst.attributes.childAction }},{{ instance.lldpInst.attributes.ctrl }},{{ instance.lldpInst.attributes.dn }},{{ instance.lldpInst.attributes.holdTime }},{{ instance.lldpInst.attributes.infraVlan }},{{ instance.lldpInst.attributes.initDelayTime }},{{ instance.lldpInst.attributes.lcOwn }},{{ instance.lldpInst.attributes.modTs }},{{ instance.lldpInst.attributes.monPolDn }},{{ instance.lldpInst.attributes.operErr }},{{ instance.lldpInst.attributes.optTlvSel | replace(","," ") }},{{ instance.lldpInst.attributes.status }},{{ instance.lldpInst.attributes.sysDesc }},{{ instance.lldpInst.attributes.txFreq }}
{%-     endfor %}
{%- elif "mgmtMgmtIf" in api %}Name,Admin State,Auto Negotiate,Child Action,Description,DN,FCOT Channel Number,ID,Local Owner,Last Modified,Monitoring Policy DN,MTU,SNMP Trap State,Speed,Status,Switching State
{%-     for interface in data_to_template['imdata'] %}
{{ interface.mgmtMgmtIf.attributes.name }},{{ interface.mgmtMgmtIf.attributes.adminSt }},{{ interface.mgmtMgmtIf.attributes.autoNeg }},{{ interface.mgmtMgmtIf.attributes.childAction }},{{ interface.mgmtMgmtIf.attributes.descr }},{{ interface.mgmtMgmtIf.attributes.dn }},{{ interface.mgmtMgmtIf.attributes.fcotChannelNumber }},{{ interface.mgmtMgmtIf.attributes.id }},{{ interface.mgmtMgmtIf.attributes.lcOwn }},{{ interface.mgmtMgmtIf.attributes.modTs }},{{ interface.mgmtMgmtIf.attributes.monPolDn }},{{ interface.mgmtMgmtIf.attributes.mtu }},{{ interface.mgmtMgmtIf.attributes.snmpTrapSt }},{{ interface.mgmtMgmtIf.attributes.speed }},{{ interface.mgmtMgmtIf.attributes.status }},{{ interface.mgmtMgmtIf.attributes.switchingSt }}
{%-     endfor %}
{%- elif "ospfAdjEp" in api %}Name,Area,BDR,BFD State,Child Action,DBD Options,DN,DR,Flags,Hello Options,ID,Interface ID,Last Modified,Monitoring Policy DN,Oper State,Peer IP,Peer Name,Priority,Status
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.ospfAdjEp.attributes.name }},{{ endpoint.ospfAdjEp.attributes.area }},{{ endpoint.ospfAdjEp.attributes.bdr }},{{ endpoint.ospfAdjEp.attributes.bfdSt }},{{ endpoint.ospfAdjEp.attributes.childAction }},{{ endpoint.ospfAdjEp.attributes.dbdOptions }},{{ endpoint.ospfAdjEp.attributes.dn }},{{ endpoint.ospfAdjEp.attributes.dr }},{{ endpoint.ospfAdjEp.attributes.flags }},{{ endpoint.ospfAdjEp.attributes.helloOptions }},{{ endpoint.ospfAdjEp.attributes.id }},{{ endpoint.ospfAdjEp.attributes.ifId }},{{ endpoint.ospfAdjEp.attributes.modTs }},{{ endpoint.ospfAdjEp.attributes.monPolDn }},{{ endpoint.ospfAdjEp.attributes.operSt }},{{ endpoint.ospfAdjEp.attributes.peerIp }},{{ endpoint.ospfAdjEp.attributes.peerName }},{{ endpoint.ospfAdjEp.attributes.prio }},{{ endpoint.ospfAdjEp.attributes.status }}
{%-     endfor %}
{%- elif "ospfArea" in api %}Name,ASBR Count,BR Count,Child Action,Cost,Control,DN,ID,Local Owner,LSA Checksum Summary,Last Modified,NSSA Trans Role,NSSA Trans State,NSSA Trans Stable Interval,Status,Type
{%-     for area in data_to_template['imdata'] %}
{{ area.ospfArea.attributes.name }},{{ area.ospfArea.attributes.asbrCnt }},{{ area.ospfArea.attributes.brCnt }},{{ area.ospfArea.attributes.childAction }},{{ area.ospfArea.attributes.cost }},{{ area.ospfArea.attributes.ctrl | replace(","," ") }},{{ area.ospfArea.attributes.dn }},{{ area.ospfArea.attributes.id }},{{ area.ospfArea.attributes.lcOwn }},{{ area.ospfArea.attributes.lsaCksumSum }},{{ area.ospfArea.attributes.modTs }},{{ area.ospfArea.attributes.nssaTransRole }},{{ area.ospfArea.attributes.nssaTransSt }},{{ area.ospfArea.attributes.nssaTransStabIntvl }},{{ area.ospfArea.attributes.status }},{{ area.ospfArea.attributes.type }}
{%-     endfor %}
{%- elif "ospfDb" in api %}Name,Child Action,DN,Last Modified,Status,Type
{%-     for database in data_to_template['imdata'] %}
{{ database.ospfDb.attributes.name }},{{ database.ospfDb.attributes.childAction }},{{ database.ospfDb.attributes.dn }},{{ database.ospfDb.attributes.modTs }},{{ database.ospfDb.attributes.status }},{{ database.ospfDb.attributes.type }}
{%-     endfor %}
{%- elif "ospfDom" in api %}Name,Bandwidth Reference,Child Action,Control,Distance,DN,ECMP Oper State,Fail State Quality,Flags,Local Owner,Max ECMP,Last Modified,Monitoring Policy DN,Oper State,Router ID,Self Advertised Router Tag,Status
{%-     for domain in data_to_template['imdata'] %}
{{ domain.ospfDom.attributes.name }},{{ domain.ospfDom.attributes.bwRef }},{{ domain.ospfDom.attributes.childAction }},{{ domain.ospfDom.attributes.ctrl }},{{ domain.ospfDom.attributes.dist }},{{ domain.ospfDom.attributes.dn }},{{ domain.ospfDom.attributes.ecmpOperSt }},{{ domain.ospfDom.attributes.failStQual }},{{ domain.ospfDom.attributes.flags | replace(","," ") }},{{ domain.ospfDom.attributes.lcOwn }},{{ domain.ospfDom.attributes.maxEcmp }},{{ domain.ospfDom.attributes.modTs }},{{ domain.ospfDom.attributes.monPolDn }},{{ domain.ospfDom.attributes.operSt }},{{ domain.ospfDom.attributes.rtrId }},{{ domain.ospfDom.attributes.selfAdvRtTag }},{{ domain.ospfDom.attributes.status }}
{%-     endfor %}
{%- elif "ospfEntity" in api %}Name,Admin State,Child Action,DN,Local Owner,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.ospfEntity.attributes.name }},{{ entity.ospfEntity.attributes.adminSt }},{{ entity.ospfEntity.attributes.childAction }},{{ entity.ospfEntity.attributes.dn }},{{ entity.ospfEntity.attributes.lcOwn }},{{ entity.ospfEntity.attributes.modTs }},{{ entity.ospfEntity.attributes.monPolDn }},{{ entity.ospfEntity.attributes.operErr }},{{ entity.ospfEntity.attributes.operSt }},{{ entity.ospfEntity.attributes.status }}
{%-     endfor %}
{%- elif "ospfExtP" in api %}Name,Name Alias,Annotation,Area Cost,Area Control,Area ID,Area Type,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Multipod Internal,Status,UID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.ospfExtP.attributes.name }},{{ profile.ospfExtP.attributes.nameAlias }},{{ profile.ospfExtP.attributes.annotation }},{{ profile.ospfExtP.attributes.areaCost }},{{ profile.ospfExtP.attributes.areaCtrl | replace(","," ") }},{{ profile.ospfExtP.attributes.areaId }},{{ profile.ospfExtP.attributes.areaType }},{{ profile.ospfExtP.attributes.childAction }},{{ profile.ospfExtP.attributes.descr }},{{ profile.ospfExtP.attributes.dn }},{{ profile.ospfExtP.attributes.extMngdBy }},{{ profile.ospfExtP.attributes.lcOwn }},{{ profile.ospfExtP.attributes.modTs }},{{ profile.ospfExtP.attributes.monPolDn }},{{ profile.ospfExtP.attributes.multipodInternal }},{{ profile.ospfExtP.attributes.status }},{{ profile.ospfExtP.attributes.uid }}
{%-     endfor %}
{%- elif "ospfIf" in api %}Name,Address,Admin State,Area,BDR,BDR ID,Child Action,Cost,Control,Dead Interval,Description,DN,DR,DR ID,Failed State Quality,Flags,Hello Interval,ID,Local Owner,LSA Checksum Summary,Last Modified,Monitoring Policy DN,NW Type,Oper Cost,Oper State,P2P Oper State,Prefix Suppress,Priority,Retransmit Interval,Status,Type,Transmit Delay
{%-     for interface in data_to_template['imdata'] %}
{{ interface.ospfIf.attributes.name }},{{ interface.ospfIf.attributes.addr }},{{ interface.ospfIf.attributes.adminSt }},{{ interface.ospfIf.attributes.area }},{{ interface.ospfIf.attributes.bdr }},{{ interface.ospfIf.attributes.bdrId }},{{ interface.ospfIf.attributes.childAction }},{{ interface.ospfIf.attributes.cost }},{{ interface.ospfIf.attributes.ctrl | replace(","," ") }},{{ interface.ospfIf.attributes.deadIntvl }},{{ interface.ospfIf.attributes.descr }},{{ interface.ospfIf.attributes.dn }},{{ interface.ospfIf.attributes.dr }},{{ interface.ospfIf.attributes.drId }},{{ interface.ospfIf.attributes.failStQual }},{{ interface.ospfIf.attributes.flags | replace(","," ") }},{{ interface.ospfIf.attributes.helloIntvl }},{{ interface.ospfIf.attributes.id }},{{ interface.ospfIf.attributes.lcOwn }},{{ interface.ospfIf.attributes.lsaCksumSum }},{{ interface.ospfIf.attributes.modTs }},{{ interface.ospfIf.attributes.monPolDn }},{{ interface.ospfIf.attributes.nwT }},{{ interface.ospfIf.attributes.operCost }},{{ interface.ospfIf.attributes.operSt }},{{ interface.ospfIf.attributes.p2pOperSt }},{{ interface.ospfIf.attributes.pfxSuppress }},{{ interface.ospfIf.attributes.prio }},{{ interface.ospfIf.attributes.rexmitIntvl }},{{ interface.ospfIf.attributes.status }},{{ interface.ospfIf.attributes.type }},{{ interface.ospfIf.attributes.xmitDelay }}
{%-     endfor %}
{%- elif "ospfInst" in api %}Name,Admin State,Child Action,Control,DN,Local Owner,Memory Alert,Last Modified,Monitoring Policy DN,Oper Error,Status
{%-     for instance in data_to_template['imdata'] %}
{{ instance.ospfInst.attributes.name }},{{ instance.ospfInst.attributes.adminSt }},{{ instance.ospfInst.attributes.childAction }},{{ instance.ospfInst.attributes.ctrl }},{{ instance.ospfInst.attributes.dn }},{{ instance.ospfInst.attributes.lcOwn }},{{ instance.ospfInst.attributes.memAlert }},{{ instance.ospfInst.attributes.modTs }},{{ instance.ospfInst.attributes.monPolDn }},{{ instance.ospfInst.attributes.operErr }},{{ instance.ospfInst.attributes.status}}
{%-     endfor %}
{%- elif "ospfRoute" in api %}Name,Area,Child Action,Distance,DN,Flags,Multicast Cost,Last Modified,Path Type,Prefix,Status,Tag,Unicast Cost
{%-     for route in data_to_template['imdata'] %}
{{ route.ospfRoute.attributes.name }},{{ route.ospfRoute.attributes.area }},{{ route.ospfRoute.attributes.childAction }},{{ route.ospfRoute.attributes.dist }},{{ route.ospfRoute.attributes.dn }},{{ route.ospfRoute.attributes.flags | replace(","," ") }},{{ route.ospfRoute.attributes.mcastCost }},{{ route.ospfRoute.attributes.modTs }},{{ route.ospfRoute.attributes.pathT }},{{ route.ospfRoute.attributes.pfx }},{{ route.ospfRoute.attributes.status }},{{ route.ospfRoute.attributes.tag }},{{ route.ospfRoute.attributes.ucastCost }}
{%-     endfor %}
{%- elif "ospfUcNexthop" in api %}Name,Address,Child Action,DN,Flags,Interface,Last Modified,Status
{%-     for nexthop in data_to_template['imdata'] %}
{{ nexthop.ospfUcNexthop.attributes.name }},{{ nexthop.ospfUcNexthop.attributes.addr }},{{ nexthop.ospfUcNexthop.attributes.childAction }},{{ nexthop.ospfUcNexthop.attributes.dn }},{{ nexthop.ospfUcNexthop.attributes.flags | replace(","," ") }},{{ nexthop.ospfUcNexthop.attributes.if }},{{ nexthop.ospfUcNexthop.attributes.modTs }},{{ nexthop.ospfUcNexthop.attributes.status }}
{%-     endfor %}
{%- elif "pcAggrIf" in api %}Name,Active Ports,Admin State,Auto Negotiate,Bandwidth,Child Action,Created,Control,Delay,Description,DN,Dot1q EtherType,Ethpm Config Failed Bmp,Ethpm Config Failed Timestamp,Ethpm Config State,FCOT Channel Number,FOP,Hash Dist,ID,Inherited Bandwidth,IOD,Is Platform Supported,Is Reflective Relay Config Supported,Last Bundle Member,Last Bundle Time,Last State,Last State Cause,Last Time,Last Unbundle Member,Last Unbundle Time,Layer,Local Owner,Logical Interface,Link Debounce,Link Log,Load Defer Start Time,LTL,Max Active,Max Links,MDIX,Medium,Min Links,Last Modified,Mode,Monitoring Policy DN,MTU,Oper Channel Mode,OS Summary,Path S Description,Port Channel ID,Port Channel Mode,Port Channel Member Config Failed Bmp,Port Channel Member Config Failed Timestamp,Port Channel Member Config State,Port Type,Priority Flow Control,Reflective Relay Enable,Router MAC,Row State,SNMP Trap State,Span Mode,Speed,Status,Susp Min Links,Switching State,Trunk Log,Usage
{%-     for interface in data_to_template['imdata'] %}
{{ interface.pcAggrIf.attributes.name }},{{ interface.pcAggrIf.attributes.activePorts }},{{ interface.pcAggrIf.attributes.adminSt }},{{ interface.pcAggrIf.attributes.autoNeg }},{{ interface.pcAggrIf.attributes.bw }},{{ interface.pcAggrIf.attributes.childAction }},{{ interface.pcAggrIf.attributes.createTime }},{{ interface.pcAggrIf.attributes.ctrl | replace(","," ") }},{{ interface.pcAggrIf.attributes.delay }},{{ interface.pcAggrIf.attributes.descr }},{{ interface.pcAggrIf.attributes.dn }},{{ interface.pcAggrIf.attributes.dot1qEtherType }},{{ interface.pcAggrIf.attributes.ethpmCfgFailedBmp }},{{ interface.pcAggrIf.attributes.ethpmCfgFailedTs }},{{ interface.pcAggrIf.attributes.ethpmCfgState }},{{ interface.pcAggrIf.attributes.fcotChannelNumber }},{{ interface.pcAggrIf.attributes.fop }},{{ interface.pcAggrIf.attributes.hashDist }},{{ interface.pcAggrIf.attributes.id }},{{ interface.pcAggrIf.attributes.inhBw }},{{ interface.pcAggrIf.attributes.iod }},{{ interface.pcAggrIf.attributes.isPlatformSupported }},{{ interface.pcAggrIf.attributes.isReflectiveRelayCfgSupported }},{{ interface.pcAggrIf.attributes.lastBundleMbr }},{{ interface.pcAggrIf.attributes.lastBundleTime }},{{ interface.pcAggrIf.attributes.lastSt }},{{ interface.pcAggrIf.attributes.lastStCause }},{{ interface.pcAggrIf.attributes.lastTime }},{{ interface.pcAggrIf.attributes.lastUnbundleMbr }},{{ interface.pcAggrIf.attributes.lastUnbundleTime }},{{ interface.pcAggrIf.attributes.layer }},{{ interface.pcAggrIf.attributes.lcOwn }},{{ interface.pcAggrIf.attributes.lif }},{{ interface.pcAggrIf.attributes.linkDebounce }},{{ interface.pcAggrIf.attributes.linkLog }},{{ interface.pcAggrIf.attributes.loadDeferStartTime }},{{ interface.pcAggrIf.attributes.ltl }},{{ interface.pcAggrIf.attributes.maxActive }},{{ interface.pcAggrIf.attributes.maxLinks }},{{ interface.pcAggrIf.attributes.mdix }},{{ interface.pcAggrIf.attributes.medium }},{{ interface.pcAggrIf.attributes.minLinks }},{{ interface.pcAggrIf.attributes.modTs }},{{ interface.pcAggrIf.attributes.mode }},{{ interface.pcAggrIf.attributes.monPolDn }},{{ interface.pcAggrIf.attributes.mtu }},{{ interface.pcAggrIf.attributes.operChannelMode }},{{ interface.pcAggrIf.attributes.osSum }},{{ interface.pcAggrIf.attributes.pathSDescr }},{{ interface.pcAggrIf.attributes.pcId }},{{ interface.pcAggrIf.attributes.pcMode }},{{ interface.pcAggrIf.attributes.pcmCfgFailedBmp }},{{ interface.pcAggrIf.attributes.pcmCfgFailedTs }},{{ interface.pcAggrIf.attributes.pcmCfgState }},{{ interface.pcAggrIf.attributes.portT }},{{ interface.pcAggrIf.attributes.prioFlowCtrl }},{{ interface.pcAggrIf.attributes.reflectiveRelayEn }},{{ interface.pcAggrIf.attributes.routerMac }},{{ interface.pcAggrIf.attributes.rowSt }},{{ interface.pcAggrIf.attributes.snmpTrapSt }},{{ interface.pcAggrIf.attributes.spanMode }},{{ interface.pcAggrIf.attributes.speed }},{{ interface.pcAggrIf.attributes.status }},{{ interface.pcAggrIf.attributes.suspMinlinks }},{{ interface.pcAggrIf.attributes.switchingSt }},{{ interface.pcAggrIf.attributes.trunkLog }},{{ interface.pcAggrIf.attributes.usage }}
{%-     endfor %}
{%- elif "pcRsMbrIfs" in api %}t S Key,Child Action,DN,Force Resolve,Local Owner,Last Modified,Monitoring Policy DN,Parent S Key,Port Channel Member Config Failed Bmp,Port Channel Member Config Failed Timestamp,Port Channel Member Config State,rType,State,State Quality,Status,tCl,tDn,tType
{%-     for member in data_to_template['imdata'] %}
{{ member.pcRsMbrIfs.attributes.tSKey }},{{ member.pcRsMbrIfs.attributes.childAction }},{{ member.pcRsMbrIfs.attributes.dn }},{{ member.pcRsMbrIfs.attributes.forceResolve }},{{ member.pcRsMbrIfs.attributes.lcOwn }},{{ member.pcRsMbrIfs.attributes.modTs }},{{ member.pcRsMbrIfs.attributes.monPolDn }},{{ member.pcRsMbrIfs.attributes.parentSKey }},{{ member.pcRsMbrIfs.attributes.pcmCfgFailedBmp }},{{ member.pcRsMbrIfs.attributes.pcmCfgFailedTs }},{{ member.pcRsMbrIfs.attributes.pcmCfgState }},{{ member.pcRsMbrIfs.attributes.rType }},{{ member.pcRsMbrIfs.attributes.state }},{{ member.pcRsMbrIfs.attributes.stateQual }},{{ member.pcRsMbrIfs.attributes.status }},{{ member.pcRsMbrIfs.attributes.tCl }},{{ member.pcRsMbrIfs.attributes.tDn }},{{ member.pcRsMbrIfs.attributes.tType }}
{%-     endfor %}
{%- elif "sviIf" in api %}Name,Admin State,Auto State,Bandwidth,Car Del,Child Action,Delay,Description,DN,ID,Inband Management,IOD,Local Owner,Load Interval 1,Load Interval 2,Load Interval 3,MAC,Medium,Last Modified,Monitoring Policy DN,MTU,MTU Inherit,Oper State,Oper State Quality,OS Summary,QoS Priority,Routed Out Def DN,Status,VLAN ID,VLAN Type,vMAC
{%-     for interface in data_to_template['imdata'] %}
{{ interface.sviIf.attributes.name }},{{ interface.sviIf.attributes.adminSt }},{{ interface.sviIf.attributes.autostate }},{{ interface.sviIf.attributes.bw }},{{ interface.sviIf.attributes.carDel }},{{ interface.sviIf.attributes.childAction }},{{ interface.sviIf.attributes.delay }},{{ interface.sviIf.attributes.descr }},{{ interface.sviIf.attributes.dn }},{{ interface.sviIf.attributes.id }},{{ interface.sviIf.attributes.inbMgmt }},{{ interface.sviIf.attributes.iod }},{{ interface.sviIf.attributes.lcOwn }},{{ interface.sviIf.attributes.loadIntvl1 }},{{ interface.sviIf.attributes.loadIntvl2 }},{{ interface.sviIf.attributes.loadIntvl3 }},{{ interface.sviIf.attributes.mac }},{{ interface.sviIf.attributes.medium }},{{ interface.sviIf.attributes.modTs }},{{ interface.sviIf.attributes.monPolDn }},{{ interface.sviIf.attributes.mtu }},{{ interface.sviIf.attributes.mtuInherit }},{{ interface.sviIf.attributes.operSt }},{{ interface.sviIf.attributes.operStQual }},{{ interface.sviIf.attributes.osSum }},{{ interface.sviIf.attributes.qosPrio }},{{ interface.sviIf.attributes.rtdOutDefDn }},{{ interface.sviIf.attributes.status }},{{ interface.sviIf.attributes.vlanId }},{{ interface.sviIf.attributes.vlanT }},{{ interface.sviIf.attributes.vmac }}
{%-     endfor %}
{%- elif "tunnelIf" in api %}Name,ACL TCAM State Quality,Admin State,Configured MTU,Child Action,Del In Progress,Description,Destination,DN,ID,ID Requestor DN,IOD,Keep Alive Interval,Keep Alive Retries,LCC,Local Owner,MAC,Last Modified,Monitoring Policy DN,Oper State,Oper State Quality,Source,Status,T Layer,T Type,TM Config Failed Bmp,TM Config Failed Timestamp,TM Config State,Type,Underlay VRF Name,v6 Source,VRF Name
{%-     for interface in data_to_template['imdata'] %}
{{ interface.tunnelIf.attributes.name }},{{ interface.tunnelIf.attributes.aclTcamStQual }},{{ interface.tunnelIf.attributes.adminSt }},{{ interface.tunnelIf.attributes.cfgdMtu }},{{ interface.tunnelIf.attributes.childAction }},{{ interface.tunnelIf.attributes.delInProg }},{{ interface.tunnelIf.attributes.descr }},{{ interface.tunnelIf.attributes.dest }},{{ interface.tunnelIf.attributes.dn }},{{ interface.tunnelIf.attributes.id }},{{ interface.tunnelIf.attributes.idRequestorDn }},{{ interface.tunnelIf.attributes.iod }},{{ interface.tunnelIf.attributes.keepAlvIntvl }},{{ interface.tunnelIf.attributes.keepAlvRetries }},{{ interface.tunnelIf.attributes.lcC }},{{ interface.tunnelIf.attributes.lcOwn }},{{ interface.tunnelIf.attributes.mac }},{{ interface.tunnelIf.attributes.modTs }},{{ interface.tunnelIf.attributes.monPolDn }},{{ interface.tunnelIf.attributes.operSt }},{{ interface.tunnelIf.attributes.operStQual }},{{ interface.tunnelIf.attributes.src }},{{ interface.tunnelIf.attributes.status }},{{ interface.tunnelIf.attributes.tLayer }},{{ interface.tunnelIf.attributes.tType }},{{ interface.tunnelIf.attributes.tmCfgFailedBmp }},{{ interface.tunnelIf.attributes.tmCfgFailedTs }},{{ interface.tunnelIf.attributes.tmCfgState }},{{ interface.tunnelIf.attributes.type | replace(","," ") }},{{ interface.tunnelIf.attributes.underlayVrfName }},{{ interface.tunnelIf.attributes.v6Src }},{{ interface.tunnelIf.attributes.vrfName }}
{%-     endfor %}
{%- elif "uribv4Db" in api %}Name,Child Action,DN,Last Modified,Status,Type
{%-     for route in data_to_template['imdata'] %}
{{ route.uribv4Db.attributes.name }},{{ route.uribv4Db.attributes.childAction }},{{ route.uribv4Db.attributes.dn }},{{ route.uribv4Db.attributes.modTs }},{{ route.uribv4Db.attributes.status }},{{ route.uribv4Db.attributes.type }}
{%-     endfor %}
{%- elif "uribv4Dom" in api %}Name,Child Action,DN,Last Modified,Oper State,Status
{%-     for route in data_to_template['imdata'] %}
{{ route.uribv4Dom.attributes.name }},{{ route.uribv4Dom.attributes.childAction }},{{ route.uribv4Dom.attributes.dn }},{{ route.uribv4Dom.attributes.modTs }},{{ route.uribv4Dom.attributes.operSt }}{{ route.uribv4Dom.attributes.status }}
{%-     endfor %}
{%- elif "uribv4Entity" in api %}Name,Admin State,Child Action,DN,Last Modified,Monitoring Policy DN,Oper Error,Oper State,Status
{%-     for entity in data_to_template['imdata'] %}
{{ entity.uribv4Entity.attributes.name }},{{ entity.uribv4Entity.attributes.adminSt }},{{ entity.uribv4Entity.attributes.childAction }},{{ entity.uribv4Entity.attributes.dn }},{{ entity.uribv4Entity.attributes.modTs }},{{ entity.uribv4Entity.attributes.monPolDn }},{{ entity.uribv4Entity.attributes.operErr }},{{ entity.uribv4Entity.attributes.operSt }},{{ entity.uribv4Entity.attributes.status }}
{%-     endfor %}
{%- elif "uribv4Nexthop" in api %}Name,Next Hop Metric,Next Hop Tag,Active,Address,Child Action,Created,DN,Interface,Metric,Last Modified,Owner,Preference,Route Type,rw VNID,Status,Tag,Type,VRF
{%-     for nexthop in data_to_template['imdata'] %}
{{ nexthop.uribv4Nexthop.attributes.name }},{{ nexthop.uribv4Nexthop.attributes.Nhmetric }},{{ nexthop.uribv4Nexthop.attributes.Nhtag }},{{ nexthop.uribv4Nexthop.attributes.active }},{{ nexthop.uribv4Nexthop.attributes.addr }},{{ nexthop.uribv4Nexthop.attributes.childAction }},{{ nexthop.uribv4Nexthop.attributes.createTs }},{{ nexthop.uribv4Nexthop.attributes.dn }},{{ nexthop.uribv4Nexthop.attributes.if }},{{ nexthop.uribv4Nexthop.attributes.metric }},{{ nexthop.uribv4Nexthop.attributes.modTs }},{{ nexthop.uribv4Nexthop.attributes.owner }},{{ nexthop.uribv4Nexthop.attributes.pref }},{{ nexthop.uribv4Nexthop.attributes.routeType }},{{ nexthop.uribv4Nexthop.attributes.rwVnid }},{{ nexthop.uribv4Nexthop.attributes.status }},{{ nexthop.uribv4Nexthop.attributes.tag }},{{ nexthop.uribv4Nexthop.attributes.type | replace(","," ") }},{{ nexthop.uribv4Nexthop.attributes.vrf }}
{%-     endfor %}
{%- elif "uribv4Route" in api %}Name,Child Action,DN,Last Modified,Prefix,Prefix Length,Status
{%-     for route in data_to_template['imdata'] %}
{{ route.uribv4Route.attributes.name }},{{ route.uribv4Route.attributes.childAction }},{{ route.uribv4Route.attributes.dn }},{{ route.uribv4Route.attributes.modTs }},{{ route.uribv4Route.attributes.prefix }},{{ route.uribv4Route.attributes.prefixLength }},{{ route.uribv4Route.attributes.status }}
{%-     endfor %}
{%- elif "vlanCktEp" in api %}Name,Admin State,Allow USeg Unsupported,Child Action,Class Preferred Oper State,Created,Control,DN,Encapsulation,Enforced Preference,Endpoint Up Sequence Number,EPG DN,Excessive TCN Flush Control,Fabric Encapsulation,Flood In Encapsulation Unsupported,Forward Control,Hardware ID,ID,Local Owner,Last Modified,Mode,Monitoring Policy DN,Oper State,Oper State Quality,Oper State,Port Channel Tag,Proxy ARP Unsupported,QoS Priority,QoS M Config Failed Bmp,QoS M Config Failed Timestamp,QoS M Config State,Status,Type,VLAN Manager Config Failed Bmp,VLAN Manager Config Failed Timestamp,VLAN Manager Config State,VLAN Manager Custom Fault Bmp
{%-     for vlan in data_to_template['imdata'] %}
{{ vlan.vlanCktEp.attributes.name }},{{ vlan.vlanCktEp.attributes.adminSt }},{{ vlan.vlanCktEp.attributes.allowUsegUnsupported }},{{ vlan.vlanCktEp.attributes.childAction }},{{ vlan.vlanCktEp.attributes.classPrefOperSt }},{{ vlan.vlanCktEp.attributes.createTs }},{{ vlan.vlanCktEp.attributes.ctrl | replace(","," ") }},{{ vlan.vlanCktEp.attributes.dn }},{{ vlan.vlanCktEp.attributes.encap }},{{ vlan.vlanCktEp.attributes.enfPref }},{{ vlan.vlanCktEp.attributes.epUpSeqNum }},{{ vlan.vlanCktEp.attributes.epgDn }},{{ vlan.vlanCktEp.attributes.excessiveTcnFlushCnt }},{{ vlan.vlanCktEp.attributes.fabEncap }},{{ vlan.vlanCktEp.attributes.floodInEncapUnsupported }},{{ vlan.vlanCktEp.attributes.fwdCtrl | replace(","," ") }},{{ vlan.vlanCktEp.attributes.hwId }},{{ vlan.vlanCktEp.attributes.id }},{{ vlan.vlanCktEp.attributes.lcOwn }},{{ vlan.vlanCktEp.attributes.modTs }},{{ vlan.vlanCktEp.attributes.mode }},{{ vlan.vlanCktEp.attributes.monPolDn }},{{ vlan.vlanCktEp.attributes.operSt }},{{ vlan.vlanCktEp.attributes.operStQual }},{{ vlan.vlanCktEp.attributes.operState }},{{ vlan.vlanCktEp.attributes.pcTag }},{{ vlan.vlanCktEp.attributes.proxyArpUnsupported }},{{ vlan.vlanCktEp.attributes.qosPrio }},{{ vlan.vlanCktEp.attributes.qosmCfgFailedBmp }},{{ vlan.vlanCktEp.attributes.qosmCfgFailedTs }},{{ vlan.vlanCktEp.attributes.qosmCfgState }},{{ vlan.vlanCktEp.attributes.status }},{{ vlan.vlanCktEp.attributes.type }},{{ vlan.vlanCktEp.attributes.vlanmgrCfgFailedBmp }},{{ vlan.vlanCktEp.attributes.vlanmgrCfgFailedTs }},{{ vlan.vlanCktEp.attributes.vlanmgrCfgState }},{{ vlan.vlanCktEp.attributes.vlanmgrCustFaultBmp }}
{%-     endfor %}
{%- elif "vmmCtrlrP" in api %}Name,Name Alias,Annotation,Child Action,Config Issues,DN,Domain Name,DVS Version,Externally Managed By,Host Or IP,Inventory Trigger State,Local Owner,Last Modified,Mode,Monitoring Policy DN,Microsoft Config Error Message,Microsoft Config Issues,N1KV Stats Mode,Port,Root Container Name,Scope,Sequence Number,Stats Mode,Status,UID,VXLAN Deployment Preference
{%-     for profile in data_to_template['imdata'] %}
{{ profile.vmmCtrlrP.attributes.name }},{{ profile.vmmCtrlrP.attributes.nameAlias }},{{ profile.vmmCtrlrP.attributes.annotation }},{{ profile.vmmCtrlrP.attributes.childAction }},{{ profile.vmmCtrlrP.attributes.configIssues }},{{ profile.vmmCtrlrP.attributes.dn }},{{ profile.vmmCtrlrP.attributes.domName }},{{ profile.vmmCtrlrP.attributes.dvsVersion }},{{ profile.vmmCtrlrP.attributes.extMngdBy }},{{ profile.vmmCtrlrP.attributes.hostOrIp }},{{ profile.vmmCtrlrP.attributes.inventoryTrigSt }},{{ profile.vmmCtrlrP.attributes.lcOwn }},{{ profile.vmmCtrlrP.attributes.modTs }},{{ profile.vmmCtrlrP.attributes.mode }},{{ profile.vmmCtrlrP.attributes.monPolDn }},{{ profile.vmmCtrlrP.attributes.msftConfigErrMsg }},{{ profile.vmmCtrlrP.attributes.msftConfigIssues }},{{ profile.vmmCtrlrP.attributes.n1kvStatsMode }},{{ profile.vmmCtrlrP.attributes.port }},{{ profile.vmmCtrlrP.attributes.rootContName }},{{ profile.vmmCtrlrP.attributes.scope }},{{ profile.vmmCtrlrP.attributes.seqNum }},{{ profile.vmmCtrlrP.attributes.statsMode }},{{ profile.vmmCtrlrP.attributes.status }},{{ profile.vmmCtrlrP.attributes.uid }},{{ profile.vmmCtrlrP.attributes.vxlanDeplPref }}
{%-     endfor %}
{%- elif "vmmDomP" in api %}Name,Name Alias,Access Mode,Annotation,ARP Learning,AVE Timeout,Child Action,Config Infra Pg,Config Issues,Control Knob,Delimiter,DN,Enable AVE,Enable Tag,Enable VM Folder,Encapsulation Mode,Enforced Preference,Endpoint Inventory Type,Endpoint Retention Time,Externally Managed By,Hypervisor Availability Monitor,LAG Policy Name,Local Owner,Multicast Address,Last Modified,Mode,Monitoring Policy DN,Owner Key,Owner Tag,Preferred Encapsulation Mode,Status,TX ID,UID,Unique ID
{%-     for profile in data_to_template['imdata'] %}
{{ profile.vmmDomP.attributes.name }},{{ profile.vmmDomP.attributes.nameAlias }},{{ profile.vmmDomP.attributes.accessMode }},{{ profile.vmmDomP.attributes.annotation }},{{ profile.vmmDomP.attributes.arpLearning }},{{ profile.vmmDomP.attributes.aveTimeOut }},{{ profile.vmmDomP.attributes.childAction }},{{ profile.vmmDomP.attributes.configInfraPg }},{{ profile.vmmDomP.attributes.configIssues }},{{ profile.vmmDomP.attributes.ctrlKnob }},{{ profile.vmmDomP.attributes.delimiter }},{{ profile.vmmDomP.attributes.dn }},{{ profile.vmmDomP.attributes.enableAVE }},{{ profile.vmmDomP.attributes.enableTag }},{{ profile.vmmDomP.attributes.enableVmFolder }},{{ profile.vmmDomP.attributes.encapMode }},{{ profile.vmmDomP.attributes.enfPref }},{{ profile.vmmDomP.attributes.epInventoryType }},{{ profile.vmmDomP.attributes.epRetTime }},{{ profile.vmmDomP.attributes.extMngdBy }},{{ profile.vmmDomP.attributes.hvAvailMonitor }},{{ profile.vmmDomP.attributes.lagPolicyName }},{{ profile.vmmDomP.attributes.lcOwn }},{{ profile.vmmDomP.attributes.mcastAddr }},{{ profile.vmmDomP.attributes.modTs }},{{ profile.vmmDomP.attributes.mode }},{{ profile.vmmDomP.attributes.monPolDn }},{{ profile.vmmDomP.attributes.ownerKey }},{{ profile.vmmDomP.attributes.ownerTag }},{{ profile.vmmDomP.attributes.prefEncapMode }},{{ profile.vmmDomP.attributes.status }},{{ profile.vmmDomP.attributes.txId }},{{ profile.vmmDomP.attributes.uid }},{{ profile.vmmDomP.attributes.uniqueId }}
{%-     endfor %}
{%- elif "vmmProvP" in api %}Name,Name Alias,Annotation,Child Action,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Type,UID,Vendor
{%-     for profile in data_to_template['imdata'] %}
{{ profile.vmmProvP.attributes.name }},{{ profile.vmmProvP.attributes.nameAlias }},{{ profile.vmmProvP.attributes.annotation }},{{ profile.vmmProvP.attributes.childAction }},{{ profile.vmmProvP.attributes.dn }},{{ profile.vmmProvP.attributes.extMngdBy }},{{ profile.vmmProvP.attributes.lcOwn }},{{ profile.vmmProvP.attributes.modTs }},{{ profile.vmmProvP.attributes.monPolDn }},{{ profile.vmmProvP.attributes.ownerKey }},{{ profile.vmmProvP.attributes.ownerTag }},{{ profile.vmmProvP.attributes.status }},{{ profile.vmmProvP.attributes.type }},{{ profile.vmmProvP.attributes.uid }},{{ profile.vmmProvP.attributes.vendor }}
{%-     endfor %}
{%- elif "vmmUsrAccP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Owner Key,Owner Tag,Status,UID,User
{%-     for profile in data_to_template['imdata'] %}
{{ profile.vmmUsrAccP.attributes.name }},{{ profile.vmmUsrAccP.attributes.nameAlias }},{{ profile.vmmUsrAccP.attributes.annotation }},{{ profile.vmmUsrAccP.attributes.childAction }},{{ profile.vmmUsrAccP.attributes.descr }},{{ profile.vmmUsrAccP.attributes.dn }},{{ profile.vmmUsrAccP.attributes.extMngdBy }},{{ profile.vmmUsrAccP.attributes.lcOwn }},{{ profile.vmmUsrAccP.attributes.modTs }},{{ profile.vmmUsrAccP.attributes.ownerKey }},{{ profile.vmmUsrAccP.attributes.ownerTag }},{{ profile.vmmUsrAccP.attributes.status }},{{ profile.vmmUsrAccP.attributes.uid }},{{ profile.vmmUsrAccP.attributes.usr }}
{%-     endfor %}
{%- elif "vpcDom" in api %}Name,Batched VPC Inv,Child Action,Compatibility Quality,Compatibility Quality String,Compatibility State,Dead Interval,DN,Dual Active State,ID,ISSU From Version,ISSU To Version,LACP Role,Local Owner,Local MAC,Local Priority,Last Modified,Monitoring Policy DN,Old Role,Oper Role,Oper State,Orphan Port List,Peer IP,Peer MAC,Peer Priority,Peer State,Peer State Quality,Peer Version,Role Priority,Self Init Fabric Link Flap Count,Split Brain Timer Duration,Split Brain Timer Is Running,Split Brain Timer Start Time,Status,Summary Oper Role,System MAC,System Priority,Try Role Establish Timer Duration,Try Role Establish Timer Is Running,Try Role Establish Timer Start Time,Type2 Compatibility Quality,Type2 Compatibility Quality String,Type2 Compatibility State,Virtual IP Announce Delay,Virtual IP,VPC Config Failed Bmp,VPC Config Failed Timestamp,VPC Config State,VPC MAC,VPC Priority
{%-     for domain in data_to_template['imdata'] %}
{{ domain.vpcDom.attributes.name }},{{ domain.vpcDom.attributes.batchedVpcInv }},{{ domain.vpcDom.attributes.childAction }},{{ domain.vpcDom.attributes.compatQual }},{{ domain.vpcDom.attributes.compatQualStr }},{{ domain.vpcDom.attributes.compatSt }},{{ domain.vpcDom.attributes.deadIntvl }},{{ domain.vpcDom.attributes.dn }},{{ domain.vpcDom.attributes.dualActiveSt }},{{ domain.vpcDom.attributes.id }},{{ domain.vpcDom.attributes.issuFromVer }},{{ domain.vpcDom.attributes.issuToVer }},{{ domain.vpcDom.attributes.lacpRole }},{{ domain.vpcDom.attributes.lcOwn }},{{ domain.vpcDom.attributes.localMAC }},{{ domain.vpcDom.attributes.localPrio }},{{ domain.vpcDom.attributes.modTs }},{{ domain.vpcDom.attributes.monPolDn }},{{ domain.vpcDom.attributes.oldRole }},{{ domain.vpcDom.attributes.operRole }},{{ domain.vpcDom.attributes.operSt | replace(","," ") }},{{ domain.vpcDom.attributes.orphanPortList }},{{ domain.vpcDom.attributes.peerIp }},{{ domain.vpcDom.attributes.peerMAC }},{{ domain.vpcDom.attributes.peerPrio }},{{ domain.vpcDom.attributes.peerSt }},{{ domain.vpcDom.attributes.peerStQual }},{{ domain.vpcDom.attributes.peerVersion }},{{ domain.vpcDom.attributes.rolePrio }},{{ domain.vpcDom.attributes.selfIniFabLinkFlapCnt }},{{ domain.vpcDom.attributes.splitBrainTimerDuration }},{{ domain.vpcDom.attributes.splitBrainTimerIsRun }},{{ domain.vpcDom.attributes.splitBrainTimerStartTime }},{{ domain.vpcDom.attributes.status }},{{ domain.vpcDom.attributes.summOperRole }},{{ domain.vpcDom.attributes.sysMac }},{{ domain.vpcDom.attributes.sysPrio }},{{ domain.vpcDom.attributes.tryRoleEstabTimerDuration }},{{ domain.vpcDom.attributes.tryRoleEstabTimerIsRun }},{{ domain.vpcDom.attributes.tryRoleEstabTimerStartTime }},{{ domain.vpcDom.attributes.type2CompatQual }},{{ domain.vpcDom.attributes.type2CompatQualStr }},{{ domain.vpcDom.attributes.type2CompatSt }},{{ domain.vpcDom.attributes.vIpAnnounceDelay }},{{ domain.vpcDom.attributes.virtualIp }},{{ domain.vpcDom.attributes.vpcCfgFailedBmp }},{{ domain.vpcDom.attributes.vpcCfgFailedTs }},{{ domain.vpcDom.attributes.vpcCfgState }},{{ domain.vpcDom.attributes.vpcMAC }},{{ domain.vpcDom.attributes.vpcPrio }}
{%-     endfor %}
{%- endif %}